@@ -85,6 +85,8 @@ class ContactsController extends Controller
         }
 
         $tagsCount = Tag::contactsCount();
+        $contactsWithoutTagsCount = (clone $contacts)->doesntHave('tags')->count();
+
         $tags = null;
         $url = null;
         $count = 1;
@@ -131,10 +133,12 @@ class ContactsController extends Controller
             ->withHasArchived($nbArchived > 0)
             ->withArchivedContacts($nbArchived)
             ->withTags($tags)
+            ->withSort($sort)
             ->withTagsCount($tagsCount)
             ->withUrl($url)
             ->withTagCount($count)
-            ->withTagLess($request->input('no_tag') ?? false);
+            ->withTagLess($request->input('no_tag') ?? false)
+            ->with('contactsWithoutTagsCount', $contactsWithoutTagsCount);
     }
 
     /**
