@@ -16,7 +16,7 @@ class User extends JsonResource
      * Transform the resource into an array.
      *
      * @param  \Illuminate\Http\Request  $request
-     * @return array
+     * @return array|\Illuminate\Contracts\Support\Arrayable|\JsonSerializable
      */
     public function toArray($request)
     {
@@ -26,6 +26,7 @@ class User extends JsonResource
             'object' => 'user',
             'first_name' => $this->first_name,
             'last_name' => $this->last_name,
+            'name' => $this->name,
             'email' => $this->email,
             'me_contact' => new ContactShortResource($this->me),
             'timezone' => $this->timezone,
