@@ -11,16 +11,13 @@ class Country extends JsonResource
      * Transform the resource into an array.
      *
      * @param  \Illuminate\Http\Request  $request
-     * @return array
+     * @return array|\Illuminate\Contracts\Support\Arrayable|\JsonSerializable
      */
     public function toArray($request)
     {
         if (is_array($this->resource)) {
             $id = $this->resource['id'];
             $name = $this->resource['country'];
-        } elseif ($this->resource instanceof \PragmaRX\Countries\Package\Support\Collection) {
-            $id = $this->resource->id;
-            $name = $this->resource->country;
         } else {
             $id = $this->resource;
             $name = CountriesHelper::get($this->resource);
