@@ -3,7 +3,6 @@
 namespace App\Jobs;
 
 use Throwable;
-use App\Services\BaseService;
 use Illuminate\Bus\Queueable;
 use App\Services\QueuableService;
 use Illuminate\Queue\SerializesModels;
@@ -39,14 +38,11 @@ class ServiceQueue implements ShouldQueue
     /**
      * Create a new job instance.
      *
-     * @param  BaseService  $service
+     * @param  QueuableService  $service
      * @param  array|null  $data
      */
-    public function __construct(BaseService $service, array $data = null)
+    public function __construct(QueuableService $service, array $data = null)
     {
-        if (! $service instanceof QueuableService) {
-            throw new \Exception('Service is not queuable');
-        }
         $this->service = $service;
         $this->data = $data;
     }
