@@ -28,15 +28,17 @@ class DefaultTemperatureScale extends Migration
                     $currentLocale = $user->locale;
                 }
 
-                switch ($country->cca2) {
-                    case 'US':
-                    case 'BZ':
-                    case 'KY':
-                        $user->temperature_scale = 'fahrenheit';
-                        break;
-                    default:
-                        $user->temperature_scale = 'celsius';
-                        break;
+                if ($country !== null) {
+                    switch ($country->getIsoAlpha2()) {
+                        case 'US':
+                        case 'BZ':
+                        case 'KY':
+                            $user->temperature_scale = 'fahrenheit';
+                            break;
+                        default:
+                            $user->temperature_scale = 'celsius';
+                            break;
+                    }
                 }
 
                 $user->save();
