@@ -140,8 +140,10 @@ return [
 
     'relationship_type_partner' => 'significant other',
     'relationship_type_partner_female' => 'significant other',
+    'relationship_type_partner_male' => 'significant other',
     'relationship_type_partner_with_name' => ':name’s significant other',
     'relationship_type_partner_female_with_name' => ':name’s significant other',
+    'relationship_type_partner_male_with_name' => ':name’s significant other',
 
     'relationship_type_spouse' => 'زوج',
     'relationship_type_spouse_female' => 'wife',
@@ -152,23 +154,31 @@ return [
 
     'relationship_type_date' => 'موعد',
     'relationship_type_date_female' => 'موعد',
+    'relationship_type_date_male' => 'date',
     'relationship_type_date_with_name' => ':name’s date',
     'relationship_type_date_female_with_name' => ':name’s date',
+    'relationship_type_date_male_with_name' => ':name’s date',
 
     'relationship_type_lover' => 'عاشق',
     'relationship_type_lover_female' => 'عاشقة',
+    'relationship_type_lover_male' => 'lover',
     'relationship_type_lover_with_name' => ':name’s lover',
     'relationship_type_lover_female_with_name' => ':name’s lover',
+    'relationship_type_lover_male_with_name' => ':name’s lover',
 
     'relationship_type_inlovewith' => 'مغرم بـ',
     'relationship_type_inlovewith_female' => 'مغرمة بـ',
+    'relationship_type_inlovewith_male' => 'in love with',
     'relationship_type_inlovewith_with_name' => 'someone :name is in love with',
     'relationship_type_inlovewith_female_with_name' => 'someone :name is in love with',
+    'relationship_type_inlovewith_male_with_name' => 'someone :name is in love with',
 
     'relationship_type_lovedby' => 'محبوب من قِبل',
     'relationship_type_lovedby_female' => 'محبوبة من قِبل',
+    'relationship_type_lovedby_male' => 'loved by',
     'relationship_type_lovedby_with_name' => ':name’s secret lover',
     'relationship_type_lovedby_female_with_name' => ':name’s secret lover',
+    'relationship_type_lovedby_male_with_name' => ':name’s secret lover',
 
     'relationship_type_ex' => 'ex-partner',
     'relationship_type_ex_female' => 'ex-girlfriend',
@@ -228,18 +238,24 @@ return [
 
     'relationship_type_uncle' => 'عم/خال',
     'relationship_type_uncle_female' => 'عمة/خالة',
+    'relationship_type_uncle_male' => 'uncle',
     'relationship_type_uncle_with_name' => 'عم/خال :name',
     'relationship_type_uncle_female_with_name' => 'عمة/خالة :name',
+    'relationship_type_uncle_male_with_name' => ':name’s uncle',
 
     'relationship_type_nephew' => 'ابن شقيق',
     'relationship_type_nephew_female' => 'ابنة شقيقة',
+    'relationship_type_nephew_male' => 'nephew',
     'relationship_type_nephew_with_name' => 'ابن شقيق :name',
     'relationship_type_nephew_female_with_name' => 'ابنة شقيقة :name',
+    'relationship_type_nephew_male_with_name' => ':name’s nephew',
 
     'relationship_type_cousin' => 'ابن عم/خال',
     'relationship_type_cousin_female' => 'ابنة عمة/خالة',
+    'relationship_type_cousin_male' => 'cousin',
     'relationship_type_cousin_with_name' => 'ابن عم/خال :name',
     'relationship_type_cousin_female_with_name' => 'ابنة عمة/خالة :name',
+    'relationship_type_cousin_male_with_name' => ':name’s cousin',
 
     'relationship_type_godfather' => 'godparent',
     'relationship_type_godfather_female' => 'godmother',
@@ -257,38 +273,52 @@ return [
 
     'relationship_type_friend' => 'صديق',
     'relationship_type_friend_female' => 'صديقة',
+    'relationship_type_friend_male' => 'friend',
     'relationship_type_friend_with_name' => 'صديق :name',
     'relationship_type_friend_female_with_name' => 'صديقة :name',
+    'relationship_type_friend_male_with_name' => ':name’s friend',
 
     'relationship_type_bestfriend' => 'الصديق المفضل',
     'relationship_type_bestfriend_female' => 'الصديقة المفضلة',
+    'relationship_type_bestfriend_male' => 'best friend',
     'relationship_type_bestfriend_with_name' => 'صديق :name المفضل',
     'relationship_type_bestfriend_female_with_name' => 'صديقة :name المفضلة',
+    'relationship_type_bestfriend_male_with_name' => ':name’s best friend',
 
     'relationship_type_colleague' => 'زميل',
     'relationship_type_colleague_female' => 'زميلة',
+    'relationship_type_colleague_male' => 'colleague',
     'relationship_type_colleague_with_name' => 'زميل :name',
     'relationship_type_colleague_female_with_name' => 'زميلة :name',
+    'relationship_type_colleague_male_with_name' => ':name’s colleague',
 
     'relationship_type_boss' => 'مدير',
     'relationship_type_boss_female' => 'مديرة',
+    'relationship_type_boss_male' => 'boss',
     'relationship_type_boss_with_name' => 'مدير :name',
     'relationship_type_boss_female_with_name' => 'مديرة :name',
+    'relationship_type_boss_male_with_name' => ':name’s boss',
 
     'relationship_type_subordinate' => 'مرؤوس',
     'relationship_type_subordinate_female' => 'مرؤوسة',
+    'relationship_type_subordinate_male' => 'subordinate',
     'relationship_type_subordinate_with_name' => 'مرؤوس :name',
     'relationship_type_subordinate_female_with_name' => 'مرؤوسة :name',
+    'relationship_type_subordinate_male_with_name' => ':name’s subordinate',
 
     'relationship_type_mentor' => 'مرشد',
     'relationship_type_mentor_female' => 'مرشدة',
+    'relationship_type_mentor_male' => 'mentor',
     'relationship_type_mentor_with_name' => 'مرشد :name',
     'relationship_type_mentor_female_with_name' => 'مرشدة :name',
+    'relationship_type_mentor_male_with_name' => ':name’s mentor',
 
     'relationship_type_protege' => 'protégé',
     'relationship_type_protege_female' => 'protégé',
+    'relationship_type_protege_male' => 'protégé',
     'relationship_type_protege_with_name' => ':name’s protégé',
     'relationship_type_protege_female_with_name' => ':name’s protégé',
+    'relationship_type_protege_male_with_name' => ':name’s protégé',
 
     'relationship_type_ex_husband' => 'ex-spouse',
     'relationship_type_ex_husband_female' => 'طليقة',
