@@ -14,7 +14,7 @@ return [
     'add' => 'Přidat',
     'cancel' => 'Zrušit',
     'confirm' => 'Potvrdit',
-    'delete_confirm' => 'Are you sure?',
+    'delete_confirm' => 'Jste si jisti?',
     'delete' => 'Smazat',
     'edit' => 'Upravit',
     'upload' => 'Nahrát',
@@ -31,7 +31,7 @@ return [
     'new' => 'nový',
     'unknown' => 'Nevím',
     'load_more' => 'Načíst další',
-    'loading' => 'Loading…',
+    'loading' => 'Načítání…',
     'with' => 's',
     'today' => 'dnes',
     'yesterday' => 'včera',
@@ -39,16 +39,16 @@ return [
     'date' => 'Datum',
     'type' => 'Typ',
     'zoom' => 'Zvětšení',
-    'upgrade' => 'Upgrade to unlock',
+    'upgrade' => 'Upgradujte pro odemknutí',
     'percent_uploaded' => '{percent}% nahráno',
     'retry' => 'Opakovat',
     'filter' => 'Filtrovat seznam',
     'go_back' => 'Jít zpět',
-    'file_selected' => 'One file selected…|{count} files selected…',
+    'file_selected' => 'Jeden soubor vybrán…| vybráno {count} souborů…',
 
     'application_title' => 'Monica – správce osobních vztahů',
     'application_description' => 'Monica is a tool to manage your interactions with your loved ones, friends and family.',
-    'application_og_title' => 'Have better relations with your loved ones. Free online CRM for friends and family.',
+    'application_og_title' => 'Pro lepší vztahy s vašimi blízkými. Bezplatný online CRM pro přátele a rodinu.',
 
     'markdown_description' => 'Chcete pohodlně formátovat text? Podporujeme formát markdown pro značení tučně, kurzivou, vytváření seznamu a další.',
     'markdown_link' => 'Číst dokumentaci',
@@ -64,14 +64,14 @@ return [
     'main_nav_activities' => 'Aktivity',
     'main_nav_tasks' => 'Úkoly',
 
-    'footer_remarks' => 'Comments?',
-    'footer_send_email' => 'Send us an email',
+    'footer_remarks' => 'Komentáře?',
+    'footer_send_email' => 'Pošlete nám e-mail',
     'footer_privacy' => 'Podmínky používání',
     'footer_release' => 'Poznámky k vydání',
     'footer_newsletter' => 'Odběr novinek',
     'footer_source_code' => 'Monica na GitHubu',
     'footer_version' => 'Verze: :version',
-    'footer_new_version' => 'A new version of Monica is available',
+    'footer_new_version' => 'Je dostupné nová verze aplikace Monica',
 
     'footer_modal_version_whats_new' => 'Novinky',
     'footer_modal_version_release_away' => 'Jste jedno vydání pozadu za nejnovější dostupnou verzí. Měli byste aktualizovat svou instanci.|Jste :number vydání pozadu za nejnovější dostupnou verzí. Měli byste aktualizovat svou instanci.',
@@ -113,17 +113,17 @@ return [
     'error_try_again' => 'Něco se pokazilo. Zkuste to znovu.',
     'error_id' => 'ID chyby: :id',
     'error_unavailable' => 'Služba není dostupná',
-    'error_maintenance' => 'Maintenance in progress. We’ll be right back.',
+    'error_maintenance' => 'Probíhá údržba. Budeme obratem zpátky.',
     'error_help' => 'Budeme hned zpátky.',
     'error_twitter' => 'Sledujte <a href="https://twitter.com/:twitter">náš Twitter účet</a> a buďte upozorněni, až služba znovu poběží.',
     'error_no_term' => 'Pro tuto instanci zatím neexistují žádná pravidla.',
 
-    'default_save_success' => 'The data has been saved.',
+    'default_save_success' => 'Data byla uložena.',
 
-    'compliance_title' => 'Sorry for the interruption.',
-    'compliance_desc' => 'We have changed our <a href=":urlterm" hreflang=":hreflang">Terms of Use</a> and <a href=":url" hreflang=":hreflang">Privacy Policy</a>. By law we have to ask you to review them and accept them so you can continue to use your account.',
+    'compliance_title' => 'Omlouváme se za vyrušení.',
+    'compliance_desc' => 'Změnili jsme <a href=":urlterm" hreflang=":hreflang">Smluvní podmínky</a> a <a href=":url" hreflang=":hreflang">Zásady ochrany osobních údajů</a>. Podle zákona vás musíme požádat, abyste je zkontrolovali a přijali, abyste mohli nadále používat svůj účet.',
     'compliance_desc_end' => 'We don’t do anything nasty with your data or account and will never do.',
-    'compliance_terms' => 'Accept new terms and privacy policy',
+    'compliance_terms' => 'Přijmout nové podmínky a zásady ochrany osobních údajů',
 
     // Relationship types
     // Yes, each relationship type has 8 strings associated with it.
@@ -132,18 +132,20 @@ return [
     // and then, the feminine version of the string. Finally, in some sentences
     // in the UI, we need to include the name of the person we add the relationship
     // to.
-    'relationship_type_group_love' => 'Love relationships',
-    'relationship_type_group_family' => 'Family relationships',
-    'relationship_type_group_friend' => 'Friend relationships',
-    'relationship_type_group_work' => 'Work relationships',
-    'relationship_type_group_other' => 'Other kind of relationships',
+    'relationship_type_group_love' => 'Milostné vztahy',
+    'relationship_type_group_family' => 'Rodinné vztahy',
+    'relationship_type_group_friend' => 'Vztahy s přáteli',
+    'relationship_type_group_work' => 'Pracovní vztahy',
+    'relationship_type_group_other' => 'Jiný druh vztahů',
 
-    'relationship_type_partner' => 'significant other',
-    'relationship_type_partner_female' => 'significant other',
+    'relationship_type_partner' => 'drahá polovička',
+    'relationship_type_partner_female' => 'drahá polovička',
+    'relationship_type_partner_male' => 'drahá polovička',
     'relationship_type_partner_with_name' => ':name’s significant other',
     'relationship_type_partner_female_with_name' => ':name’s significant other',
+    'relationship_type_partner_male_with_name' => ':name’s significant other',
 
-    'relationship_type_spouse' => 'spouse',
+    'relationship_type_spouse' => 'Manžel(ka)',
     'relationship_type_spouse_female' => 'manželka',
     'relationship_type_spouse_male' => 'manžel',
     'relationship_type_spouse_with_name' => ':name’s spouse',
@@ -152,41 +154,49 @@ return [
 
     'relationship_type_date' => 'date',
     'relationship_type_date_female' => 'date',
+    'relationship_type_date_male' => 'date',
     'relationship_type_date_with_name' => ':name’s date',
     'relationship_type_date_female_with_name' => ':name’s date',
+    'relationship_type_date_male_with_name' => ':name’s date',
 
     'relationship_type_lover' => 'lover',
     'relationship_type_lover_female' => 'lover',
+    'relationship_type_lover_male' => 'lover',
     'relationship_type_lover_with_name' => ':name’s lover',
     'relationship_type_lover_female_with_name' => ':name’s lover',
+    'relationship_type_lover_male_with_name' => ':name’s lover',
 
     'relationship_type_inlovewith' => 'in love with',
     'relationship_type_inlovewith_female' => 'in love with',
+    'relationship_type_inlovewith_male' => 'in love with',
     'relationship_type_inlovewith_with_name' => 'someone :name is in love with',
     'relationship_type_inlovewith_female_with_name' => 'someone :name is in love with',
+    'relationship_type_inlovewith_male_with_name' => 'someone :name is in love with',
 
     'relationship_type_lovedby' => 'loved by',
     'relationship_type_lovedby_female' => 'loved by',
+    'relationship_type_lovedby_male' => 'loved by',
     'relationship_type_lovedby_with_name' => ':name’s secret lover',
     'relationship_type_lovedby_female_with_name' => ':name’s secret lover',
+    'relationship_type_lovedby_male_with_name' => ':name’s secret lover',
 
-    'relationship_type_ex' => 'ex-partner',
-    'relationship_type_ex_female' => 'ex-girlfriend',
-    'relationship_type_ex_male' => 'ex-boyfriend',
+    'relationship_type_ex' => 'bývalý partner',
+    'relationship_type_ex_female' => 'bývalá přítelkyně',
+    'relationship_type_ex_male' => 'bývalý přítel',
     'relationship_type_ex_with_name' => ':name’s ex-partner',
     'relationship_type_ex_female_with_name' => ':name’s ex-girlfriend',
     'relationship_type_ex_male_with_name' => ':name’s ex-boyfriend',
 
-    'relationship_type_parent' => 'parent',
+    'relationship_type_parent' => 'rodič',
     'relationship_type_parent_female' => 'matka',
-    'relationship_type_parent_male' => 'father',
+    'relationship_type_parent_male' => 'otec',
     'relationship_type_parent_with_name' => ':name’s parent',
     'relationship_type_parent_female_with_name' => ':name’s mother',
     'relationship_type_parent_male_with_name' => ':name’s father',
 
-    'relationship_type_child' => 'child',
+    'relationship_type_child' => 'dítě',
     'relationship_type_child_female' => 'dcera',
-    'relationship_type_child_male' => 'son',
+    'relationship_type_child_male' => 'syn',
     'relationship_type_child_with_name' => ':name’s child',
     'relationship_type_child_female_with_name' => ':name’s daughter',
     'relationship_type_child_male_with_name' => ':name’s son',
@@ -205,45 +215,51 @@ return [
     'relationship_type_stepchild_female_with_name' => ':name’s stepdaughter',
     'relationship_type_stepchild_male_with_name' => ':name’s stepson',
 
-    'relationship_type_sibling' => 'sibling',
+    'relationship_type_sibling' => 'sourozenec',
     'relationship_type_sibling_female' => 'sestra',
-    'relationship_type_sibling_male' => 'brother',
+    'relationship_type_sibling_male' => 'bratr',
     'relationship_type_sibling_with_name' => ':name’s sibling',
     'relationship_type_sibling_female_with_name' => ':name’s sister',
     'relationship_type_sibling_male_with_name' => ':name’s brother',
 
-    'relationship_type_grandparent' => 'grandparent',
-    'relationship_type_grandparent_female' => 'grandmother',
-    'relationship_type_grandparent_male' => 'grandfather',
+    'relationship_type_grandparent' => 'prarodič',
+    'relationship_type_grandparent_female' => 'babička',
+    'relationship_type_grandparent_male' => 'dědeček',
     'relationship_type_grandparent_with_name' => ':name’s grandparent',
     'relationship_type_grandparent_female_with_name' => ':name’s grandmother',
     'relationship_type_grandparent_male_with_name' => ':name’s grandfather',
 
-    'relationship_type_grandchild' => 'grandchild',
-    'relationship_type_grandchild_female' => 'granddaughter',
-    'relationship_type_grandchild_male' => 'grandson',
+    'relationship_type_grandchild' => 'vnouče',
+    'relationship_type_grandchild_female' => 'vnučka',
+    'relationship_type_grandchild_male' => 'vnuk',
     'relationship_type_grandchild_with_name' => ':name’s grandchild',
     'relationship_type_grandchild_female_with_name' => ':name’s granddauther',
     'relationship_type_grandchild_male_with_name' => ':name’s grandson',
 
     'relationship_type_uncle' => 'strýc',
     'relationship_type_uncle_female' => 'teta',
+    'relationship_type_uncle_male' => 'strýc',
     'relationship_type_uncle_with_name' => ':name’s uncle',
     'relationship_type_uncle_female_with_name' => ':name’s aunt',
+    'relationship_type_uncle_male_with_name' => ':name’s uncle',
 
     'relationship_type_nephew' => 'synovec',
     'relationship_type_nephew_female' => 'neteř',
+    'relationship_type_nephew_male' => 'synovec',
     'relationship_type_nephew_with_name' => ':name’s nephew',
     'relationship_type_nephew_female_with_name' => ':name’s niece',
+    'relationship_type_nephew_male_with_name' => ':name’s nephew',
 
     'relationship_type_cousin' => 'bratranec',
     'relationship_type_cousin_female' => 'sestřenice',
+    'relationship_type_cousin_male' => 'bratranec',
     'relationship_type_cousin_with_name' => ':name’s cousin',
     'relationship_type_cousin_female_with_name' => ':name’s cousin',
+    'relationship_type_cousin_male_with_name' => ':name’s cousin',
 
     'relationship_type_godfather' => 'godparent',
-    'relationship_type_godfather_female' => 'godmother',
-    'relationship_type_godfather_male' => 'godfather',
+    'relationship_type_godfather_female' => 'kmotra',
+    'relationship_type_godfather_male' => 'kmotr',
     'relationship_type_godfather_with_name' => ':name’s godparent',
     'relationship_type_godfather_female_with_name' => ':name’s godmother',
     'relationship_type_godfather_male_with_name' => ':name’s godfather',
@@ -257,82 +273,96 @@ return [
 
     'relationship_type_friend' => 'kamarád',
     'relationship_type_friend_female' => 'kamarádka',
+    'relationship_type_friend_male' => 'přítel',
     'relationship_type_friend_with_name' => ':name’s friend',
     'relationship_type_friend_female_with_name' => ':name’s friend',
+    'relationship_type_friend_male_with_name' => ':name’s friend',
 
     'relationship_type_bestfriend' => 'nejlepší kamarád',
     'relationship_type_bestfriend_female' => 'nejlepší kamarádka',
+    'relationship_type_bestfriend_male' => 'nejlepší přítel',
     'relationship_type_bestfriend_with_name' => ':name’s best friend',
     'relationship_type_bestfriend_female_with_name' => ':name’s best friend',
+    'relationship_type_bestfriend_male_with_name' => ':name’s best friend',
 
     'relationship_type_colleague' => 'kolega',
     'relationship_type_colleague_female' => 'kolegyně',
+    'relationship_type_colleague_male' => 'colleague',
     'relationship_type_colleague_with_name' => ':name’s colleague',
     'relationship_type_colleague_female_with_name' => ':name’s colleague',
+    'relationship_type_colleague_male_with_name' => ':name’s colleague',
 
     'relationship_type_boss' => 'nadřízený',
     'relationship_type_boss_female' => 'nadřízená',
+    'relationship_type_boss_male' => 'boss',
     'relationship_type_boss_with_name' => ':name’s boss',
     'relationship_type_boss_female_with_name' => ':name’s boss',
+    'relationship_type_boss_male_with_name' => ':name’s boss',
 
     'relationship_type_subordinate' => 'podřízený',
     'relationship_type_subordinate_female' => 'podřízená',
+    'relationship_type_subordinate_male' => 'subordinate',
     'relationship_type_subordinate_with_name' => ':name’s subordinate',
     'relationship_type_subordinate_female_with_name' => ':name’s subordinate',
+    'relationship_type_subordinate_male_with_name' => ':name’s subordinate',
 
     'relationship_type_mentor' => 'mentor',
     'relationship_type_mentor_female' => 'mentor',
+    'relationship_type_mentor_male' => 'mentor',
     'relationship_type_mentor_with_name' => ':name’s mentor',
     'relationship_type_mentor_female_with_name' => ':name’s mentor',
+    'relationship_type_mentor_male_with_name' => ':name’s mentor',
 
     'relationship_type_protege' => 'protégé',
     'relationship_type_protege_female' => 'protégé',
+    'relationship_type_protege_male' => 'protégé',
     'relationship_type_protege_with_name' => ':name’s protégé',
     'relationship_type_protege_female_with_name' => ':name’s protégé',
+    'relationship_type_protege_male_with_name' => ':name’s protégé',
 
-    'relationship_type_ex_husband' => 'ex-spouse',
+    'relationship_type_ex_husband' => 'bývalý manžel/ka',
     'relationship_type_ex_husband_female' => 'ex wife',
-    'relationship_type_ex_husband_male' => 'ex-husband',
+    'relationship_type_ex_husband_male' => 'bývalý manžel',
     'relationship_type_ex_husband_with_name' => ':name’s ex-spouse',
     'relationship_type_ex_husband_female_with_name' => ':name’s ex wife',
     'relationship_type_ex_husband_male_with_name' => ':name’s ex-husband',
 
     // emotions
-    'emotion_primary_love' => 'Love',
-    'emotion_primary_joy' => 'Joy',
-    'emotion_primary_surprise' => 'Surprise',
-    'emotion_primary_anger' => 'Anger',
-    'emotion_primary_sadness' => 'Sadness',
-    'emotion_primary_fear' => 'Fear',
+    'emotion_primary_love' => 'Láska',
+    'emotion_primary_joy' => 'Radost',
+    'emotion_primary_surprise' => 'Překvapení',
+    'emotion_primary_anger' => 'Hněv',
+    'emotion_primary_sadness' => 'Smutek',
+    'emotion_primary_fear' => 'Strach',
 
-    'emotion_secondary_affection' => 'Affection',
+    'emotion_secondary_affection' => 'Náklonnost',
     'emotion_secondary_lust' => 'Lust',
     'emotion_secondary_longing' => 'Longing',
     'emotion_secondary_cheerfulness' => 'Cheerfulness',
     'emotion_secondary_zest' => 'Zest',
     'emotion_secondary_contentment' => 'Contentment',
-    'emotion_secondary_pride' => 'Pride',
-    'emotion_secondary_optimism' => 'Optimism',
+    'emotion_secondary_pride' => 'Hrdost',
+    'emotion_secondary_optimism' => 'Optimismus',
     'emotion_secondary_enthrallment' => 'Enthrallment',
-    'emotion_secondary_relief' => 'Relief',
-    'emotion_secondary_surprise' => 'Surprise',
-    'emotion_secondary_irritation' => 'Irritation',
+    'emotion_secondary_relief' => 'Úleva',
+    'emotion_secondary_surprise' => 'Překvapení',
+    'emotion_secondary_irritation' => 'Podrážděnost',
     'emotion_secondary_exasperation' => 'Exasperation',
-    'emotion_secondary_rage' => 'Rage',
-    'emotion_secondary_disgust' => 'Disgust',
+    'emotion_secondary_rage' => 'Vztek',
+    'emotion_secondary_disgust' => 'Znechucení',
     'emotion_secondary_envy' => 'Envy',
     'emotion_secondary_suffering' => 'Suffering',
-    'emotion_secondary_sadness' => 'Sadness',
-    'emotion_secondary_disappointment' => 'Disappointment',
+    'emotion_secondary_sadness' => 'Smutek',
+    'emotion_secondary_disappointment' => 'Zklamání',
     'emotion_secondary_shame' => 'Shame',
     'emotion_secondary_neglect' => 'Neglect',
-    'emotion_secondary_sympathy' => 'Sympathy',
+    'emotion_secondary_sympathy' => 'Sympatie',
     'emotion_secondary_horror' => 'Horror',
-    'emotion_secondary_nervousness' => 'Nervousness',
+    'emotion_secondary_nervousness' => 'Nervozita',
 
     'emotion_adoration' => 'Adoration',
-    'emotion_affection' => 'Affection',
-    'emotion_love' => 'Love',
+    'emotion_affection' => 'Náklonnost',
+    'emotion_love' => 'Láska',
     'emotion_fondness' => 'Fondness',
     'emotion_liking' => 'Liking',
     'emotion_attraction' => 'Attraction',
@@ -468,49 +498,49 @@ return [
     'weather_sunny' => 'Sunny',
     'weather_clear' => 'Clear',
     'weather_clear-day' => 'Clear',
-    'weather_clear-night' => 'Clear night',
-    'weather_light-drizzle' => 'Light drizzle',
-    'weather_patchy-light-drizzle' => 'Patchy light drizzle',
-    'weather_patchy-light-rain' => 'Patchy light rain',
-    'weather_light-rain' => 'Light rain',
-    'weather_moderate-rain-at-times' => 'Moderate rain at times',
-    'weather_moderate-rain' => 'Moderate rain',
-    'weather_patchy-rain-possible' => 'Patchy rain possible',
-    'weather_heavy-rain-at-times' => 'Heavy rain at times',
-    'weather_heavy-rain' => 'Heavy rain',
-    'weather_light-freezing-rain' => 'Light freezing rain',
-    'weather_moderate-or-heavy-freezing-rain' => 'Moderate or heavy freezing rain',
-    'weather_light-sleet' => 'Light sleet',
-    'weather_moderate-or-heavy-rain-shower' => 'Moderate or heavy rain shower',
-    'weather_light-rain-shower' => 'Light rain shower',
-    'weather_torrential-rain-shower' => 'Torrential rain shower',
-    'weather_rain' => 'Rain',
-    'weather_snow' => 'Snow',
-    'weather_blowing-snow' => 'Blowing snow',
-    'weather_patchy-light-snow' => 'Patchy light snow',
-    'weather_light-snow' => 'Light snow',
-    'weather_patchy-moderate-snow' => 'Patchy moderate snow',
-    'weather_moderate-snow' => 'Moderate snow',
-    'weather_patchy-heavy-snow' => 'Patchy heavy snow',
-    'weather_heavy-snow' => 'Heavy snow',
-    'weather_light-snow-showers' => 'Light snow showers',
-    'weather_moderate-or-heavy-snow-showers' => 'Moderate or heavy snow showers',
-    'weather_patchy-snow-possible' => 'Patchy snow possible',
-    'weather_patchy-sleet-possible' => 'Patchy sleet possible',
-    'weather_moderate-or-heavy-sleet' => 'Moderate or heavy sleet',
-    'weather_light-sleet-showers' => 'Light sleet showers',
-    'weather_moderate-or-heavy-sleet-showers' => 'Moderate or heavy sleet showers',
-    'weather_sleet' => 'Sleet',
-    'weather_wind' => 'Wind',
-    'weather_fog' => 'Fog',
-    'weather_freezing-fog' => 'Freezing fog',
-    'weather_mist' => 'Mist',
-    'weather_blizzard' => 'Blizzard',
-    'weather_overcast' => 'Overcast',
-    'weather_cloudy' => 'Cloudy',
-    'weather_partly-cloudy-day' => 'Partly cloudy',
-    'weather_partly-cloudy-night' => 'Partly cloudy',
-    'weather_freezing-drizzle' => 'Freezing drizzle',
+    'weather_clear-night' => 'Jasná noc',
+    'weather_light-drizzle' => 'Slabé mrholení',
+    'weather_patchy-light-drizzle' => 'Místy slabé mrholení',
+    'weather_patchy-light-rain' => 'Místy slabý déšť',
+    'weather_light-rain' => 'Slabý déšť',
+    'weather_moderate-rain-at-times' => 'Občasný mírný déšť',
+    'weather_moderate-rain' => 'Mírný déšť',
+    'weather_patchy-rain-possible' => 'Místy možný déšť',
+    'weather_heavy-rain-at-times' => 'Občasný vydatný déšť',
+    'weather_heavy-rain' => 'Vydatný déšť',
+    'weather_light-freezing-rain' => 'Slabý mrznoucí déšť',
+    'weather_moderate-or-heavy-freezing-rain' => 'Střední nebo silný mrznoucí déšť',
+    'weather_light-sleet' => 'Slabý déšť se sněhem',
+    'weather_moderate-or-heavy-rain-shower' => 'Střední nebo silné déšťové přeháňky',
+    'weather_light-rain-shower' => 'Slabé dešťové přeháňky',
+    'weather_torrential-rain-shower' => 'Přívalové dešťové přeháňky',
+    'weather_rain' => 'Déšť',
+    'weather_snow' => 'Sněžení',
+    'weather_blowing-snow' => 'Zvířený sníh',
+    'weather_patchy-light-snow' => 'Místy slabé sněžení',
+    'weather_light-snow' => 'Slabé sněžení',
+    'weather_patchy-moderate-snow' => 'Místy střední sněžení',
+    'weather_moderate-snow' => 'Mírné sněžení',
+    'weather_patchy-heavy-snow' => 'Místy silné sněžení',
+    'weather_heavy-snow' => 'Silné sněžení',
+    'weather_light-snow-showers' => 'Slabé sněhové přeháňky',
+    'weather_moderate-or-heavy-snow-showers' => 'Střední nebo silné sněhové přeháňky',
+    'weather_patchy-snow-possible' => 'Místy možné sněžení',
+    'weather_patchy-sleet-possible' => 'Místy možný déšť se sněhem',
+    'weather_moderate-or-heavy-sleet' => 'Střední nebo silný déšť se sněhem',
+    'weather_light-sleet-showers' => 'Slabé přeháňky deště se sněhem',
+    'weather_moderate-or-heavy-sleet-showers' => 'Střední nebo silné přeháňky deště se sněhem',
+    'weather_sleet' => 'Déšť se sněhem',
+    'weather_wind' => 'Vítr',
+    'weather_fog' => 'Mlha',
+    'weather_freezing-fog' => 'Mrznoucí mlha',
+    'weather_mist' => 'Opar',
+    'weather_blizzard' => 'Sněhová vánice',
+    'weather_overcast' => 'Zataženo',
+    'weather_cloudy' => 'Oblačno',
+    'weather_partly-cloudy-day' => 'Částečně oblačno',
+    'weather_partly-cloudy-night' => 'Částečně oblačno',
+    'weather_freezing-drizzle' => 'Mrznoucí mrholení',
     'weather_heavy-freezing-drizzle' => 'Heavy freezing drizzle',
     'weather_patchy-freezing-drizzle-possible' => 'Patchy freezing drizzle possible',
     'weather_ice-pellets' => 'Ice pellets',
