@@ -140,8 +140,10 @@ return [
 
     'relationship_type_partner' => 'partner',
     'relationship_type_partner_female' => 'partner',
+    'relationship_type_partner_male' => 'significant other',
     'relationship_type_partner_with_name' => ':name’s partner',
     'relationship_type_partner_female_with_name' => ':name’s partner',
+    'relationship_type_partner_male_with_name' => ':name’s significant other',
 
     'relationship_type_spouse' => 'ægtefælle',
     'relationship_type_spouse_female' => 'wife',
@@ -152,23 +154,31 @@ return [
 
     'relationship_type_date' => 'date',
     'relationship_type_date_female' => 'date',
+    'relationship_type_date_male' => 'date',
     'relationship_type_date_with_name' => ':name’s date',
     'relationship_type_date_female_with_name' => ':name’s date',
+    'relationship_type_date_male_with_name' => ':name’s date',
 
     'relationship_type_lover' => 'elsker',
     'relationship_type_lover_female' => 'elsker',
+    'relationship_type_lover_male' => 'lover',
     'relationship_type_lover_with_name' => ':name’s elsker',
     'relationship_type_lover_female_with_name' => ':name’s elsker',
+    'relationship_type_lover_male_with_name' => ':name’s lover',
 
     'relationship_type_inlovewith' => 'in love with',
     'relationship_type_inlovewith_female' => 'in love with',
+    'relationship_type_inlovewith_male' => 'in love with',
     'relationship_type_inlovewith_with_name' => 'someone :name is in love with',
     'relationship_type_inlovewith_female_with_name' => 'someone :name is in love with',
+    'relationship_type_inlovewith_male_with_name' => 'someone :name is in love with',
 
     'relationship_type_lovedby' => 'loved by',
     'relationship_type_lovedby_female' => 'loved by',
+    'relationship_type_lovedby_male' => 'loved by',
     'relationship_type_lovedby_with_name' => ':name’s secret lover',
     'relationship_type_lovedby_female_with_name' => ':name’s secret lover',
+    'relationship_type_lovedby_male_with_name' => ':name’s secret lover',
 
     'relationship_type_ex' => 'ex-partner',
     'relationship_type_ex_female' => 'ekskæreste',
@@ -228,18 +238,24 @@ return [
 
     'relationship_type_uncle' => 'onkel',
     'relationship_type_uncle_female' => 'tante',
+    'relationship_type_uncle_male' => 'uncle',
     'relationship_type_uncle_with_name' => ':name’s onkel',
     'relationship_type_uncle_female_with_name' => ':name’s tante',
+    'relationship_type_uncle_male_with_name' => ':name’s uncle',
 
     'relationship_type_nephew' => 'nevø',
     'relationship_type_nephew_female' => 'niece',
+    'relationship_type_nephew_male' => 'nephew',
     'relationship_type_nephew_with_name' => ':name’s nevø',
     'relationship_type_nephew_female_with_name' => ':name’s niece',
+    'relationship_type_nephew_male_with_name' => ':name’s nephew',
 
     'relationship_type_cousin' => 'fætter',
     'relationship_type_cousin_female' => 'kusine',
+    'relationship_type_cousin_male' => 'cousin',
     'relationship_type_cousin_with_name' => ':name’s fætter',
     'relationship_type_cousin_female_with_name' => ':name’s kusine',
+    'relationship_type_cousin_male_with_name' => ':name’s cousin',
 
     'relationship_type_godfather' => 'godparent',
     'relationship_type_godfather_female' => 'gudmor',
@@ -257,38 +273,52 @@ return [
 
     'relationship_type_friend' => 'ven',
     'relationship_type_friend_female' => 'veninde',
+    'relationship_type_friend_male' => 'friend',
     'relationship_type_friend_with_name' => ':name’s ven',
     'relationship_type_friend_female_with_name' => ':name’s veninde',
+    'relationship_type_friend_male_with_name' => ':name’s friend',
 
     'relationship_type_bestfriend' => 'bedste ven',
     'relationship_type_bestfriend_female' => 'bedste veninde',
+    'relationship_type_bestfriend_male' => 'best friend',
     'relationship_type_bestfriend_with_name' => ':name’s bedste ven',
     'relationship_type_bestfriend_female_with_name' => ':name’s bedste veninde',
+    'relationship_type_bestfriend_male_with_name' => ':name’s best friend',
 
     'relationship_type_colleague' => 'kollega',
     'relationship_type_colleague_female' => 'kollega',
+    'relationship_type_colleague_male' => 'colleague',
     'relationship_type_colleague_with_name' => ':name’s kollega',
     'relationship_type_colleague_female_with_name' => ':name’s kollega',
+    'relationship_type_colleague_male_with_name' => ':name’s colleague',
 
     'relationship_type_boss' => 'boss',
     'relationship_type_boss_female' => 'boss',
+    'relationship_type_boss_male' => 'boss',
     'relationship_type_boss_with_name' => ':name’s boss',
     'relationship_type_boss_female_with_name' => ':name’s boss',
+    'relationship_type_boss_male_with_name' => ':name’s boss',
 
     'relationship_type_subordinate' => 'subordinate',
     'relationship_type_subordinate_female' => 'subordinate',
+    'relationship_type_subordinate_male' => 'subordinate',
     'relationship_type_subordinate_with_name' => ':name’s subordinate',
     'relationship_type_subordinate_female_with_name' => ':name’s subordinate',
+    'relationship_type_subordinate_male_with_name' => ':name’s subordinate',
 
     'relationship_type_mentor' => 'mentor',
     'relationship_type_mentor_female' => 'mentor',
+    'relationship_type_mentor_male' => 'mentor',
     'relationship_type_mentor_with_name' => ':name’s mentor',
     'relationship_type_mentor_female_with_name' => ':name’s mentor',
+    'relationship_type_mentor_male_with_name' => ':name’s mentor',
 
     'relationship_type_protege' => 'protégé',
     'relationship_type_protege_female' => 'protégé',
+    'relationship_type_protege_male' => 'protégé',
     'relationship_type_protege_with_name' => ':name’s protégé',
     'relationship_type_protege_female_with_name' => ':name’s protégé',
+    'relationship_type_protege_male_with_name' => ':name’s protégé',
 
     'relationship_type_ex_husband' => 'ex-spouse',
     'relationship_type_ex_husband_female' => 'ekskone',
