@@ -140,8 +140,10 @@ return [
 
     'relationship_type_partner' => 'Lebensgefährte',
     'relationship_type_partner_female' => 'Lebensgefährtin',
+    'relationship_type_partner_male' => 'Lebensgefährte',
     'relationship_type_partner_with_name' => ':names Lebensgefährte',
     'relationship_type_partner_female_with_name' => ':names Lebensgefährtin',
+    'relationship_type_partner_male_with_name' => ':name’s Lebensgefährte',
 
     'relationship_type_spouse' => 'Ehegatte',
     'relationship_type_spouse_female' => 'Ehefrau',
@@ -152,23 +154,31 @@ return [
 
     'relationship_type_date' => 'Verabredung',
     'relationship_type_date_female' => 'Verabredung',
+    'relationship_type_date_male' => 'Verabredung',
     'relationship_type_date_with_name' => ':names Verabredung',
     'relationship_type_date_female_with_name' => ':names Verabredung',
+    'relationship_type_date_male_with_name' => ':name’s Verabredung',
 
     'relationship_type_lover' => 'Liebhaber',
     'relationship_type_lover_female' => 'Liebhaberin',
+    'relationship_type_lover_male' => 'Liebhaber',
     'relationship_type_lover_with_name' => ':names Liebhaber',
     'relationship_type_lover_female_with_name' => ':names Liebhaberin',
+    'relationship_type_lover_male_with_name' => ':name’s Liebhaber',
 
     'relationship_type_inlovewith' => 'verliebt in',
     'relationship_type_inlovewith_female' => 'verliebt in',
+    'relationship_type_inlovewith_male' => 'verliebt in',
     'relationship_type_inlovewith_with_name' => ':name ist verliebt in',
     'relationship_type_inlovewith_female_with_name' => ':name ist verliebt in',
+    'relationship_type_inlovewith_male_with_name' => ':name ist verliebt in',
 
     'relationship_type_lovedby' => 'geliebt von',
     'relationship_type_lovedby_female' => 'geliebt von',
+    'relationship_type_lovedby_male' => 'geliebt von',
     'relationship_type_lovedby_with_name' => ':names heimlicher Verehrer',
     'relationship_type_lovedby_female_with_name' => ':names heimliche Verehrerin',
+    'relationship_type_lovedby_male_with_name' => ':name’s heimlicher Verehrer',
 
     'relationship_type_ex' => 'Ex-Partner',
     'relationship_type_ex_female' => 'Ex-Freundin',
@@ -228,18 +238,24 @@ return [
 
     'relationship_type_uncle' => 'Onkel',
     'relationship_type_uncle_female' => 'Tante',
+    'relationship_type_uncle_male' => 'Onkel',
     'relationship_type_uncle_with_name' => ':name\'s Onkel',
     'relationship_type_uncle_female_with_name' => ':name\'s Tante',
+    'relationship_type_uncle_male_with_name' => ':name’s Onkel',
 
     'relationship_type_nephew' => 'Neffe',
     'relationship_type_nephew_female' => 'Nichte',
+    'relationship_type_nephew_male' => 'Neffe',
     'relationship_type_nephew_with_name' => ':name\'s Neffe',
     'relationship_type_nephew_female_with_name' => ':name\'s Nichte',
+    'relationship_type_nephew_male_with_name' => ':name’s Neffe',
 
     'relationship_type_cousin' => 'Cousin',
     'relationship_type_cousin_female' => 'Cousine',
+    'relationship_type_cousin_male' => 'Cousin',
     'relationship_type_cousin_with_name' => ':name\'s Cousin',
     'relationship_type_cousin_female_with_name' => ':name\'s Cousine',
+    'relationship_type_cousin_male_with_name' => ':name’s Cousin',
 
     'relationship_type_godfather' => 'Pate',
     'relationship_type_godfather_female' => 'Patin',
@@ -257,38 +273,52 @@ return [
 
     'relationship_type_friend' => 'Freund',
     'relationship_type_friend_female' => 'Freundin',
+    'relationship_type_friend_male' => 'Freund',
     'relationship_type_friend_with_name' => ':name\'s Freund',
     'relationship_type_friend_female_with_name' => ':name\'s Freundin',
+    'relationship_type_friend_male_with_name' => ':name’s Freund',
 
     'relationship_type_bestfriend' => 'Bester Freund',
     'relationship_type_bestfriend_female' => 'Beste Freundin',
+    'relationship_type_bestfriend_male' => 'bester Freund',
     'relationship_type_bestfriend_with_name' => ':name\'s bester Freund',
     'relationship_type_bestfriend_female_with_name' => ':name\'s beste Freundin',
+    'relationship_type_bestfriend_male_with_name' => ':name’s bester Freund',
 
     'relationship_type_colleague' => 'Kollege',
     'relationship_type_colleague_female' => 'Kollegin',
+    'relationship_type_colleague_male' => 'Kollege',
     'relationship_type_colleague_with_name' => ':name\'s Kollege',
     'relationship_type_colleague_female_with_name' => ':name\'s Kollegin',
+    'relationship_type_colleague_male_with_name' => ':name’s Kollege',
 
     'relationship_type_boss' => 'Chef',
     'relationship_type_boss_female' => 'Chefin',
+    'relationship_type_boss_male' => 'Chef',
     'relationship_type_boss_with_name' => ':name\'s Chef',
     'relationship_type_boss_female_with_name' => ':name\'s Chefin',
+    'relationship_type_boss_male_with_name' => ':name’s Chef',
 
     'relationship_type_subordinate' => ':name\'s Untergebener',
     'relationship_type_subordinate_female' => ':name\'s Untergebene',
+    'relationship_type_subordinate_male' => 'Untergebener',
     'relationship_type_subordinate_with_name' => ':name\'s Mitarbeiter',
     'relationship_type_subordinate_female_with_name' => ':name\'s Mitarbeiterin',
+    'relationship_type_subordinate_male_with_name' => ':name’s Untergebener',
 
     'relationship_type_mentor' => 'Mentor',
     'relationship_type_mentor_female' => 'Mentorin',
+    'relationship_type_mentor_male' => 'Mentor',
     'relationship_type_mentor_with_name' => ':name\'s Mentor',
     'relationship_type_mentor_female_with_name' => ':name\'s Mentorin',
+    'relationship_type_mentor_male_with_name' => ':name’s Mentor',
 
     'relationship_type_protege' => 'Schützling',
     'relationship_type_protege_female' => 'Schützling',
+    'relationship_type_protege_male' => 'Schützling',
     'relationship_type_protege_with_name' => ':name’s Schützling',
     'relationship_type_protege_female_with_name' => ':name’s Schützling',
+    'relationship_type_protege_male_with_name' => ':name’s Schützling',
 
     'relationship_type_ex_husband' => 'Ex-Mann',
     'relationship_type_ex_husband_female' => 'Ex-Frau',
