@@ -140,8 +140,10 @@ return [
 
     'relationship_type_partner' => 'σύντροφος',
     'relationship_type_partner_female' => 'σύντροφος',
+    'relationship_type_partner_male' => 'significant other',
     'relationship_type_partner_with_name' => 'σύντροφος :name',
     'relationship_type_partner_female_with_name' => 'σύντροφος :name',
+    'relationship_type_partner_male_with_name' => ':name’s significant other',
 
     'relationship_type_spouse' => 'σύζυγος',
     'relationship_type_spouse_female' => 'wife',
@@ -152,23 +154,31 @@ return [
 
     'relationship_type_date' => 'ημερομηνία',
     'relationship_type_date_female' => 'ημερομηνία',
+    'relationship_type_date_male' => 'date',
     'relationship_type_date_with_name' => 'ημερομηνία :name',
     'relationship_type_date_female_with_name' => 'ημερομηνία :name',
+    'relationship_type_date_male_with_name' => ':name’s date',
 
     'relationship_type_lover' => 'εραστής',
     'relationship_type_lover_female' => 'εραστής',
+    'relationship_type_lover_male' => 'lover',
     'relationship_type_lover_with_name' => 'εραστής :name',
     'relationship_type_lover_female_with_name' => 'εραστής :name',
+    'relationship_type_lover_male_with_name' => ':name’s lover',
 
     'relationship_type_inlovewith' => 'ερωτευμένος με',
     'relationship_type_inlovewith_female' => 'ερωτευμένος με',
+    'relationship_type_inlovewith_male' => 'in love with',
     'relationship_type_inlovewith_with_name' => 'κάποιος με τον οποίο ο :name είναι ερωτευμένος',
     'relationship_type_inlovewith_female_with_name' => 'κάποιος με τον οποίο ο :name είναι ερωτευμένος',
+    'relationship_type_inlovewith_male_with_name' => 'someone :name is in love with',
 
     'relationship_type_lovedby' => 'αγαπημένος του',
     'relationship_type_lovedby_female' => 'αγαπημένος του',
+    'relationship_type_lovedby_male' => 'loved by',
     'relationship_type_lovedby_with_name' => 'κρυφός εραστής :name',
     'relationship_type_lovedby_female_with_name' => 'κρυφός εραστής της :name',
+    'relationship_type_lovedby_male_with_name' => ':name’s secret lover',
 
     'relationship_type_ex' => 'ex-partner',
     'relationship_type_ex_female' => 'πρώην φίλη',
@@ -228,18 +238,24 @@ return [
 
     'relationship_type_uncle' => 'θείος',
     'relationship_type_uncle_female' => 'θεία',
+    'relationship_type_uncle_male' => 'uncle',
     'relationship_type_uncle_with_name' => 'θείος του :name',
     'relationship_type_uncle_female_with_name' => 'θεία του :name',
+    'relationship_type_uncle_male_with_name' => ':name’s uncle',
 
     'relationship_type_nephew' => 'ανιψιός',
     'relationship_type_nephew_female' => 'ανιψιά',
+    'relationship_type_nephew_male' => 'nephew',
     'relationship_type_nephew_with_name' => 'ανιψιός του :name',
     'relationship_type_nephew_female_with_name' => 'ανιψιά του :name',
+    'relationship_type_nephew_male_with_name' => ':name’s nephew',
 
     'relationship_type_cousin' => 'ξάδερφος',
     'relationship_type_cousin_female' => 'ξαδέρφη',
+    'relationship_type_cousin_male' => 'cousin',
     'relationship_type_cousin_with_name' => 'ξάδερφος του :name',
     'relationship_type_cousin_female_with_name' => 'ξαδέρφη του :name',
+    'relationship_type_cousin_male_with_name' => ':name’s cousin',
 
     'relationship_type_godfather' => 'godparent',
     'relationship_type_godfather_female' => 'νονά',
@@ -257,38 +273,52 @@ return [
 
     'relationship_type_friend' => 'φίλος',
     'relationship_type_friend_female' => 'φίλη',
+    'relationship_type_friend_male' => 'friend',
     'relationship_type_friend_with_name' => 'φίλος του :name',
     'relationship_type_friend_female_with_name' => 'φίλη του :name',
+    'relationship_type_friend_male_with_name' => ':name’s friend',
 
     'relationship_type_bestfriend' => 'καλύτερος φίλος',
     'relationship_type_bestfriend_female' => 'καλύτερη φίλη',
+    'relationship_type_bestfriend_male' => 'best friend',
     'relationship_type_bestfriend_with_name' => 'καλύτερος φίλος του :name',
     'relationship_type_bestfriend_female_with_name' => 'καλύτερη φίλη του :name',
+    'relationship_type_bestfriend_male_with_name' => ':name’s best friend',
 
     'relationship_type_colleague' => 'συνάδελφος',
     'relationship_type_colleague_female' => 'συνάδελφος',
+    'relationship_type_colleague_male' => 'colleague',
     'relationship_type_colleague_with_name' => 'συνάδελφος του :name',
     'relationship_type_colleague_female_with_name' => 'συνάδελφος του :name',
+    'relationship_type_colleague_male_with_name' => ':name’s colleague',
 
     'relationship_type_boss' => 'αφεντικό',
     'relationship_type_boss_female' => 'αφεντικό',
+    'relationship_type_boss_male' => 'boss',
     'relationship_type_boss_with_name' => 'αφεντικό του :name',
     'relationship_type_boss_female_with_name' => 'αφεντικό του :name',
+    'relationship_type_boss_male_with_name' => ':name’s boss',
 
     'relationship_type_subordinate' => 'υφιστάμενος',
     'relationship_type_subordinate_female' => 'υφιστάμενη',
+    'relationship_type_subordinate_male' => 'subordinate',
     'relationship_type_subordinate_with_name' => 'υφιστάμενος του :name',
     'relationship_type_subordinate_female_with_name' => 'υφιστάμενη του :name',
+    'relationship_type_subordinate_male_with_name' => ':name’s subordinate',
 
     'relationship_type_mentor' => 'σύμβουλος',
     'relationship_type_mentor_female' => 'μέντορας',
+    'relationship_type_mentor_male' => 'mentor',
     'relationship_type_mentor_with_name' => 'σύμβουλος του :name',
     'relationship_type_mentor_female_with_name' => 'σύμβουλος της :name',
+    'relationship_type_mentor_male_with_name' => ':name’s mentor',
 
     'relationship_type_protege' => 'protégé',
     'relationship_type_protege_female' => 'protégé',
+    'relationship_type_protege_male' => 'protégé',
     'relationship_type_protege_with_name' => ':name’s protégé',
     'relationship_type_protege_female_with_name' => ':name’s protégé',
+    'relationship_type_protege_male_with_name' => ':name’s protégé',
 
     'relationship_type_ex_husband' => 'ex-spouse',
     'relationship_type_ex_husband_female' => 'πρώην σύζυγος',
