@@ -12,5 +12,5 @@ return [
     'type_lunch' => 'Γεύμα με',
     'type_hangout' => 'Βρέθηκα με',
     'type_email' => 'Email',
-    'type_birthday_kid' => 'Wish happy birthday to the child of',
+    'type_birthday_kid' => 'Ευχηθείτε χαρούμενα γενέθλια στο παιδί του',
 ];
