@@ -140,8 +140,10 @@ return [
 
     'relationship_type_partner' => 'pareja',
     'relationship_type_partner_female' => 'pareja',
+    'relationship_type_partner_male' => 'significant other',
     'relationship_type_partner_with_name' => 'la pareja de :name',
     'relationship_type_partner_female_with_name' => 'la pareja de :name',
+    'relationship_type_partner_male_with_name' => ':name’s significant other',
 
     'relationship_type_spouse' => 'esposa',
     'relationship_type_spouse_female' => 'esposa',
@@ -152,23 +154,31 @@ return [
 
     'relationship_type_date' => 'cita',
     'relationship_type_date_female' => 'cita',
+    'relationship_type_date_male' => 'date',
     'relationship_type_date_with_name' => 'la cita de :name',
     'relationship_type_date_female_with_name' => 'la cita de :name',
+    'relationship_type_date_male_with_name' => ':name’s date',
 
     'relationship_type_lover' => 'amante',
     'relationship_type_lover_female' => 'amante',
+    'relationship_type_lover_male' => 'lover',
     'relationship_type_lover_with_name' => 'el amante de :name',
     'relationship_type_lover_female_with_name' => 'la amante de :name',
+    'relationship_type_lover_male_with_name' => ':name’s lover',
 
     'relationship_type_inlovewith' => 'enamorado de',
     'relationship_type_inlovewith_female' => 'enamorada de',
+    'relationship_type_inlovewith_male' => 'enamorado de',
     'relationship_type_inlovewith_with_name' => 'alguien :name está enamorado de',
     'relationship_type_inlovewith_female_with_name' => 'alguien :name está enamorado de',
+    'relationship_type_inlovewith_male_with_name' => 'someone :name is in love with',
 
     'relationship_type_lovedby' => 'querido por',
     'relationship_type_lovedby_female' => 'querido por',
+    'relationship_type_lovedby_male' => 'loved by',
     'relationship_type_lovedby_with_name' => 'amante secreto de :name',
     'relationship_type_lovedby_female_with_name' => 'amante secreto de :name',
+    'relationship_type_lovedby_male_with_name' => ':name’s secret lover',
 
     'relationship_type_ex' => 'ex-pareja',
     'relationship_type_ex_female' => 'ex-novia',
@@ -228,18 +238,24 @@ return [
 
     'relationship_type_uncle' => 'tío',
     'relationship_type_uncle_female' => 'tía',
+    'relationship_type_uncle_male' => 'uncle',
     'relationship_type_uncle_with_name' => 'tío de :name',
     'relationship_type_uncle_female_with_name' => 'tía de :name',
+    'relationship_type_uncle_male_with_name' => ':name’s uncle',
 
     'relationship_type_nephew' => 'sobrino',
     'relationship_type_nephew_female' => 'sobrina',
+    'relationship_type_nephew_male' => 'sobrino',
     'relationship_type_nephew_with_name' => 'sobrino de :name',
     'relationship_type_nephew_female_with_name' => 'sobrina de :name',
+    'relationship_type_nephew_male_with_name' => ':name’s nephew',
 
     'relationship_type_cousin' => 'primo/a',
     'relationship_type_cousin_female' => 'prima',
+    'relationship_type_cousin_male' => 'primo/a',
     'relationship_type_cousin_with_name' => 'primo de :name',
     'relationship_type_cousin_female_with_name' => 'prima de :name',
+    'relationship_type_cousin_male_with_name' => ':name’s cousin',
 
     'relationship_type_godfather' => 'abuelo/a',
     'relationship_type_godfather_female' => 'madrina',
@@ -257,38 +273,52 @@ return [
 
     'relationship_type_friend' => 'amigo',
     'relationship_type_friend_female' => 'amigo',
+    'relationship_type_friend_male' => 'amigo',
     'relationship_type_friend_with_name' => 'amigo de :name',
     'relationship_type_friend_female_with_name' => 'amiga de :name',
+    'relationship_type_friend_male_with_name' => ':name’s friend',
 
     'relationship_type_bestfriend' => 'mejor amigo',
     'relationship_type_bestfriend_female' => 'mejor amiga',
+    'relationship_type_bestfriend_male' => 'mejor amigo',
     'relationship_type_bestfriend_with_name' => 'mejor amigo de :name',
     'relationship_type_bestfriend_female_with_name' => 'mejor amiga de :name',
+    'relationship_type_bestfriend_male_with_name' => ':name’s best friend',
 
     'relationship_type_colleague' => 'colega',
     'relationship_type_colleague_female' => 'colega',
+    'relationship_type_colleague_male' => 'colleague',
     'relationship_type_colleague_with_name' => 'colega de :name',
     'relationship_type_colleague_female_with_name' => 'colega de :name',
+    'relationship_type_colleague_male_with_name' => ':name’s colleague',
 
     'relationship_type_boss' => 'jefe',
     'relationship_type_boss_female' => 'jefa',
+    'relationship_type_boss_male' => 'jefe',
     'relationship_type_boss_with_name' => 'jefe de :name',
     'relationship_type_boss_female_with_name' => 'jefe de :name',
+    'relationship_type_boss_male_with_name' => ':name’s boss',
 
     'relationship_type_subordinate' => 'subordinado',
     'relationship_type_subordinate_female' => 'subordinada',
+    'relationship_type_subordinate_male' => 'subordinado',
     'relationship_type_subordinate_with_name' => 'subordinado de :name',
     'relationship_type_subordinate_female_with_name' => 'subordinada de :name',
+    'relationship_type_subordinate_male_with_name' => ':name’s subordinate',
 
     'relationship_type_mentor' => 'mentor',
     'relationship_type_mentor_female' => 'mentora',
+    'relationship_type_mentor_male' => 'mentor',
     'relationship_type_mentor_with_name' => 'mentor de :name',
     'relationship_type_mentor_female_with_name' => 'mentora de :name',
+    'relationship_type_mentor_male_with_name' => ':name’s mentor',
 
-    'relationship_type_protege' => 'protégé',
-    'relationship_type_protege_female' => 'protégé',
-    'relationship_type_protege_with_name' => ':name’s protégé',
-    'relationship_type_protege_female_with_name' => ':name’s protégé',
+    'relationship_type_protege' => 'protegido',
+    'relationship_type_protege_female' => 'protegida',
+    'relationship_type_protege_male' => 'protégé',
+    'relationship_type_protege_with_name' => 'protegido de :name',
+    'relationship_type_protege_female_with_name' => 'protegida de :name',
+    'relationship_type_protege_male_with_name' => ':name’s protégé',
 
     'relationship_type_ex_husband' => 'ex esposa',
     'relationship_type_ex_husband_female' => 'ex esposa',
@@ -308,24 +338,24 @@ return [
     'emotion_secondary_affection' => 'Afecto',
     'emotion_secondary_lust' => 'Lujuria',
     'emotion_secondary_longing' => 'Nostalgia',
-    'emotion_secondary_cheerfulness' => 'Cheerfulness',
-    'emotion_secondary_zest' => 'Zest',
-    'emotion_secondary_contentment' => 'Contentment',
+    'emotion_secondary_cheerfulness' => 'Jovialidad',
+    'emotion_secondary_zest' => 'Ánimo',
+    'emotion_secondary_contentment' => 'Contentamiento',
     'emotion_secondary_pride' => 'Orgullo',
     'emotion_secondary_optimism' => 'Optimismo',
-    'emotion_secondary_enthrallment' => 'Enthrallment',
+    'emotion_secondary_enthrallment' => 'Fascinación',
     'emotion_secondary_relief' => 'Alivio',
     'emotion_secondary_surprise' => 'Sorpresa',
     'emotion_secondary_irritation' => 'Irritación',
     'emotion_secondary_exasperation' => 'Exasperación',
     'emotion_secondary_rage' => 'Ira',
-    'emotion_secondary_disgust' => 'Disgust',
+    'emotion_secondary_disgust' => 'Asco',
     'emotion_secondary_envy' => 'Envidia',
     'emotion_secondary_suffering' => 'Sufriendo',
     'emotion_secondary_sadness' => 'Tristeza',
     'emotion_secondary_disappointment' => 'Decepción',
     'emotion_secondary_shame' => 'Vergüenza',
-    'emotion_secondary_neglect' => 'Neglect',
+    'emotion_secondary_neglect' => 'Desatendido',
     'emotion_secondary_sympathy' => 'Simpatía',
     'emotion_secondary_horror' => 'Horror',
     'emotion_secondary_nervousness' => 'Nerviosismo',
@@ -333,26 +363,26 @@ return [
     'emotion_adoration' => 'Adoración',
     'emotion_affection' => 'Afecto',
     'emotion_love' => 'Amor',
-    'emotion_fondness' => 'Fondness',
-    'emotion_liking' => 'Liking',
+    'emotion_fondness' => 'Cariño',
+    'emotion_liking' => 'Gusto',
     'emotion_attraction' => 'Atracción',
-    'emotion_caring' => 'Caring',
-    'emotion_tenderness' => 'Tenderness',
+    'emotion_caring' => 'Cariñoso',
+    'emotion_tenderness' => 'Ternura',
     'emotion_compassion' => 'Compasión',
     'emotion_sentimentality' => 'Sentimentalidad',
-    'emotion_arousal' => 'Arousal',
+    'emotion_arousal' => 'Excitación',
     'emotion_desire' => 'Deseo',
     'emotion_lust' => 'Lujuria',
     'emotion_passion' => 'Pasión',
-    'emotion_infatuation' => 'Infatuation',
+    'emotion_infatuation' => 'Infatuación',
     'emotion_longing' => 'Nostalgia',
-    'emotion_amusement' => 'Amusement',
-    'emotion_bliss' => 'Bliss',
-    'emotion_cheerfulness' => 'Cheerfulness',
-    'emotion_gaiety' => 'Gaiety',
-    'emotion_glee' => 'Glee',
-    'emotion_jolliness' => 'Jolliness',
-    'emotion_joviality' => 'Joviality',
+    'emotion_amusement' => 'Diversión',
+    'emotion_bliss' => 'Dicha',
+    'emotion_cheerfulness' => 'Jovialidad',
+    'emotion_gaiety' => 'Regocijo',
+    'emotion_glee' => 'Júbilo',
+    'emotion_jolliness' => 'Felicidad',
+    'emotion_joviality' => 'Jovialidad',
     'emotion_joy' => 'Alegría',
     'emotion_delight' => 'Deleite',
     'emotion_enjoyment' => 'Disfrute',
@@ -404,52 +434,52 @@ return [
     'emotion_vengefulness' => 'Venganza',
     'emotion_dislike' => 'Desagrado',
     'emotion_resentment' => 'Resentimiento',
-    'emotion_disgust' => 'Disgust',
-    'emotion_revulsion' => 'Revulsion',
-    'emotion_contempt' => 'Contempt',
+    'emotion_disgust' => 'Asco',
+    'emotion_revulsion' => 'Repugnancia',
+    'emotion_contempt' => 'Desprecio',
     'emotion_envy' => 'Envidia',
     'emotion_jealousy' => 'Celoso',
-    'emotion_agony' => 'Agony',
-    'emotion_suffering' => 'Suffering',
-    'emotion_hurt' => 'Hurt',
-    'emotion_anguish' => 'Anguish',
-    'emotion_depression' => 'Depression',
-    'emotion_despair' => 'Despair',
-    'emotion_hopelessness' => 'Hopelessness',
-    'emotion_gloom' => 'Gloom',
-    'emotion_glumness' => 'Glumness',
+    'emotion_agony' => 'Agonía',
+    'emotion_suffering' => 'Sufrimiento',
+    'emotion_hurt' => 'Dolor',
+    'emotion_anguish' => 'Angustia',
+    'emotion_depression' => 'Depresión',
+    'emotion_despair' => 'Desesperanza',
+    'emotion_hopelessness' => 'Desesperanza',
+    'emotion_gloom' => 'Tristeza',
+    'emotion_glumness' => 'Melancolía',
     'emotion_sadness' => 'Tristeza',
-    'emotion_unhappiness' => 'Unhappiness',
-    'emotion_grief' => 'Grief',
-    'emotion_sorrow' => 'Sorrow',
-    'emotion_woe' => 'Woe',
-    'emotion_misery' => 'Misery',
-    'emotion_melancholy' => 'Melancholy',
-    'emotion_dismay' => 'Dismay',
-    'emotion_disappointment' => 'Disappointment',
-    'emotion_displeasure' => 'Displeasure',
-    'emotion_guilt' => 'Guilt',
+    'emotion_unhappiness' => 'Infelicidad',
+    'emotion_grief' => 'Duelo',
+    'emotion_sorrow' => 'Pesar',
+    'emotion_woe' => 'Aflicción',
+    'emotion_misery' => 'Miseria',
+    'emotion_melancholy' => 'Melancolía',
+    'emotion_dismay' => 'Consternación',
+    'emotion_disappointment' => 'Decepción',
+    'emotion_displeasure' => 'Disgusto',
+    'emotion_guilt' => 'Culpa',
     'emotion_shame' => 'Vergüenza',
     'emotion_regret' => 'Arrepentimiento',
     'emotion_remorse' => 'Remordimiento',
     'emotion_alienation' => 'Alienación',
     'emotion_isolation' => 'Aislamiento',
-    'emotion_neglect' => 'Neglect',
-    'emotion_loneliness' => 'Loneliness',
-    'emotion_rejection' => 'Rejection',
-    'emotion_homesickness' => 'Homesickness',
-    'emotion_defeat' => 'Defeat',
-    'emotion_dejection' => 'Dejection',
+    'emotion_neglect' => 'Desatendido',
+    'emotion_loneliness' => 'Soledad',
+    'emotion_rejection' => 'Rechazo',
+    'emotion_homesickness' => 'Nostalgia',
+    'emotion_defeat' => 'Derrota',
+    'emotion_dejection' => 'Abatimiento',
     'emotion_insecurity' => 'Inseguridad',
     'emotion_embarrassment' => 'Avergonzado',
-    'emotion_humiliation' => 'Humiliation',
+    'emotion_humiliation' => 'Humillación',
     'emotion_insult' => 'Insultado',
-    'emotion_pity' => 'Pity',
+    'emotion_pity' => 'Lástima',
     'emotion_sympathy' => 'Simpatía',
     'emotion_alarm' => 'Alarmado',
     'emotion_shock' => 'Conmoción',
     'emotion_fear' => 'Miedo',
-    'emotion_fright' => 'Fright',
+    'emotion_fright' => 'Susto',
     'emotion_horror' => 'Horror',
     'emotion_terror' => 'Terror',
     'emotion_panic' => 'Pánico',
@@ -478,49 +508,49 @@ return [
     'weather_patchy-rain-possible' => 'Posible lluvia irregular',
     'weather_heavy-rain-at-times' => 'Lluvia fuerte ocasional',
     'weather_heavy-rain' => 'Lluvia fuerte',
-    'weather_light-freezing-rain' => 'Light freezing rain',
-    'weather_moderate-or-heavy-freezing-rain' => 'Moderate or heavy freezing rain',
-    'weather_light-sleet' => 'Light sleet',
-    'weather_moderate-or-heavy-rain-shower' => 'Moderate or heavy rain shower',
-    'weather_light-rain-shower' => 'Light rain shower',
-    'weather_torrential-rain-shower' => 'Torrential rain shower',
+    'weather_light-freezing-rain' => 'Lluvia leve helada',
+    'weather_moderate-or-heavy-freezing-rain' => 'Lluvia gélida moderada o fuerte',
+    'weather_light-sleet' => 'Aguanieve leve',
+    'weather_moderate-or-heavy-rain-shower' => 'Chubascos de lluvia moderados o fuertes',
+    'weather_light-rain-shower' => 'Llovizna leve',
+    'weather_torrential-rain-shower' => 'Lluvias torrenciales',
     'weather_rain' => 'Lluvia',
     'weather_snow' => 'Nieve',
-    'weather_blowing-snow' => 'Blowing snow',
-    'weather_patchy-light-snow' => 'Patchy light snow',
-    'weather_light-snow' => 'Light snow',
-    'weather_patchy-moderate-snow' => 'Patchy moderate snow',
-    'weather_moderate-snow' => 'Moderate snow',
-    'weather_patchy-heavy-snow' => 'Patchy heavy snow',
-    'weather_heavy-snow' => 'Heavy snow',
-    'weather_light-snow-showers' => 'Light snow showers',
-    'weather_moderate-or-heavy-snow-showers' => 'Moderate or heavy snow showers',
-    'weather_patchy-snow-possible' => 'Patchy snow possible',
-    'weather_patchy-sleet-possible' => 'Patchy sleet possible',
-    'weather_moderate-or-heavy-sleet' => 'Moderate or heavy sleet',
-    'weather_light-sleet-showers' => 'Light sleet showers',
-    'weather_moderate-or-heavy-sleet-showers' => 'Moderate or heavy sleet showers',
+    'weather_blowing-snow' => 'Ventisca',
+    'weather_patchy-light-snow' => 'Nevada leve irregular',
+    'weather_light-snow' => 'Leve nevada',
+    'weather_patchy-moderate-snow' => 'Nevada irregular moderada',
+    'weather_moderate-snow' => 'Nevada moderada',
+    'weather_patchy-heavy-snow' => 'Nevada irregular fuerte',
+    'weather_heavy-snow' => 'Fuertes nevadas',
+    'weather_light-snow-showers' => 'Chubascos débiles de nieve',
+    'weather_moderate-or-heavy-snow-showers' => 'Nevadas moderadas o pesadas',
+    'weather_patchy-snow-possible' => 'Posible nevada irregular',
+    'weather_patchy-sleet-possible' => 'Posible aguanieve irregular',
+    'weather_moderate-or-heavy-sleet' => 'Aguanieve moderada o fuerte',
+    'weather_light-sleet-showers' => 'Aguanieve leve',
+    'weather_moderate-or-heavy-sleet-showers' => 'Chubascos de aguanieve moderados o fuertes',
     'weather_sleet' => 'Aguanieve',
     'weather_wind' => 'Viento',
     'weather_fog' => 'Niebla',
-    'weather_freezing-fog' => 'Freezing fog',
-    'weather_mist' => 'Mist',
-    'weather_blizzard' => 'Blizzard',
-    'weather_overcast' => 'Overcast',
+    'weather_freezing-fog' => 'Niebla gélida',
+    'weather_mist' => 'Neblina',
+    'weather_blizzard' => 'Ventisca',
+    'weather_overcast' => 'Nublado',
     'weather_cloudy' => 'Nublado',
     'weather_partly-cloudy-day' => 'Parcialmente nublado',
     'weather_partly-cloudy-night' => 'Parcialmente nublado',
-    'weather_freezing-drizzle' => 'Freezing drizzle',
-    'weather_heavy-freezing-drizzle' => 'Heavy freezing drizzle',
-    'weather_patchy-freezing-drizzle-possible' => 'Patchy freezing drizzle possible',
+    'weather_freezing-drizzle' => 'Llovizna gélida',
+    'weather_heavy-freezing-drizzle' => 'Llovizna gélida fuerte',
+    'weather_patchy-freezing-drizzle-possible' => 'Posible llovizna gélida irregular',
     'weather_ice-pellets' => 'Granizo',
     'weather_light-showers-of-ice-pellets' => 'Granizada débil',
     'weather_moderate-or-heavy-showers-of-ice-pellets' => 'Granizada moderada o fuerte',
-    'weather_thundery-outbreaks-possible' => 'Thundery outbreaks possible',
-    'weather_patchy-light-rain-with-thunder' => 'Patchy light rain with thunder',
-    'weather_moderate-or-heavy-rain-with-thunder' => 'Moderate or heavy rain with thunder',
-    'weather_patchy-light-snow-with-thunder' => 'Patchy light snow with thunder',
-    'weather_moderate-or-heavy-snow-with-thunder' => 'Moderate or heavy snow with thunder',
+    'weather_thundery-outbreaks-possible' => 'Posibles brotes de trueno',
+    'weather_patchy-light-rain-with-thunder' => 'Lluvia débil irregular acompañada de truenos',
+    'weather_moderate-or-heavy-rain-with-thunder' => 'Lluvia moderada o fuerte acompañada de truenos',
+    'weather_patchy-light-snow-with-thunder' => 'Nevadas suaves acompañadas de truenos',
+    'weather_moderate-or-heavy-snow-with-thunder' => 'Nevadas moderadas o fuertes acompañadas de truenos',
     'weather_current_temperature_celsius' => ':temperatura ºC',
     'weather_current_temperature_fahrenheit' => ':temperatura ºF',
     'weather_current_title' => 'Clima actual',
