@@ -140,8 +140,10 @@ return [
 
     'relationship_type_partner' => 'conjoint',
     'relationship_type_partner_female' => 'conjointe',
+    'relationship_type_partner_male' => 'conjoint',
     'relationship_type_partner_with_name' => 'conjoint de :name',
     'relationship_type_partner_female_with_name' => 'conjointe de :name',
+    'relationship_type_partner_male_with_name' => 'conjoint de :name',
 
     'relationship_type_spouse' => 'épouse',
     'relationship_type_spouse_female' => 'femme',
@@ -152,23 +154,31 @@ return [
 
     'relationship_type_date' => 'rendez-vous',
     'relationship_type_date_female' => 'rendez-vous',
+    'relationship_type_date_male' => 'rendez-vous',
     'relationship_type_date_with_name' => 'rendez-vous de :name',
     'relationship_type_date_female_with_name' => 'rendez-vous de :name',
+    'relationship_type_date_male_with_name' => 'rendez-vous de :name',
 
     'relationship_type_lover' => 'amant',
     'relationship_type_lover_female' => 'amante',
+    'relationship_type_lover_male' => 'amant',
     'relationship_type_lover_with_name' => 'amant de :name',
     'relationship_type_lover_female_with_name' => 'amante de :name',
+    'relationship_type_lover_male_with_name' => 'amant de :name',
 
     'relationship_type_inlovewith' => 'amoureux',
     'relationship_type_inlovewith_female' => 'amoureuse',
+    'relationship_type_inlovewith_male' => 'amoureux',
     'relationship_type_inlovewith_with_name' => 'une personne dont :name est amoureux',
     'relationship_type_inlovewith_female_with_name' => 'une personne dont :name est amoureuse',
+    'relationship_type_inlovewith_male_with_name' => 'une personne dont :name est amoureux',
 
     'relationship_type_lovedby' => 'aimé par',
     'relationship_type_lovedby_female' => 'aimée par',
+    'relationship_type_lovedby_male' => 'aimé par',
     'relationship_type_lovedby_with_name' => 'amant secret de :name',
     'relationship_type_lovedby_female_with_name' => 'amante secrète de :name',
+    'relationship_type_lovedby_male_with_name' => 'amant secret de :name',
 
     'relationship_type_ex' => 'ex-partenaire',
     'relationship_type_ex_female' => 'ex-petite amie',
@@ -228,18 +238,24 @@ return [
 
     'relationship_type_uncle' => 'oncle',
     'relationship_type_uncle_female' => 'tante',
+    'relationship_type_uncle_male' => 'oncle',
     'relationship_type_uncle_with_name' => 'oncle de :name',
     'relationship_type_uncle_female_with_name' => 'tante de :name',
+    'relationship_type_uncle_male_with_name' => 'oncle de :name',
 
     'relationship_type_nephew' => 'neveu',
     'relationship_type_nephew_female' => 'nièce',
-    'relationship_type_nephew_with_name' => 'neuveu de :name',
+    'relationship_type_nephew_male' => 'neveu',
+    'relationship_type_nephew_with_name' => 'neveu de :name',
     'relationship_type_nephew_female_with_name' => 'nièce de :name',
+    'relationship_type_nephew_male_with_name' => 'neveu de :name',
 
     'relationship_type_cousin' => 'cousin',
     'relationship_type_cousin_female' => 'cousine',
+    'relationship_type_cousin_male' => 'cousin',
     'relationship_type_cousin_with_name' => 'cousin de :name',
     'relationship_type_cousin_female_with_name' => 'cousine de :name',
+    'relationship_type_cousin_male_with_name' => 'cousin de :name',
 
     'relationship_type_godfather' => 'parrain ou marraine',
     'relationship_type_godfather_female' => 'marraine',
@@ -257,38 +273,52 @@ return [
 
     'relationship_type_friend' => 'ami',
     'relationship_type_friend_female' => 'amie',
+    'relationship_type_friend_male' => 'ami',
     'relationship_type_friend_with_name' => 'ami de :name',
     'relationship_type_friend_female_with_name' => 'amie de :name',
+    'relationship_type_friend_male_with_name' => 'ami de :name',
 
     'relationship_type_bestfriend' => 'meilleur ami',
     'relationship_type_bestfriend_female' => 'meilleure amie',
+    'relationship_type_bestfriend_male' => 'meilleur ami',
     'relationship_type_bestfriend_with_name' => 'meilleur ami de :name',
     'relationship_type_bestfriend_female_with_name' => 'meilleure amie de :name',
+    'relationship_type_bestfriend_male_with_name' => 'meilleur ami de :name',
 
     'relationship_type_colleague' => 'collègue',
     'relationship_type_colleague_female' => 'collègue',
+    'relationship_type_colleague_male' => 'collègue',
     'relationship_type_colleague_with_name' => 'collègue de :name',
     'relationship_type_colleague_female_with_name' => 'collègue de :name',
+    'relationship_type_colleague_male_with_name' => 'collègue de :name',
 
     'relationship_type_boss' => 'patron',
     'relationship_type_boss_female' => 'patronne',
+    'relationship_type_boss_male' => 'patron',
     'relationship_type_boss_with_name' => 'patron de :name',
     'relationship_type_boss_female_with_name' => 'patronne de :name',
+    'relationship_type_boss_male_with_name' => 'patron de :name',
 
     'relationship_type_subordinate' => 'employé',
     'relationship_type_subordinate_female' => 'employée',
+    'relationship_type_subordinate_male' => 'employé',
     'relationship_type_subordinate_with_name' => 'employé de :name',
     'relationship_type_subordinate_female_with_name' => 'employée de :name',
+    'relationship_type_subordinate_male_with_name' => 'employé de :name',
 
     'relationship_type_mentor' => 'mentor',
     'relationship_type_mentor_female' => 'mentore',
+    'relationship_type_mentor_male' => 'mentor',
     'relationship_type_mentor_with_name' => 'mentor de :name',
     'relationship_type_mentor_female_with_name' => 'mentore de :name',
+    'relationship_type_mentor_male_with_name' => 'mentor de :name',
 
     'relationship_type_protege' => 'protégé',
     'relationship_type_protege_female' => 'protégée',
+    'relationship_type_protege_male' => 'protégé',
     'relationship_type_protege_with_name' => 'protégé de :name',
     'relationship_type_protege_female_with_name' => 'protégée de :name',
+    'relationship_type_protege_male_with_name' => 'protégé de :name',
 
     'relationship_type_ex_husband' => 'ex-épouse',
     'relationship_type_ex_husband_female' => 'ex-femme',
@@ -495,8 +525,8 @@ return [
     'weather_heavy-snow' => 'Forte neige',
     'weather_light-snow-showers' => 'Légères averses de neige',
     'weather_moderate-or-heavy-snow-showers' => 'Averses de neige modérées a fortes',
-    'weather_patchy-snow-possible' => 'Pluie éparse possible',
-    'weather_patchy-sleet-possible' => 'Pluie éparse possible',
+    'weather_patchy-snow-possible' => 'Neige éparse possible',
+    'weather_patchy-sleet-possible' => 'Neige fondue éparse possible',
     'weather_moderate-or-heavy-sleet' => 'Neige modérée ou forte',
     'weather_light-sleet-showers' => 'Légeres averses de neige fondue',
     'weather_moderate-or-heavy-sleet-showers' => 'Averses de neige fondue modérées a fortes',
@@ -513,14 +543,14 @@ return [
     'weather_freezing-drizzle' => 'Bruine verglaçante',
     'weather_heavy-freezing-drizzle' => 'Forte bruine verglaçante',
     'weather_patchy-freezing-drizzle-possible' => 'Bruine verglaçante par endroit',
-    'weather_ice-pellets' => 'Granules de glace',
+    'weather_ice-pellets' => 'Grêle',
     'weather_light-showers-of-ice-pellets' => 'Averses éparses de grêle',
     'weather_moderate-or-heavy-showers-of-ice-pellets' => 'Averses modérées ou fortes de grêle',
     'weather_thundery-outbreaks-possible' => 'Orages possibles',
     'weather_patchy-light-rain-with-thunder' => 'Pluie légère éparse avec tonnerre',
     'weather_moderate-or-heavy-rain-with-thunder' => 'Pluie modérée ou forte avec tonnerre',
     'weather_patchy-light-snow-with-thunder' => 'Pluie légère éparse avec tonnerre',
-    'weather_moderate-or-heavy-snow-with-thunder' => 'Neige éparse modérée à forte avec tonnerre par endroit',
+    'weather_moderate-or-heavy-snow-with-thunder' => 'Neige modérée ou forte avec tonnerre',
     'weather_current_temperature_celsius' => ':temperature °C',
     'weather_current_temperature_fahrenheit' => ':temperature °F',
     'weather_current_title' => 'Météo actuelle',
