@@ -22,7 +22,7 @@ return [
     'reset' => 'Votre mot de passe a été réinitialisé !',
     'sent' => 'Nous vous avons envoyé par courriel le lien de réinitialisation du mot de passe.',
     'token' => 'Ce jeton de réinitialisation du mot de passe n’est pas valide.',
-    'user' => 'Si l’email que vous avez entré correspond chez nous, un email de réinitialisation du mot de passe vous a été envoyé.',
+    'user' => 'Si l’adresse email que vous avez entrée existe dans notre base de données, un couriel de réinitialisation du mot de passe vous a été envoyé.',
     'changed' => 'Mot de passe changé avec succès.',
     'invalid' => 'Le mot de passe que vous avez saisi est incorrect.',
     'throttled' => 'Merci de patienter avant de réessayer.',
