@@ -42,7 +42,7 @@ return [
     'export_title_json' => 'ייצוא ל־Json',
     'export_submitted' => 'הייצוא שלך הוגש, הוא יהיה זמין בעוד מספר רגעים…',
     'export_json_explanation' => 'הנתונים שלך מיוצאים בתצורת Json למטרות גיבוי.',
-    'export_json_beta' => 'Json export is in preview mode. Tell us what you think about it:',
+    'export_json_beta' => 'ייצוא Json הוא במצב תצוגה מקדימה. נא לספר לנו מה דעתך עליו:',
     'export_json_cta' => 'ייצוא ל־Json',
     'export_header_type' => 'סוג',
     'export_header_timestamp' => 'מועד יצירה',
@@ -331,6 +331,7 @@ return [
     'tags_list_description' => 'ניתן לארגן את אנשי הקשר שלך על ידי הגדרת תגיות. תגיות עובדות כמו תיקיות אך יש לך אפשרות להוסיף יותר מתגית אחת לאיש קשר. כדי להוסיף תגית חדשה, ניתן להוסיף אותה על איש הקשר עצמו.',
     'tags_list_contact_number' => 'איש קשר אחד|:count אנשי קשר',
     'tags_list_delete_success' => 'התגית נמחקה בהצלחה',
+    'tags_list_edit_success' => 'The tag has been successfully updated',
     'tags_list_delete_confirmation' => 'למחוק את התגית? לא יימחקו אנשי קשר, רק התגית.',
     'tags_blank_title' => 'תגיות הן דרך נהדרת לארגון אנשי הקשר שלך.',
     'tags_blank_description' => 'תגיות עובדות כמו תיקיות, אך ניתן להוסיף יותר מתגית אחת לאיש קשר. יש לגשת לאיש קשר ולתייג כחבר, מיד מתחת לשם. לאחר תיוג איש קשר, ניתן לחזור לכאן כדי לנהל את כל התגיות בחשבון שלך.',
