@@ -140,8 +140,10 @@ return [
 
     'relationship_type_partner' => 'orang yang berarti',
     'relationship_type_partner_female' => 'orang yang berarti',
+    'relationship_type_partner_male' => 'significant other',
     'relationship_type_partner_with_name' => ':name orang yang berarti lainnya',
     'relationship_type_partner_female_with_name' => ':name orang yang berarti lainnya',
+    'relationship_type_partner_male_with_name' => ':name’s significant other',
 
     'relationship_type_spouse' => 'pasangan',
     'relationship_type_spouse_female' => 'wife',
@@ -152,23 +154,31 @@ return [
 
     'relationship_type_date' => 'tanggal',
     'relationship_type_date_female' => 'tanggal',
+    'relationship_type_date_male' => 'date',
     'relationship_type_date_with_name' => 'Tanggal :name',
     'relationship_type_date_female_with_name' => 'Tanggal :name',
+    'relationship_type_date_male_with_name' => ':name’s date',
 
     'relationship_type_lover' => 'kekasih',
     'relationship_type_lover_female' => 'kekasih',
+    'relationship_type_lover_male' => 'lover',
     'relationship_type_lover_with_name' => 'kekasih :name',
     'relationship_type_lover_female_with_name' => 'kekasih :name',
+    'relationship_type_lover_male_with_name' => ':name’s lover',
 
     'relationship_type_inlovewith' => 'jatuh cinta dengan',
     'relationship_type_inlovewith_female' => 'jatuh cinta dengan',
+    'relationship_type_inlovewith_male' => 'in love with',
     'relationship_type_inlovewith_with_name' => 'seseorang :name jatuh cinta dengan',
     'relationship_type_inlovewith_female_with_name' => 'seseorang :name jatuh cinta dengan',
+    'relationship_type_inlovewith_male_with_name' => 'someone :name is in love with',
 
     'relationship_type_lovedby' => 'dicintai oleh',
     'relationship_type_lovedby_female' => 'dicintai oleh',
+    'relationship_type_lovedby_male' => 'loved by',
     'relationship_type_lovedby_with_name' => 'Kekasih rahasia :name',
     'relationship_type_lovedby_female_with_name' => 'Kekasih rahasia :name',
+    'relationship_type_lovedby_male_with_name' => ':name’s secret lover',
 
     'relationship_type_ex' => 'ex-partner',
     'relationship_type_ex_female' => 'mantan pacar',
@@ -228,18 +238,24 @@ return [
 
     'relationship_type_uncle' => 'paman',
     'relationship_type_uncle_female' => 'bibi',
+    'relationship_type_uncle_male' => 'uncle',
     'relationship_type_uncle_with_name' => 'Paman :name',
     'relationship_type_uncle_female_with_name' => 'Bibi :name',
+    'relationship_type_uncle_male_with_name' => ':name’s uncle',
 
     'relationship_type_nephew' => 'keponakan',
     'relationship_type_nephew_female' => 'ponakan',
+    'relationship_type_nephew_male' => 'nephew',
     'relationship_type_nephew_with_name' => 'Keponakan :name',
     'relationship_type_nephew_female_with_name' => 'Ponakan :name',
+    'relationship_type_nephew_male_with_name' => ':name’s nephew',
 
     'relationship_type_cousin' => 'saudara',
     'relationship_type_cousin_female' => 'saudara',
+    'relationship_type_cousin_male' => 'cousin',
     'relationship_type_cousin_with_name' => 'saudara :name',
     'relationship_type_cousin_female_with_name' => 'saudara :name',
+    'relationship_type_cousin_male_with_name' => ':name’s cousin',
 
     'relationship_type_godfather' => 'godparent',
     'relationship_type_godfather_female' => 'wali perempuan',
@@ -257,38 +273,52 @@ return [
 
     'relationship_type_friend' => 'teman',
     'relationship_type_friend_female' => 'teman',
+    'relationship_type_friend_male' => 'friend',
     'relationship_type_friend_with_name' => 'Teman :name',
     'relationship_type_friend_female_with_name' => 'Teman :name',
+    'relationship_type_friend_male_with_name' => ':name’s friend',
 
     'relationship_type_bestfriend' => 'teman akrab',
     'relationship_type_bestfriend_female' => 'teman akrab',
+    'relationship_type_bestfriend_male' => 'best friend',
     'relationship_type_bestfriend_with_name' => 'Sahabat :name',
     'relationship_type_bestfriend_female_with_name' => 'Sahabat :name',
+    'relationship_type_bestfriend_male_with_name' => ':name’s best friend',
 
     'relationship_type_colleague' => 'kolega',
     'relationship_type_colleague_female' => 'kolega',
+    'relationship_type_colleague_male' => 'colleague',
     'relationship_type_colleague_with_name' => 'Kolega :name',
     'relationship_type_colleague_female_with_name' => 'Kolega :name',
+    'relationship_type_colleague_male_with_name' => ':name’s colleague',
 
     'relationship_type_boss' => 'bos',
     'relationship_type_boss_female' => 'bos',
+    'relationship_type_boss_male' => 'boss',
     'relationship_type_boss_with_name' => 'bos :name',
     'relationship_type_boss_female_with_name' => 'bos :name',
+    'relationship_type_boss_male_with_name' => ':name’s boss',
 
     'relationship_type_subordinate' => 'bawahan',
     'relationship_type_subordinate_female' => 'bawahan',
+    'relationship_type_subordinate_male' => 'subordinate',
     'relationship_type_subordinate_with_name' => 'bawahan :name',
     'relationship_type_subordinate_female_with_name' => 'bawahan :name',
+    'relationship_type_subordinate_male_with_name' => ':name’s subordinate',
 
     'relationship_type_mentor' => 'pelatih',
     'relationship_type_mentor_female' => 'pelatih',
+    'relationship_type_mentor_male' => 'mentor',
     'relationship_type_mentor_with_name' => 'Pelatih :name',
     'relationship_type_mentor_female_with_name' => 'Pelatih :name',
+    'relationship_type_mentor_male_with_name' => ':name’s mentor',
 
     'relationship_type_protege' => 'protégé',
     'relationship_type_protege_female' => 'protégé',
+    'relationship_type_protege_male' => 'protégé',
     'relationship_type_protege_with_name' => ':name’s protégé',
     'relationship_type_protege_female_with_name' => ':name’s protégé',
+    'relationship_type_protege_male_with_name' => ':name’s protégé',
 
     'relationship_type_ex_husband' => 'ex-spouse',
     'relationship_type_ex_husband_female' => 'mantan istri',
