@@ -140,162 +140,192 @@ return [
 
     'relationship_type_partner' => 'partner',
     'relationship_type_partner_female' => 'partner',
+    'relationship_type_partner_male' => 'partner',
     'relationship_type_partner_with_name' => 'partner di :name',
     'relationship_type_partner_female_with_name' => 'partner di :name',
+    'relationship_type_partner_male_with_name' => 'partner di :name',
 
     'relationship_type_spouse' => 'marito',
-    'relationship_type_spouse_female' => 'wife',
-    'relationship_type_spouse_male' => 'husband',
+    'relationship_type_spouse_female' => 'moglie',
+    'relationship_type_spouse_male' => 'marito',
     'relationship_type_spouse_with_name' => 'marito di :name',
-    'relationship_type_spouse_female_with_name' => ':name’s wife',
-    'relationship_type_spouse_male_with_name' => ':name’s husband',
+    'relationship_type_spouse_female_with_name' => 'Moglie di :name',
+    'relationship_type_spouse_male_with_name' => 'Marito di :name',
 
     'relationship_type_date' => 'impegnato',
     'relationship_type_date_female' => 'impegnata',
+    'relationship_type_date_male' => 'data',
     'relationship_type_date_with_name' => 'impegnato con :name',
     'relationship_type_date_female_with_name' => 'impegnata con :name',
+    'relationship_type_date_male_with_name' => 'ragazzo di :name',
 
     'relationship_type_lover' => 'amante',
     'relationship_type_lover_female' => 'amante',
+    'relationship_type_lover_male' => 'amante',
     'relationship_type_lover_with_name' => ': nome amante',
     'relationship_type_lover_female_with_name' => ': nome amante',
+    'relationship_type_lover_male_with_name' => 'amante di :name',
 
     'relationship_type_inlovewith' => 'innamorati di',
     'relationship_type_inlovewith_female' => 'innamorati di',
+    'relationship_type_inlovewith_male' => 'innamorato di',
     'relationship_type_inlovewith_with_name' => 'qualcuno: è innamorato di',
     'relationship_type_inlovewith_female_with_name' => 'qualcuno di cui :name è innamorata',
+    'relationship_type_inlovewith_male_with_name' => 'qualcuno di cui :name è innamorato',
 
     'relationship_type_lovedby' => 'amato da',
     'relationship_type_lovedby_female' => 'amata da',
+    'relationship_type_lovedby_male' => 'amato da',
     'relationship_type_lovedby_with_name' => 'amante segreto di :name',
     'relationship_type_lovedby_female_with_name' => 'amante segreto di :name',
+    'relationship_type_lovedby_male_with_name' => 'amante segreto di :name',
 
-    'relationship_type_ex' => 'ex-partner',
+    'relationship_type_ex' => 'ex compagno/a',
     'relationship_type_ex_female' => 'ex-fidanzata',
-    'relationship_type_ex_male' => 'ex-boyfriend',
-    'relationship_type_ex_with_name' => ':name’s ex-partner',
+    'relationship_type_ex_male' => 'ex-fidanzato',
+    'relationship_type_ex_with_name' => 'Ex compagno/a di :name',
     'relationship_type_ex_female_with_name' => 'ex-fidanzata di :name',
-    'relationship_type_ex_male_with_name' => ':name’s ex-boyfriend',
+    'relationship_type_ex_male_with_name' => 'Ex fidanzato di :name',
 
-    'relationship_type_parent' => 'parent',
+    'relationship_type_parent' => 'genitore',
     'relationship_type_parent_female' => 'madre',
-    'relationship_type_parent_male' => 'father',
-    'relationship_type_parent_with_name' => ':name’s parent',
+    'relationship_type_parent_male' => 'padre',
+    'relationship_type_parent_with_name' => 'Genitore di :name',
     'relationship_type_parent_female_with_name' => 'madre di :name',
-    'relationship_type_parent_male_with_name' => ':name’s father',
+    'relationship_type_parent_male_with_name' => 'Padre di :name',
 
-    'relationship_type_child' => 'child',
+    'relationship_type_child' => 'bambino/a',
     'relationship_type_child_female' => 'figlia',
-    'relationship_type_child_male' => 'son',
-    'relationship_type_child_with_name' => ':name’s child',
+    'relationship_type_child_male' => 'figlio',
+    'relationship_type_child_with_name' => 'Bambino/a di :name',
     'relationship_type_child_female_with_name' => 'figlia di :name',
-    'relationship_type_child_male_with_name' => ':name’s son',
+    'relationship_type_child_male_with_name' => 'Figlio di :name',
 
-    'relationship_type_stepparent' => 'step-parent',
+    'relationship_type_stepparent' => 'genitore adottivo',
     'relationship_type_stepparent_female' => 'madrigna',
-    'relationship_type_stepparent_male' => 'stepfather',
-    'relationship_type_stepparent_with_name' => ':name’s step-parent',
+    'relationship_type_stepparent_male' => 'padre adottivo',
+    'relationship_type_stepparent_with_name' => 'Genitore adottivo di :name',
     'relationship_type_stepparent_female_with_name' => ':name della matrigna',
-    'relationship_type_stepparent_male_with_name' => ':name’s stepfather',
+    'relationship_type_stepparent_male_with_name' => 'Padre adottivo di :name',
 
-    'relationship_type_stepchild' => 'stepchild',
+    'relationship_type_stepchild' => 'figlio/a adottivo',
     'relationship_type_stepchild_female' => 'figliastra',
-    'relationship_type_stepchild_male' => 'stepson',
-    'relationship_type_stepchild_with_name' => ':name’s stepchild',
+    'relationship_type_stepchild_male' => 'figlio adottivo',
+    'relationship_type_stepchild_with_name' => 'Figlio/a adottivo/a di :name',
     'relationship_type_stepchild_female_with_name' => ':name della figliastra',
-    'relationship_type_stepchild_male_with_name' => ':name’s stepson',
+    'relationship_type_stepchild_male_with_name' => 'Figlio adottivo di :name',
 
-    'relationship_type_sibling' => 'sibling',
+    'relationship_type_sibling' => 'fratello/sorella',
     'relationship_type_sibling_female' => 'sorella',
-    'relationship_type_sibling_male' => 'brother',
-    'relationship_type_sibling_with_name' => ':name’s sibling',
+    'relationship_type_sibling_male' => 'fratello',
+    'relationship_type_sibling_with_name' => 'Fratello/Sorella di :name',
     'relationship_type_sibling_female_with_name' => 'sorella di :name',
-    'relationship_type_sibling_male_with_name' => ':name’s brother',
+    'relationship_type_sibling_male_with_name' => 'Fratello di :name',
 
-    'relationship_type_grandparent' => 'grandparent',
-    'relationship_type_grandparent_female' => 'grandmother',
-    'relationship_type_grandparent_male' => 'grandfather',
-    'relationship_type_grandparent_with_name' => ':name’s grandparent',
-    'relationship_type_grandparent_female_with_name' => ':name’s grandmother',
-    'relationship_type_grandparent_male_with_name' => ':name’s grandfather',
+    'relationship_type_grandparent' => 'nonno/a',
+    'relationship_type_grandparent_female' => 'nonna',
+    'relationship_type_grandparent_male' => 'nonno',
+    'relationship_type_grandparent_with_name' => 'Nonno/a di :name',
+    'relationship_type_grandparent_female_with_name' => 'Nonna di :name',
+    'relationship_type_grandparent_male_with_name' => 'Nonno di :name',
 
-    'relationship_type_grandchild' => 'grandchild',
-    'relationship_type_grandchild_female' => 'granddaughter',
-    'relationship_type_grandchild_male' => 'grandson',
-    'relationship_type_grandchild_with_name' => ':name’s grandchild',
-    'relationship_type_grandchild_female_with_name' => ':name’s granddauther',
-    'relationship_type_grandchild_male_with_name' => ':name’s grandson',
+    'relationship_type_grandchild' => 'nipote',
+    'relationship_type_grandchild_female' => 'nipote',
+    'relationship_type_grandchild_male' => 'nipote',
+    'relationship_type_grandchild_with_name' => 'Nipote di :name',
+    'relationship_type_grandchild_female_with_name' => 'Nipotina di :name',
+    'relationship_type_grandchild_male_with_name' => 'Nipotino di :name',
 
     'relationship_type_uncle' => 'zio',
     'relationship_type_uncle_female' => 'zia',
+    'relationship_type_uncle_male' => 'zio',
     'relationship_type_uncle_with_name' => 'zio di :name',
     'relationship_type_uncle_female_with_name' => 'zia di :name',
+    'relationship_type_uncle_male_with_name' => 'zio di :name',
 
     'relationship_type_nephew' => 'nipote',
     'relationship_type_nephew_female' => 'nipote',
+    'relationship_type_nephew_male' => 'nipote',
     'relationship_type_nephew_with_name' => 'nipote di :name',
     'relationship_type_nephew_female_with_name' => 'nipote di :name',
+    'relationship_type_nephew_male_with_name' => 'nipote di :name',
 
     'relationship_type_cousin' => 'cugino',
     'relationship_type_cousin_female' => 'cugino',
-    'relationship_type_cousin_with_name' => ': nome del cugino',
-    'relationship_type_cousin_female_with_name' => ': nome del cugino',
+    'relationship_type_cousin_male' => 'cugino',
+    'relationship_type_cousin_with_name' => 'Cugino di :name',
+    'relationship_type_cousin_female_with_name' => 'Cugina di :name',
+    'relationship_type_cousin_male_with_name' => 'cugino di :name',
 
-    'relationship_type_godfather' => 'godparent',
+    'relationship_type_godfather' => 'padrino',
     'relationship_type_godfather_female' => 'madrina',
-    'relationship_type_godfather_male' => 'godfather',
-    'relationship_type_godfather_with_name' => ':name’s godparent',
+    'relationship_type_godfather_male' => 'padrino',
+    'relationship_type_godfather_with_name' => 'Padrino/Madrina di :name',
     'relationship_type_godfather_female_with_name' => ': nome della madrina',
-    'relationship_type_godfather_male_with_name' => ':name’s godfather',
+    'relationship_type_godfather_male_with_name' => 'Padrino di :name',
 
-    'relationship_type_godson' => 'godchild',
+    'relationship_type_godson' => 'figlioccio/a',
     'relationship_type_godson_female' => 'figlioccia',
-    'relationship_type_godson_male' => 'godson',
-    'relationship_type_godson_with_name' => ':name’s godchild',
+    'relationship_type_godson_male' => 'figlioccio',
+    'relationship_type_godson_with_name' => 'Figlioccio/a di :name',
     'relationship_type_godson_female_with_name' => 'figlioccia di :name',
-    'relationship_type_godson_male_with_name' => ':name’s godson',
+    'relationship_type_godson_male_with_name' => 'Figlioccio di :name',
 
     'relationship_type_friend' => 'amico',
     'relationship_type_friend_female' => 'amico',
+    'relationship_type_friend_male' => 'amico',
     'relationship_type_friend_with_name' => 'amico di :name',
     'relationship_type_friend_female_with_name' => 'amica di :name',
+    'relationship_type_friend_male_with_name' => 'amico di :name',
 
     'relationship_type_bestfriend' => 'miglior amico',
     'relationship_type_bestfriend_female' => 'miglior amico',
+    'relationship_type_bestfriend_male' => 'migliore amico',
     'relationship_type_bestfriend_with_name' => 'miglior amico di :name',
     'relationship_type_bestfriend_female_with_name' => 'miglior amica di :name',
+    'relationship_type_bestfriend_male_with_name' => 'migliore amico di :name',
 
     'relationship_type_colleague' => 'collega',
     'relationship_type_colleague_female' => 'collega',
+    'relationship_type_colleague_male' => 'collega',
     'relationship_type_colleague_with_name' => 'collega di :name',
     'relationship_type_colleague_female_with_name' => 'collega di :name',
+    'relationship_type_colleague_male_with_name' => 'collega di :name',
 
     'relationship_type_boss' => 'capo',
     'relationship_type_boss_female' => 'capo',
+    'relationship_type_boss_male' => 'capo',
     'relationship_type_boss_with_name' => 'capo di :name',
     'relationship_type_boss_female_with_name' => 'capo di :name',
+    'relationship_type_boss_male_with_name' => 'capo di :name',
 
     'relationship_type_subordinate' => 'dipendente',
     'relationship_type_subordinate_female' => 'dipendente',
+    'relationship_type_subordinate_male' => 'subordinate',
     'relationship_type_subordinate_with_name' => 'dipendente di :name',
     'relationship_type_subordinate_female_with_name' => 'dipendente di :name',
+    'relationship_type_subordinate_male_with_name' => ':name’s subordinate',
 
     'relationship_type_mentor' => 'mentore',
     'relationship_type_mentor_female' => 'mentrice',
+    'relationship_type_mentor_male' => 'mentore',
     'relationship_type_mentor_with_name' => 'mentore di :name',
     'relationship_type_mentor_female_with_name' => 'mentrice di :name',
+    'relationship_type_mentor_male_with_name' => 'mentore di :name',
 
-    'relationship_type_protege' => 'protégé',
-    'relationship_type_protege_female' => 'protégé',
-    'relationship_type_protege_with_name' => ':name’s protégé',
-    'relationship_type_protege_female_with_name' => ':name’s protégé',
+    'relationship_type_protege' => 'protetto',
+    'relationship_type_protege_female' => 'protetta',
+    'relationship_type_protege_male' => 'protégé',
+    'relationship_type_protege_with_name' => 'Protetto di :name',
+    'relationship_type_protege_female_with_name' => 'Protetta di :name',
+    'relationship_type_protege_male_with_name' => ':name’s protégé',
 
-    'relationship_type_ex_husband' => 'ex-spouse',
-    'relationship_type_ex_husband_female' => 'ex moglio',
-    'relationship_type_ex_husband_male' => 'ex-husband',
-    'relationship_type_ex_husband_with_name' => ':name’s ex-spouse',
+    'relationship_type_ex_husband' => 'ex coniuge',
+    'relationship_type_ex_husband_female' => 'ex moglie',
+    'relationship_type_ex_husband_male' => 'ex marito',
+    'relationship_type_ex_husband_with_name' => 'Ex coniuge di :name',
     'relationship_type_ex_husband_female_with_name' => 'ex moglie di :name',
-    'relationship_type_ex_husband_male_with_name' => ':name’s ex-husband',
+    'relationship_type_ex_husband_male_with_name' => 'Ex marito di :name',
 
     // emotions
     'emotion_primary_love' => 'Amore',
@@ -465,19 +495,19 @@ return [
     'emotion_dread' => 'Terrore',
 
     // weather
-    'weather_sunny' => 'Sunny',
-    'weather_clear' => 'Clear',
-    'weather_clear-day' => 'Clear',
+    'weather_sunny' => 'Soleggiato',
+    'weather_clear' => 'Chiaro',
+    'weather_clear-day' => 'Chiara',
     'weather_clear-night' => 'Notte limpida',
-    'weather_light-drizzle' => 'Light drizzle',
-    'weather_patchy-light-drizzle' => 'Patchy light drizzle',
-    'weather_patchy-light-rain' => 'Patchy light rain',
-    'weather_light-rain' => 'Light rain',
-    'weather_moderate-rain-at-times' => 'Moderate rain at times',
-    'weather_moderate-rain' => 'Moderate rain',
-    'weather_patchy-rain-possible' => 'Patchy rain possible',
-    'weather_heavy-rain-at-times' => 'Heavy rain at times',
-    'weather_heavy-rain' => 'Heavy rain',
+    'weather_light-drizzle' => 'Pioggia leggera',
+    'weather_patchy-light-drizzle' => 'Pioggerellina irregolare',
+    'weather_patchy-light-rain' => 'Pioggia leggera e irregolare',
+    'weather_light-rain' => 'Pioggia leggera',
+    'weather_moderate-rain-at-times' => 'Pioggia moderata e intermittente',
+    'weather_moderate-rain' => 'Pioggia moderata',
+    'weather_patchy-rain-possible' => 'Possibile pioggia a tratti',
+    'weather_heavy-rain-at-times' => 'Forte pioggia intermittente',
+    'weather_heavy-rain' => 'Forte pioggia',
     'weather_light-freezing-rain' => 'Light freezing rain',
     'weather_moderate-or-heavy-freezing-rain' => 'Moderate or heavy freezing rain',
     'weather_light-sleet' => 'Light sleet',
@@ -492,8 +522,8 @@ return [
     'weather_patchy-moderate-snow' => 'Patchy moderate snow',
     'weather_moderate-snow' => 'Moderate snow',
     'weather_patchy-heavy-snow' => 'Patchy heavy snow',
-    'weather_heavy-snow' => 'Heavy snow',
-    'weather_light-snow-showers' => 'Light snow showers',
+    'weather_heavy-snow' => 'Forte nevicata',
+    'weather_light-snow-showers' => 'Nevicate leggere',
     'weather_moderate-or-heavy-snow-showers' => 'Moderate or heavy snow showers',
     'weather_patchy-snow-possible' => 'Patchy snow possible',
     'weather_patchy-sleet-possible' => 'Patchy sleet possible',
@@ -508,8 +538,8 @@ return [
     'weather_blizzard' => 'Blizzard',
     'weather_overcast' => 'Overcast',
     'weather_cloudy' => 'Nuvoloso',
-    'weather_partly-cloudy-day' => 'Partly cloudy',
-    'weather_partly-cloudy-night' => 'Partly cloudy',
+    'weather_partly-cloudy-day' => 'Parzialmente nuvoloso',
+    'weather_partly-cloudy-night' => 'Parzialmente nuvolosa',
     'weather_freezing-drizzle' => 'Freezing drizzle',
     'weather_heavy-freezing-drizzle' => 'Heavy freezing drizzle',
     'weather_patchy-freezing-drizzle-possible' => 'Patchy freezing drizzle possible',
