@@ -12,5 +12,5 @@ return [
     'type_lunch' => 'Pranzo con',
     'type_hangout' => 'Incontro con',
     'type_email' => 'Email',
-    'type_birthday_kid' => 'Wish happy birthday to the child of',
+    'type_birthday_kid' => 'Augura buon compleanno al figlio di',
 ];
