@@ -135,167 +135,197 @@ return [
     'relationship_type_group_love' => 'Liefdesrelaties',
     'relationship_type_group_family' => 'Familierelaties',
     'relationship_type_group_friend' => 'Vriendschappen',
-    'relationship_type_group_work' => 'Collega\'s',
+    'relationship_type_group_work' => 'Collega’s',
     'relationship_type_group_other' => 'Andere relaties',
 
     'relationship_type_partner' => 'partner',
     'relationship_type_partner_female' => 'partner',
-    'relationship_type_partner_with_name' => ':name\'s van partner',
+    'relationship_type_partner_male' => 'partner',
+    'relationship_type_partner_with_name' => ':name’s van partner',
     'relationship_type_partner_female_with_name' => ':name’s partner',
+    'relationship_type_partner_male_with_name' => ':name’s partner',
 
     'relationship_type_spouse' => 'echtgenoot',
-    'relationship_type_spouse_female' => 'wife',
-    'relationship_type_spouse_male' => 'husband',
+    'relationship_type_spouse_female' => 'vrouw',
+    'relationship_type_spouse_male' => 'echtgenoot',
     'relationship_type_spouse_with_name' => ':name’s van echtgeno(o)t(e)',
-    'relationship_type_spouse_female_with_name' => ':name’s wife',
-    'relationship_type_spouse_male_with_name' => ':name’s husband',
+    'relationship_type_spouse_female_with_name' => ':name’s vrouw',
+    'relationship_type_spouse_male_with_name' => 'array[\'relationship_type_spouse_male_with_name\']',
 
     'relationship_type_date' => 'date',
     'relationship_type_date_female' => 'date',
+    'relationship_type_date_male' => 'date',
     'relationship_type_date_with_name' => ':name’s date',
-    'relationship_type_date_female_with_name' => ':name\'s date',
+    'relationship_type_date_female_with_name' => ':name’s date',
+    'relationship_type_date_male_with_name' => ':name’s date',
 
     'relationship_type_lover' => 'geliefde',
     'relationship_type_lover_female' => 'geliefde',
+    'relationship_type_lover_male' => 'geliefde',
     'relationship_type_lover_with_name' => ':name’s geliefde',
     'relationship_type_lover_female_with_name' => ':name’s geliefde',
+    'relationship_type_lover_male_with_name' => ':name’s geliefde',
 
     'relationship_type_inlovewith' => 'verliefd op',
     'relationship_type_inlovewith_female' => 'verliefd op',
+    'relationship_type_inlovewith_male' => 'verliefd op',
     'relationship_type_inlovewith_with_name' => 'iemand :name is verliefd op',
     'relationship_type_inlovewith_female_with_name' => 'iemand :name is verliefd op',
+    'relationship_type_inlovewith_male_with_name' => 'iemand :name is verliefd op',
 
     'relationship_type_lovedby' => 'begeert door',
     'relationship_type_lovedby_female' => 'begeert door',
+    'relationship_type_lovedby_male' => 'geliefd door',
     'relationship_type_lovedby_with_name' => ':name’s geheime minnaar',
     'relationship_type_lovedby_female_with_name' => ':name’s geheime minnaar',
+    'relationship_type_lovedby_male_with_name' => ':name’s geheime minnaar',
 
     'relationship_type_ex' => 'ex-partner',
     'relationship_type_ex_female' => 'ex-vriendin',
-    'relationship_type_ex_male' => 'ex-boyfriend',
+    'relationship_type_ex_male' => 'ex-vriend',
     'relationship_type_ex_with_name' => ':name’s ex-partner',
     'relationship_type_ex_female_with_name' => ':name’s ex-vriendinnetje',
-    'relationship_type_ex_male_with_name' => ':name’s ex-boyfriend',
+    'relationship_type_ex_male_with_name' => ':name’s ex-vriend',
 
-    'relationship_type_parent' => 'parent',
+    'relationship_type_parent' => 'ouder',
     'relationship_type_parent_female' => 'moeder',
-    'relationship_type_parent_male' => 'father',
-    'relationship_type_parent_with_name' => ':name’s parent',
+    'relationship_type_parent_male' => 'vader',
+    'relationship_type_parent_with_name' => ':name’s ouder',
     'relationship_type_parent_female_with_name' => ':name’s moeder',
-    'relationship_type_parent_male_with_name' => ':name’s father',
+    'relationship_type_parent_male_with_name' => ':name’s vader',
 
-    'relationship_type_child' => 'child',
+    'relationship_type_child' => 'kind',
     'relationship_type_child_female' => 'dochter',
-    'relationship_type_child_male' => 'son',
-    'relationship_type_child_with_name' => ':name’s child',
+    'relationship_type_child_male' => 'zoon',
+    'relationship_type_child_with_name' => ':name’s kind',
     'relationship_type_child_female_with_name' => ':name’s dochter',
-    'relationship_type_child_male_with_name' => ':name’s son',
+    'relationship_type_child_male_with_name' => ':name’s zoon',
 
-    'relationship_type_stepparent' => 'step-parent',
+    'relationship_type_stepparent' => 'stiefouder',
     'relationship_type_stepparent_female' => 'stiefmoeder',
-    'relationship_type_stepparent_male' => 'stepfather',
-    'relationship_type_stepparent_with_name' => ':name’s step-parent',
+    'relationship_type_stepparent_male' => 'stiefvader',
+    'relationship_type_stepparent_with_name' => ':name’s stiefouder',
     'relationship_type_stepparent_female_with_name' => ':name’s stiefmoeder',
-    'relationship_type_stepparent_male_with_name' => ':name’s stepfather',
+    'relationship_type_stepparent_male_with_name' => ':name’s stiefvader',
 
-    'relationship_type_stepchild' => 'stepchild',
+    'relationship_type_stepchild' => 'stiefkind',
     'relationship_type_stepchild_female' => 'stiefdochter',
-    'relationship_type_stepchild_male' => 'stepson',
-    'relationship_type_stepchild_with_name' => ':name’s stepchild',
+    'relationship_type_stepchild_male' => 'stiefzoon',
+    'relationship_type_stepchild_with_name' => ':name’s stiefkind',
     'relationship_type_stepchild_female_with_name' => ':name’s stiefdochter',
-    'relationship_type_stepchild_male_with_name' => ':name’s stepson',
+    'relationship_type_stepchild_male_with_name' => ':name’s stiefzoon',
 
-    'relationship_type_sibling' => 'sibling',
+    'relationship_type_sibling' => 'broer of zus',
     'relationship_type_sibling_female' => 'zus',
-    'relationship_type_sibling_male' => 'brother',
-    'relationship_type_sibling_with_name' => ':name’s sibling',
+    'relationship_type_sibling_male' => 'broer',
+    'relationship_type_sibling_with_name' => ':name’s broer of zus',
     'relationship_type_sibling_female_with_name' => ':name’s zus',
-    'relationship_type_sibling_male_with_name' => ':name’s brother',
+    'relationship_type_sibling_male_with_name' => ':name’s broer',
 
-    'relationship_type_grandparent' => 'grandparent',
-    'relationship_type_grandparent_female' => 'grandmother',
-    'relationship_type_grandparent_male' => 'grandfather',
-    'relationship_type_grandparent_with_name' => ':name’s grandparent',
-    'relationship_type_grandparent_female_with_name' => ':name’s grandmother',
-    'relationship_type_grandparent_male_with_name' => ':name’s grandfather',
+    'relationship_type_grandparent' => 'grootouder',
+    'relationship_type_grandparent_female' => 'oma',
+    'relationship_type_grandparent_male' => 'opa',
+    'relationship_type_grandparent_with_name' => ':name’s grootouder',
+    'relationship_type_grandparent_female_with_name' => ':name’s oma',
+    'relationship_type_grandparent_male_with_name' => ':name’s opa',
 
-    'relationship_type_grandchild' => 'grandchild',
-    'relationship_type_grandchild_female' => 'granddaughter',
-    'relationship_type_grandchild_male' => 'grandson',
-    'relationship_type_grandchild_with_name' => ':name’s grandchild',
-    'relationship_type_grandchild_female_with_name' => ':name’s granddauther',
-    'relationship_type_grandchild_male_with_name' => ':name’s grandson',
+    'relationship_type_grandchild' => 'kleinkind',
+    'relationship_type_grandchild_female' => 'kleindochter',
+    'relationship_type_grandchild_male' => 'kleinzoon',
+    'relationship_type_grandchild_with_name' => ':name’s kleinkind',
+    'relationship_type_grandchild_female_with_name' => ':name’s kleindochter',
+    'relationship_type_grandchild_male_with_name' => ':name\'s kleinzoon',
 
     'relationship_type_uncle' => 'oom',
     'relationship_type_uncle_female' => 'tante',
+    'relationship_type_uncle_male' => 'oom',
     'relationship_type_uncle_with_name' => ':name’s oom',
     'relationship_type_uncle_female_with_name' => ':name’s tante',
+    'relationship_type_uncle_male_with_name' => ':name’s oom',
 
     'relationship_type_nephew' => 'neef',
     'relationship_type_nephew_female' => 'nicht',
+    'relationship_type_nephew_male' => 'neef',
     'relationship_type_nephew_with_name' => ':name’s neef',
     'relationship_type_nephew_female_with_name' => ':name’s nicht',
+    'relationship_type_nephew_male_with_name' => ':name’s neef',
 
     'relationship_type_cousin' => 'neef',
     'relationship_type_cousin_female' => 'nicht',
+    'relationship_type_cousin_male' => 'neef',
     'relationship_type_cousin_with_name' => ':name’s neef',
     'relationship_type_cousin_female_with_name' => ':name’s nicht',
+    'relationship_type_cousin_male_with_name' => ':name’s neef',
 
-    'relationship_type_godfather' => 'godparent',
+    'relationship_type_godfather' => 'peetouder',
     'relationship_type_godfather_female' => 'peet moeder',
-    'relationship_type_godfather_male' => 'godfather',
-    'relationship_type_godfather_with_name' => ':name’s godparent',
-    'relationship_type_godfather_female_with_name' => ':name\'s peetmoeder',
-    'relationship_type_godfather_male_with_name' => ':name’s godfather',
+    'relationship_type_godfather_male' => 'peetoom',
+    'relationship_type_godfather_with_name' => ':name’s peetoom',
+    'relationship_type_godfather_female_with_name' => ':name’s peetmoeder',
+    'relationship_type_godfather_male_with_name' => ':name\'s peetoom',
 
-    'relationship_type_godson' => 'godchild',
+    'relationship_type_godson' => 'petekind',
     'relationship_type_godson_female' => 'peetdochter',
-    'relationship_type_godson_male' => 'godson',
-    'relationship_type_godson_with_name' => ':name’s godchild',
-    'relationship_type_godson_female_with_name' => ':name\'s schoondochter',
-    'relationship_type_godson_male_with_name' => ':name’s godson',
+    'relationship_type_godson_male' => 'peetzoon',
+    'relationship_type_godson_with_name' => ':name’s petekind',
+    'relationship_type_godson_female_with_name' => ':name’s schoondochter',
+    'relationship_type_godson_male_with_name' => ':name’s peetzoon',
 
     'relationship_type_friend' => 'vriend',
     'relationship_type_friend_female' => 'vriend',
+    'relationship_type_friend_male' => 'vriend',
     'relationship_type_friend_with_name' => ':name’s vriend',
     'relationship_type_friend_female_with_name' => ':name’s vriend',
+    'relationship_type_friend_male_with_name' => ':name’s vriend',
 
     'relationship_type_bestfriend' => 'beste vriend',
     'relationship_type_bestfriend_female' => 'beste vriend',
+    'relationship_type_bestfriend_male' => 'beste vriend',
     'relationship_type_bestfriend_with_name' => ':name’s beste vriend',
     'relationship_type_bestfriend_female_with_name' => ':name’s beste vriend',
+    'relationship_type_bestfriend_male_with_name' => ':name’s beste vriend',
 
     'relationship_type_colleague' => 'collega',
     'relationship_type_colleague_female' => 'collega',
+    'relationship_type_colleague_male' => 'collega',
     'relationship_type_colleague_with_name' => ':name’s collega',
     'relationship_type_colleague_female_with_name' => ':name’s collega',
+    'relationship_type_colleague_male_with_name' => ':name’s collega',
 
     'relationship_type_boss' => 'baas',
     'relationship_type_boss_female' => 'baas',
+    'relationship_type_boss_male' => 'baas',
     'relationship_type_boss_with_name' => ':name’s baas',
     'relationship_type_boss_female_with_name' => ':name’s baas',
+    'relationship_type_boss_male_with_name' => ':name’s baas',
 
     'relationship_type_subordinate' => 'ondergeschikte',
     'relationship_type_subordinate_female' => 'ondergeschikte',
+    'relationship_type_subordinate_male' => 'ondergeschikte',
     'relationship_type_subordinate_with_name' => ':name’s ondergeschikte',
     'relationship_type_subordinate_female_with_name' => ':name’s ondergeschikte',
+    'relationship_type_subordinate_male_with_name' => ':name’s ondergeschikte',
 
     'relationship_type_mentor' => 'mentor',
     'relationship_type_mentor_female' => 'mentor',
+    'relationship_type_mentor_male' => 'mentor',
     'relationship_type_mentor_with_name' => ':name’s mentor',
     'relationship_type_mentor_female_with_name' => ':name’s mentor',
+    'relationship_type_mentor_male_with_name' => ':name’s mentor',
 
-    'relationship_type_protege' => 'protégé',
-    'relationship_type_protege_female' => 'protégé',
-    'relationship_type_protege_with_name' => ':name’s protégé',
-    'relationship_type_protege_female_with_name' => ':name’s protégé',
+    'relationship_type_protege' => 'pupil',
+    'relationship_type_protege_female' => 'pupil',
+    'relationship_type_protege_male' => 'pupil',
+    'relationship_type_protege_with_name' => ':name\'s pupil',
+    'relationship_type_protege_female_with_name' => ':name\'s pupil',
+    'relationship_type_protege_male_with_name' => ':name\'s pupil',
 
-    'relationship_type_ex_husband' => 'ex-spouse',
+    'relationship_type_ex_husband' => 'ex-man',
     'relationship_type_ex_husband_female' => 'ex-vrouw',
-    'relationship_type_ex_husband_male' => 'ex-husband',
-    'relationship_type_ex_husband_with_name' => ':name’s ex-spouse',
+    'relationship_type_ex_husband_male' => 'ex-man',
+    'relationship_type_ex_husband_with_name' => ':naam ex-echtgenoot',
     'relationship_type_ex_husband_female_with_name' => ':name’s ex-vrouw',
-    'relationship_type_ex_husband_male_with_name' => ':name’s ex-husband',
+    'relationship_type_ex_husband_male_with_name' => ':naam ex-man',
 
     // emotions
     'emotion_primary_love' => 'Liefde',
@@ -466,17 +496,17 @@ return [
 
     // weather
     'weather_sunny' => 'Zonnig',
-    'weather_clear' => 'Clear',
-    'weather_clear-day' => 'Clear',
+    'weather_clear' => 'Helder',
+    'weather_clear-day' => 'Helder',
     'weather_clear-night' => 'Heldere nacht',
     'weather_light-drizzle' => 'Lichte motregen',
-    'weather_patchy-light-drizzle' => 'Patchy light drizzle',
-    'weather_patchy-light-rain' => 'Patchy light rain',
+    'weather_patchy-light-drizzle' => 'Af en toe motregen',
+    'weather_patchy-light-rain' => 'Af en toe regenval',
     'weather_light-rain' => 'Lichte regen',
-    'weather_moderate-rain-at-times' => 'Moderate rain at times',
-    'weather_moderate-rain' => 'Moderate rain',
-    'weather_patchy-rain-possible' => 'Patchy rain possible',
-    'weather_heavy-rain-at-times' => 'Heavy rain at times',
+    'weather_moderate-rain-at-times' => 'Nu en dan matige regenval',
+    'weather_moderate-rain' => 'Matige regenval',
+    'weather_patchy-rain-possible' => 'Plaatselijk regen mogelijk',
+    'weather_heavy-rain-at-times' => 'Nu en dan hevige regen',
     'weather_heavy-rain' => 'Heavy rain',
     'weather_light-freezing-rain' => 'Light freezing rain',
     'weather_moderate-or-heavy-freezing-rain' => 'Moderate or heavy freezing rain',
@@ -531,7 +561,7 @@ return [
     'dav_birthdays' => 'Verjaardagen',
     'dav_birthdays_description' => 'Verjaardagen van de contacten van :name',
     'dav_tasks' => 'Taken',
-    'dav_tasks_description' => 'Taken van :name',
+    'dav_tasks_description' => ':name’s taken',
 
     // contact list
     'contact_list_avatar' => 'Avatar',
