@@ -140,8 +140,10 @@ return [
 
     'relationship_type_partner' => 'kjæreste',
     'relationship_type_partner_female' => 'kjæreste',
+    'relationship_type_partner_male' => 'significant other',
     'relationship_type_partner_with_name' => 'kjæresten til :name',
     'relationship_type_partner_female_with_name' => 'kjæresten til :name',
+    'relationship_type_partner_male_with_name' => ':name’s significant other',
 
     'relationship_type_spouse' => 'ektefelle',
     'relationship_type_spouse_female' => 'kone',
@@ -152,23 +154,31 @@ return [
 
     'relationship_type_date' => 'date',
     'relationship_type_date_female' => 'date',
+    'relationship_type_date_male' => 'date',
     'relationship_type_date_with_name' => 'date med :name',
     'relationship_type_date_female_with_name' => 'date med :name',
+    'relationship_type_date_male_with_name' => ':name’s date',
 
     'relationship_type_lover' => 'elsker',
     'relationship_type_lover_female' => 'elskerinne',
+    'relationship_type_lover_male' => 'lover',
     'relationship_type_lover_with_name' => 'elskeren til :name',
     'relationship_type_lover_female_with_name' => 'elskerinnen til :name',
+    'relationship_type_lover_male_with_name' => ':name’s lover',
 
     'relationship_type_inlovewith' => 'forelsket i',
     'relationship_type_inlovewith_female' => 'forelsket i',
+    'relationship_type_inlovewith_male' => 'in love with',
     'relationship_type_inlovewith_with_name' => 'noen :name er forelsket i',
     'relationship_type_inlovewith_female_with_name' => 'noen :name er forelsket i',
+    'relationship_type_inlovewith_male_with_name' => 'someone :name is in love with',
 
     'relationship_type_lovedby' => 'elsket av',
     'relationship_type_lovedby_female' => 'elsket av',
+    'relationship_type_lovedby_male' => 'loved by',
     'relationship_type_lovedby_with_name' => ':name sin hemmelige elsker',
     'relationship_type_lovedby_female_with_name' => ':name sin hemmelige elskerinne',
+    'relationship_type_lovedby_male_with_name' => ':name’s secret lover',
 
     'relationship_type_ex' => 'ex-partner',
     'relationship_type_ex_female' => 'ekskjæreste',
@@ -228,18 +238,24 @@ return [
 
     'relationship_type_uncle' => 'onkel',
     'relationship_type_uncle_female' => 'tante',
+    'relationship_type_uncle_male' => 'uncle',
     'relationship_type_uncle_with_name' => 'Onkelen til :name',
     'relationship_type_uncle_female_with_name' => 'Tanten til :name',
+    'relationship_type_uncle_male_with_name' => ':name’s uncle',
 
     'relationship_type_nephew' => 'nevø',
     'relationship_type_nephew_female' => 'niese',
+    'relationship_type_nephew_male' => 'nephew',
     'relationship_type_nephew_with_name' => 'Nevøen til :name',
     'relationship_type_nephew_female_with_name' => 'Niesen til :name',
+    'relationship_type_nephew_male_with_name' => ':name’s nephew',
 
     'relationship_type_cousin' => 'fetter',
     'relationship_type_cousin_female' => 'kusine',
+    'relationship_type_cousin_male' => 'cousin',
     'relationship_type_cousin_with_name' => 'Fetteren til :name',
     'relationship_type_cousin_female_with_name' => 'Kusinen til :name',
+    'relationship_type_cousin_male_with_name' => ':name’s cousin',
 
     'relationship_type_godfather' => 'godparent',
     'relationship_type_godfather_female' => 'gudmor',
@@ -257,38 +273,52 @@ return [
 
     'relationship_type_friend' => 'venn',
     'relationship_type_friend_female' => 'venninne',
+    'relationship_type_friend_male' => 'friend',
     'relationship_type_friend_with_name' => 'Venn av :name',
     'relationship_type_friend_female_with_name' => 'Venn av :name',
+    'relationship_type_friend_male_with_name' => ':name’s friend',
 
     'relationship_type_bestfriend' => 'bestevenn',
     'relationship_type_bestfriend_female' => 'bestevenninne',
+    'relationship_type_bestfriend_male' => 'best friend',
     'relationship_type_bestfriend_with_name' => 'Bestevenn av :name',
     'relationship_type_bestfriend_female_with_name' => 'Bestevenn av :name',
+    'relationship_type_bestfriend_male_with_name' => ':name’s best friend',
 
     'relationship_type_colleague' => 'kollega',
     'relationship_type_colleague_female' => 'kollega',
+    'relationship_type_colleague_male' => 'colleague',
     'relationship_type_colleague_with_name' => 'Kollega av :name',
     'relationship_type_colleague_female_with_name' => 'Kollega av :name',
+    'relationship_type_colleague_male_with_name' => ':name’s colleague',
 
     'relationship_type_boss' => 'sjef',
     'relationship_type_boss_female' => 'sjef',
+    'relationship_type_boss_male' => 'boss',
     'relationship_type_boss_with_name' => 'Sjefen til :name',
     'relationship_type_boss_female_with_name' => 'Sjefen til :name',
+    'relationship_type_boss_male_with_name' => ':name’s boss',
 
     'relationship_type_subordinate' => 'underordnet',
     'relationship_type_subordinate_female' => 'underordnet',
+    'relationship_type_subordinate_male' => 'subordinate',
     'relationship_type_subordinate_with_name' => 'Underordnet til :name',
     'relationship_type_subordinate_female_with_name' => 'Underordnet til :name',
+    'relationship_type_subordinate_male_with_name' => ':name’s subordinate',
 
     'relationship_type_mentor' => 'mentor',
     'relationship_type_mentor_female' => 'mentor',
+    'relationship_type_mentor_male' => 'mentor',
     'relationship_type_mentor_with_name' => 'Mentor til :name',
     'relationship_type_mentor_female_with_name' => 'Mentor til :name',
+    'relationship_type_mentor_male_with_name' => ':name’s mentor',
 
     'relationship_type_protege' => 'protégé',
     'relationship_type_protege_female' => 'protégé',
+    'relationship_type_protege_male' => 'protégé',
     'relationship_type_protege_with_name' => ':name’s protégé',
     'relationship_type_protege_female_with_name' => ':name’s protégé',
+    'relationship_type_protege_male_with_name' => ':name’s protégé',
 
     'relationship_type_ex_husband' => 'ex-spouse',
     'relationship_type_ex_husband_female' => 'ekskone',
