@@ -9,23 +9,23 @@
 return [
 
     //index
-    'people_not_found' => 'Contact not found',
-    'people_list_number_kids' => ':count child|:count children',
+    'people_not_found' => 'Contacto não encontrado',
+    'people_list_number_kids' => ':count criança|:count crianças',
     'people_list_last_updated' => 'Última consulta:',
-    'people_list_number_reminders' => ':count reminder|:count reminders',
+    'people_list_number_reminders' => ':count lembrete|:count lembretes',
     'people_list_blank_title' => 'Você ainda não tem ninguém em sua conta',
     'people_list_blank_cta' => 'Adicionar uma pessoa',
     'people_list_sort' => 'Ordenar',
-    'people_list_stats' => ':count contact|:count contacts',
+    'people_list_stats' => ':count contacto|:count contactos',
     'people_list_firstnameAZ' => 'Classificar por primeiro nome A → Z',
     'people_list_firstnameZA' => 'Classificar por primeiro nome Z → A',
     'people_list_lastnameAZ' => 'Classificar por sobrenome A → Z',
     'people_list_lastnameZA' => 'Classificar por sobrenome Z → A',
-    'people_list_lastactivitydateNewtoOld' => 'Sort by last activity date, newest to oldest',
-    'people_list_lastactivitydateOldtoNew' => 'Sort by last activity date, oldest to newest',
-    'people_list_filter_tag' => 'Showing all the contacts tagged with',
+    'people_list_lastactivitydateNewtoOld' => 'Ordenar por data da última atividade, mais recente para mais antigo',
+    'people_list_lastactivitydateOldtoNew' => 'Ordenar por data da última atividade, mais antigo para mais recente',
+    'people_list_filter_tag' => 'A mostrar todos os contactos etiquetados com',
     'people_list_clear_filter' => 'Limpar filtro',
-    'people_list_contacts_per_tags' => ':count contact|:count contacts',
+    'people_list_contacts_per_tags' => ':count contacto|:count contactos',
     'people_list_show_dead' => 'Show deceased people (:count)',
     'people_list_hide_dead' => 'Hide deceased people (:count)',
     'people_search' => 'Search your contacts…',
