@@ -14,7 +14,7 @@ return [
     'add' => 'Lägg till',
     'cancel' => 'Avbryt',
     'confirm' => 'Bekräfta',
-    'delete_confirm' => 'Are you sure?',
+    'delete_confirm' => 'Är du säker?',
     'delete' => 'Radera',
     'edit' => 'Redigera',
     'upload' => 'Ladda upp',
@@ -31,7 +31,7 @@ return [
     'new' => 'ny',
     'unknown' => 'Jag vet inte',
     'load_more' => 'Ladda mer',
-    'loading' => 'Loading…',
+    'loading' => 'Laddar…',
     'with' => 'med',
     'today' => 'idag',
     'yesterday' => 'igår',
@@ -44,11 +44,11 @@ return [
     'retry' => 'Försök igen',
     'filter' => 'Filtrera listan',
     'go_back' => 'Gå tillbaka',
-    'file_selected' => 'One file selected…|{count} files selected…',
+    'file_selected' => 'En fil vald…|{count} filer valda…',
 
     'application_title' => 'Monica – Personlig Relationsansvarig',
     'application_description' => 'Monica är ett verktyg för att hantera dina interaktioner med dina nära och kära, vänner och familj.',
-    'application_og_title' => 'Have better relations with your loved ones. Free online CRM for friends and family.',
+    'application_og_title' => 'Skapa bättre relationer med dina nära och kära. Gratis online CRM för vänner och familj.',
 
     'markdown_description' => 'Vill du formatera din text fint? Vi stöder Markdown för att lägga till fetstil, kursiva, listor och mycket mer.',
     'markdown_link' => 'Läs dokumentation',
@@ -64,14 +64,14 @@ return [
     'main_nav_activities' => 'Aktiviteter',
     'main_nav_tasks' => 'Uppgifter',
 
-    'footer_remarks' => 'Comments?',
-    'footer_send_email' => 'Send us an email',
+    'footer_remarks' => 'Kommentarer?',
+    'footer_send_email' => 'Skicka ett mail till oss',
     'footer_privacy' => 'Integritetspolicy',
     'footer_release' => 'Information om utgivningen',
     'footer_newsletter' => 'Nyhetsbrev',
     'footer_source_code' => 'Bidra',
     'footer_version' => 'Version: :version',
-    'footer_new_version' => 'A new version of Monica is available',
+    'footer_new_version' => 'En ny version av Monica är tillgänglig',
 
     'footer_modal_version_whats_new' => 'Vad är nytt',
     'footer_modal_version_release_away' => 'Du är 1 version bakom den senaste versionen. Du bör uppdatera din instans.|Du är :number releaser bakom den senaste versionen. Du bör uppdatera din instans.',
@@ -113,7 +113,7 @@ return [
     'error_try_again' => 'Något gick fel. Försök igen.',
     'error_id' => 'Fel ID: ID',
     'error_unavailable' => 'Tjänsten är inte tillgänglig',
-    'error_maintenance' => 'Maintenance in progress. We’ll be right back.',
+    'error_maintenance' => 'Underhåll pågår, vi återkommer strax.',
     'error_help' => 'Vi kommer snart tillbaka.',
     'error_twitter' => 'Följ <a href="https://twitter.com/:twitter">vårt Twitter-konto</a> för att bli uppdaterad när sidan är uppe igen.',
     'error_no_term' => 'Det finns ingen policy för denna instans ännu.',
@@ -140,162 +140,192 @@ return [
 
     'relationship_type_partner' => 'partner',
     'relationship_type_partner_female' => 'partner',
+    'relationship_type_partner_male' => 'partner',
     'relationship_type_partner_with_name' => '.name\'s partner',
     'relationship_type_partner_female_with_name' => ':name\'s partner',
+    'relationship_type_partner_male_with_name' => ':name’s partner',
 
     'relationship_type_spouse' => 'make',
-    'relationship_type_spouse_female' => 'wife',
-    'relationship_type_spouse_male' => 'husband',
+    'relationship_type_spouse_female' => 'fru',
+    'relationship_type_spouse_male' => 'make',
     'relationship_type_spouse_with_name' => ':name\'s make',
-    'relationship_type_spouse_female_with_name' => ':name’s wife',
-    'relationship_type_spouse_male_with_name' => ':name’s husband',
+    'relationship_type_spouse_female_with_name' => ':name’s fru',
+    'relationship_type_spouse_male_with_name' => ':name’s make',
 
     'relationship_type_date' => 'dejt',
     'relationship_type_date_female' => 'dejt',
+    'relationship_type_date_male' => 'date',
     'relationship_type_date_with_name' => ':name\'s dejt',
     'relationship_type_date_female_with_name' => ':name\'s dejt',
+    'relationship_type_date_male_with_name' => ':name’s date',
 
     'relationship_type_lover' => 'älskare',
     'relationship_type_lover_female' => 'älskare',
+    'relationship_type_lover_male' => 'älskare',
     'relationship_type_lover_with_name' => ':name\'s älskare',
     'relationship_type_lover_female_with_name' => ':name\'s älskarinna',
+    'relationship_type_lover_male_with_name' => ':name’s älskare',
 
     'relationship_type_inlovewith' => 'kär i',
     'relationship_type_inlovewith_female' => 'kär i',
+    'relationship_type_inlovewith_male' => 'kär i',
     'relationship_type_inlovewith_with_name' => 'någon :name är kär i',
     'relationship_type_inlovewith_female_with_name' => 'någon :name är kär i',
+    'relationship_type_inlovewith_male_with_name' => 'någon :name är kär i',
 
     'relationship_type_lovedby' => 'älskad av',
     'relationship_type_lovedby_female' => 'älskad av',
+    'relationship_type_lovedby_male' => 'älskad av',
     'relationship_type_lovedby_with_name' => ':name\'s hemliga älskare',
     'relationship_type_lovedby_female_with_name' => ':name\'s hemliga älskarinna',
+    'relationship_type_lovedby_male_with_name' => ':name\'s hemliga älskare',
 
-    'relationship_type_ex' => 'ex-partner',
+    'relationship_type_ex' => 'föredetta',
     'relationship_type_ex_female' => 'ex-flickvän',
-    'relationship_type_ex_male' => 'ex-boyfriend',
-    'relationship_type_ex_with_name' => ':name’s ex-partner',
+    'relationship_type_ex_male' => 'föredetta pojkvän',
+    'relationship_type_ex_with_name' => ':name’s föredetta partner',
     'relationship_type_ex_female_with_name' => ':name\'s ex-flickvän',
-    'relationship_type_ex_male_with_name' => ':name’s ex-boyfriend',
+    'relationship_type_ex_male_with_name' => ':name’s föredetta pojkvän',
 
-    'relationship_type_parent' => 'parent',
+    'relationship_type_parent' => 'förälder',
     'relationship_type_parent_female' => 'mor',
-    'relationship_type_parent_male' => 'father',
-    'relationship_type_parent_with_name' => ':name’s parent',
+    'relationship_type_parent_male' => 'fader',
+    'relationship_type_parent_with_name' => ':name’s förälder',
     'relationship_type_parent_female_with_name' => ':name\'s mamma',
-    'relationship_type_parent_male_with_name' => ':name’s father',
+    'relationship_type_parent_male_with_name' => ':name’s fader',
 
-    'relationship_type_child' => 'child',
+    'relationship_type_child' => 'barn',
     'relationship_type_child_female' => 'dotter',
     'relationship_type_child_male' => 'son',
-    'relationship_type_child_with_name' => ':name’s child',
+    'relationship_type_child_with_name' => ':name\'s barn',
     'relationship_type_child_female_with_name' => ':name\'s dotter',
-    'relationship_type_child_male_with_name' => ':name’s son',
+    'relationship_type_child_male_with_name' => ':name\'s son',
 
-    'relationship_type_stepparent' => 'step-parent',
+    'relationship_type_stepparent' => 'styvförälder',
     'relationship_type_stepparent_female' => 'styvmor',
-    'relationship_type_stepparent_male' => 'stepfather',
-    'relationship_type_stepparent_with_name' => ':name’s step-parent',
+    'relationship_type_stepparent_male' => 'styvfar',
+    'relationship_type_stepparent_with_name' => ':name’s styvförälder',
     'relationship_type_stepparent_female_with_name' => ':name\'s styvmor',
-    'relationship_type_stepparent_male_with_name' => ':name’s stepfather',
+    'relationship_type_stepparent_male_with_name' => ':name’s styvfar',
 
-    'relationship_type_stepchild' => 'stepchild',
+    'relationship_type_stepchild' => 'styvbarn',
     'relationship_type_stepchild_female' => 'styvdotter',
-    'relationship_type_stepchild_male' => 'stepson',
-    'relationship_type_stepchild_with_name' => ':name’s stepchild',
+    'relationship_type_stepchild_male' => 'styvson',
+    'relationship_type_stepchild_with_name' => ':name’s styvbarn',
     'relationship_type_stepchild_female_with_name' => ':name\'s styvdotter',
-    'relationship_type_stepchild_male_with_name' => ':name’s stepson',
+    'relationship_type_stepchild_male_with_name' => ':name’s styvson',
 
-    'relationship_type_sibling' => 'sibling',
+    'relationship_type_sibling' => 'syskon',
     'relationship_type_sibling_female' => 'syster',
-    'relationship_type_sibling_male' => 'brother',
-    'relationship_type_sibling_with_name' => ':name’s sibling',
+    'relationship_type_sibling_male' => 'broder',
+    'relationship_type_sibling_with_name' => ':name’s syskon',
     'relationship_type_sibling_female_with_name' => ':name\'s syster',
-    'relationship_type_sibling_male_with_name' => ':name’s brother',
+    'relationship_type_sibling_male_with_name' => ':name’s broder',
 
-    'relationship_type_grandparent' => 'grandparent',
-    'relationship_type_grandparent_female' => 'grandmother',
-    'relationship_type_grandparent_male' => 'grandfather',
-    'relationship_type_grandparent_with_name' => ':name’s grandparent',
-    'relationship_type_grandparent_female_with_name' => ':name’s grandmother',
-    'relationship_type_grandparent_male_with_name' => ':name’s grandfather',
+    'relationship_type_grandparent' => 'mor- eller farförälder',
+    'relationship_type_grandparent_female' => 'farmor/mormor',
+    'relationship_type_grandparent_male' => 'farfar/morfar',
+    'relationship_type_grandparent_with_name' => ':name’s far- eller morförälder',
+    'relationship_type_grandparent_female_with_name' => ':name’s far- eller mormoder',
+    'relationship_type_grandparent_male_with_name' => ':name’s far- eller morfar',
 
-    'relationship_type_grandchild' => 'grandchild',
-    'relationship_type_grandchild_female' => 'granddaughter',
-    'relationship_type_grandchild_male' => 'grandson',
-    'relationship_type_grandchild_with_name' => ':name’s grandchild',
-    'relationship_type_grandchild_female_with_name' => ':name’s granddauther',
-    'relationship_type_grandchild_male_with_name' => ':name’s grandson',
+    'relationship_type_grandchild' => 'barnbarn',
+    'relationship_type_grandchild_female' => 'son-/dotterdotter',
+    'relationship_type_grandchild_male' => 'son-/dotterson',
+    'relationship_type_grandchild_with_name' => ':name’s barnbarn',
+    'relationship_type_grandchild_female_with_name' => ':name’s son-/dotterdotter',
+    'relationship_type_grandchild_male_with_name' => ':name’s son-/dotterson',
 
     'relationship_type_uncle' => 'farbror',
     'relationship_type_uncle_female' => 'moster',
+    'relationship_type_uncle_male' => 'far-/morbror',
     'relationship_type_uncle_with_name' => ':name\'s farbror',
     'relationship_type_uncle_female_with_name' => ':name\'s moster',
+    'relationship_type_uncle_male_with_name' => ':name’s far-/morbror',
 
     'relationship_type_nephew' => 'brorson',
     'relationship_type_nephew_female' => 'systerdotter',
+    'relationship_type_nephew_male' => 'bror-/systerbarn',
     'relationship_type_nephew_with_name' => ':name\'s brorson',
     'relationship_type_nephew_female_with_name' => ':name\'s systerdotter',
+    'relationship_type_nephew_male_with_name' => ':name’s bror-/systerbarn',
 
     'relationship_type_cousin' => 'kusin',
     'relationship_type_cousin_female' => 'kusin',
+    'relationship_type_cousin_male' => 'kusin',
     'relationship_type_cousin_with_name' => ':name\'s kusin',
     'relationship_type_cousin_female_with_name' => ':name\'s kusin',
+    'relationship_type_cousin_male_with_name' => ':name\'s kusin',
 
-    'relationship_type_godfather' => 'godparent',
+    'relationship_type_godfather' => 'gudförälder',
     'relationship_type_godfather_female' => 'gudmor',
-    'relationship_type_godfather_male' => 'godfather',
-    'relationship_type_godfather_with_name' => ':name’s godparent',
+    'relationship_type_godfather_male' => 'gudfar',
+    'relationship_type_godfather_with_name' => ':name’s gudförälder',
     'relationship_type_godfather_female_with_name' => ':name\'s gudmamma',
-    'relationship_type_godfather_male_with_name' => ':name’s godfather',
+    'relationship_type_godfather_male_with_name' => ':name’s gudfar',
 
-    'relationship_type_godson' => 'godchild',
+    'relationship_type_godson' => 'gudson/-dotter',
     'relationship_type_godson_female' => 'guddotter',
-    'relationship_type_godson_male' => 'godson',
-    'relationship_type_godson_with_name' => ':name’s godchild',
+    'relationship_type_godson_male' => 'gudson',
+    'relationship_type_godson_with_name' => ':name’s gudson/-dotter',
     'relationship_type_godson_female_with_name' => ':name\'s guddotter',
-    'relationship_type_godson_male_with_name' => ':name’s godson',
+    'relationship_type_godson_male_with_name' => ':name’s gudson',
 
     'relationship_type_friend' => 'vän',
     'relationship_type_friend_female' => 'vännina',
+    'relationship_type_friend_male' => 'vän',
     'relationship_type_friend_with_name' => ':name\'s vännina',
     'relationship_type_friend_female_with_name' => ':name\'s vän',
+    'relationship_type_friend_male_with_name' => ':name’s vän',
 
     'relationship_type_bestfriend' => 'bästa vän',
     'relationship_type_bestfriend_female' => 'bästa vän',
+    'relationship_type_bestfriend_male' => 'bästa vän',
     'relationship_type_bestfriend_with_name' => ':name\'s bästa vän',
     'relationship_type_bestfriend_female_with_name' => ':name\'s bästa vän',
+    'relationship_type_bestfriend_male_with_name' => ':name\'s bästa vän',
 
     'relationship_type_colleague' => 'kollega',
     'relationship_type_colleague_female' => 'kollega',
+    'relationship_type_colleague_male' => 'kollega',
     'relationship_type_colleague_with_name' => ':name\'s kollega',
     'relationship_type_colleague_female_with_name' => ':name\'s kollega',
+    'relationship_type_colleague_male_with_name' => ':name\'s kollega',
 
     'relationship_type_boss' => 'chef',
     'relationship_type_boss_female' => 'chef',
+    'relationship_type_boss_male' => 'chef',
     'relationship_type_boss_with_name' => ':name\'s chef',
     'relationship_type_boss_female_with_name' => ':name\'s chef',
+    'relationship_type_boss_male_with_name' => ':name\'s chef',
 
     'relationship_type_subordinate' => 'underordnad',
     'relationship_type_subordinate_female' => 'underordnad',
+    'relationship_type_subordinate_male' => 'underordnad',
     'relationship_type_subordinate_with_name' => ':name\'s underordnade',
     'relationship_type_subordinate_female_with_name' => ':name\'s underordnade',
+    'relationship_type_subordinate_male_with_name' => ':name\'s underordnade',
 
     'relationship_type_mentor' => 'mentor',
     'relationship_type_mentor_female' => 'mentor',
+    'relationship_type_mentor_male' => 'mentor',
     'relationship_type_mentor_with_name' => ':name\'s mentor',
     'relationship_type_mentor_female_with_name' => ':name\'s mentor',
+    'relationship_type_mentor_male_with_name' => ':name\'s mentor',
 
-    'relationship_type_protege' => 'protégé',
-    'relationship_type_protege_female' => 'protégé',
-    'relationship_type_protege_with_name' => ':name’s protégé',
-    'relationship_type_protege_female_with_name' => ':name’s protégé',
+    'relationship_type_protege' => 'skyddsling',
+    'relationship_type_protege_female' => 'skyddsling',
+    'relationship_type_protege_male' => 'skyddsling',
+    'relationship_type_protege_with_name' => ':name\'s skyddsling',
+    'relationship_type_protege_female_with_name' => ':name\'s skyddsling',
+    'relationship_type_protege_male_with_name' => ':name\'s skyddsling',
 
-    'relationship_type_ex_husband' => 'ex-spouse',
+    'relationship_type_ex_husband' => 'ex-make',
     'relationship_type_ex_husband_female' => 'ex-fru',
-    'relationship_type_ex_husband_male' => 'ex-husband',
-    'relationship_type_ex_husband_with_name' => ':name’s ex-spouse',
+    'relationship_type_ex_husband_male' => 'ex-make',
+    'relationship_type_ex_husband_with_name' => ':name’s ex-make',
     'relationship_type_ex_husband_female_with_name' => ':name\'s ex-fru',
-    'relationship_type_ex_husband_male_with_name' => ':name’s ex-husband',
+    'relationship_type_ex_husband_male_with_name' => ':name’s ex-make',
 
     // emotions
     'emotion_primary_love' => 'Kärlek',
@@ -465,62 +495,62 @@ return [
     'emotion_dread' => 'Fruktan',
 
     // weather
-    'weather_sunny' => 'Sunny',
-    'weather_clear' => 'Clear',
-    'weather_clear-day' => 'Clear',
+    'weather_sunny' => 'Soligt',
+    'weather_clear' => 'Klart',
+    'weather_clear-day' => 'Klar',
     'weather_clear-night' => 'Klart (natt)',
-    'weather_light-drizzle' => 'Light drizzle',
-    'weather_patchy-light-drizzle' => 'Patchy light drizzle',
-    'weather_patchy-light-rain' => 'Patchy light rain',
-    'weather_light-rain' => 'Light rain',
-    'weather_moderate-rain-at-times' => 'Moderate rain at times',
-    'weather_moderate-rain' => 'Moderate rain',
-    'weather_patchy-rain-possible' => 'Patchy rain possible',
-    'weather_heavy-rain-at-times' => 'Heavy rain at times',
-    'weather_heavy-rain' => 'Heavy rain',
-    'weather_light-freezing-rain' => 'Light freezing rain',
-    'weather_moderate-or-heavy-freezing-rain' => 'Moderate or heavy freezing rain',
-    'weather_light-sleet' => 'Light sleet',
-    'weather_moderate-or-heavy-rain-shower' => 'Moderate or heavy rain shower',
-    'weather_light-rain-shower' => 'Light rain shower',
-    'weather_torrential-rain-shower' => 'Torrential rain shower',
+    'weather_light-drizzle' => 'Lätt duggregn',
+    'weather_patchy-light-drizzle' => 'Fläckvis lätt duggregn',
+    'weather_patchy-light-rain' => 'Fläckvis lätt regn',
+    'weather_light-rain' => 'Lätt regn',
+    'weather_moderate-rain-at-times' => 'Måttligt regn ibland',
+    'weather_moderate-rain' => 'Måttligt regn',
+    'weather_patchy-rain-possible' => 'Möjligen fläckvisa skurar',
+    'weather_heavy-rain-at-times' => 'Möjligen mycket regn',
+    'weather_heavy-rain' => 'Spöregn',
+    'weather_light-freezing-rain' => 'Lätt underkylt regn',
+    'weather_moderate-or-heavy-freezing-rain' => 'Måttlig eller kraftigt underkylt regn',
+    'weather_light-sleet' => 'Lätt snöblandat',
+    'weather_moderate-or-heavy-rain-shower' => 'Måttliga eller kraftiga regnskurar',
+    'weather_light-rain-shower' => 'Lätta regnskurar',
+    'weather_torrential-rain-shower' => 'Skyfall',
     'weather_rain' => 'Regn',
     'weather_snow' => 'Snö',
-    'weather_blowing-snow' => 'Blowing snow',
-    'weather_patchy-light-snow' => 'Patchy light snow',
-    'weather_light-snow' => 'Light snow',
-    'weather_patchy-moderate-snow' => 'Patchy moderate snow',
-    'weather_moderate-snow' => 'Moderate snow',
-    'weather_patchy-heavy-snow' => 'Patchy heavy snow',
-    'weather_heavy-snow' => 'Heavy snow',
-    'weather_light-snow-showers' => 'Light snow showers',
-    'weather_moderate-or-heavy-snow-showers' => 'Moderate or heavy snow showers',
-    'weather_patchy-snow-possible' => 'Patchy snow possible',
-    'weather_patchy-sleet-possible' => 'Patchy sleet possible',
-    'weather_moderate-or-heavy-sleet' => 'Moderate or heavy sleet',
-    'weather_light-sleet-showers' => 'Light sleet showers',
-    'weather_moderate-or-heavy-sleet-showers' => 'Moderate or heavy sleet showers',
+    'weather_blowing-snow' => 'Snövindar',
+    'weather_patchy-light-snow' => 'Delvis lätt snöfall',
+    'weather_light-snow' => 'Lätt snö',
+    'weather_patchy-moderate-snow' => 'Fläckvis måttlig snö',
+    'weather_moderate-snow' => 'Måttligt snöfall',
+    'weather_patchy-heavy-snow' => 'Fläckvis kraftigt snöfall',
+    'weather_heavy-snow' => 'Kraftigt snöfall',
+    'weather_light-snow-showers' => 'Lätta snöbyar',
+    'weather_moderate-or-heavy-snow-showers' => 'Måttliga eller kraftiga snöbyar',
+    'weather_patchy-snow-possible' => 'Fläckvist snöfall möjligt',
+    'weather_patchy-sleet-possible' => 'Fläckvis snöblandat regn möjligt',
+    'weather_moderate-or-heavy-sleet' => 'Måttligt eller kraftigt snöblandat regn',
+    'weather_light-sleet-showers' => 'Lätt snöblandat regn',
+    'weather_moderate-or-heavy-sleet-showers' => 'Måttligt eller tungt snöblandat regn',
     'weather_sleet' => 'Nöje',
     'weather_wind' => 'Vind',
     'weather_fog' => 'Dimma',
-    'weather_freezing-fog' => 'Freezing fog',
-    'weather_mist' => 'Mist',
-    'weather_blizzard' => 'Blizzard',
-    'weather_overcast' => 'Overcast',
+    'weather_freezing-fog' => 'Underkyld dimma',
+    'weather_mist' => 'Dimma',
+    'weather_blizzard' => 'Snöstorm',
+    'weather_overcast' => 'Mulet',
     'weather_cloudy' => 'Molnigt',
-    'weather_partly-cloudy-day' => 'Partly cloudy',
-    'weather_partly-cloudy-night' => 'Partly cloudy',
-    'weather_freezing-drizzle' => 'Freezing drizzle',
-    'weather_heavy-freezing-drizzle' => 'Heavy freezing drizzle',
-    'weather_patchy-freezing-drizzle-possible' => 'Patchy freezing drizzle possible',
-    'weather_ice-pellets' => 'Ice pellets',
-    'weather_light-showers-of-ice-pellets' => 'Light showers of ice pellets',
-    'weather_moderate-or-heavy-showers-of-ice-pellets' => 'Moderate or heavy showers of ice pellets',
-    'weather_thundery-outbreaks-possible' => 'Thundery outbreaks possible',
-    'weather_patchy-light-rain-with-thunder' => 'Patchy light rain with thunder',
-    'weather_moderate-or-heavy-rain-with-thunder' => 'Moderate or heavy rain with thunder',
-    'weather_patchy-light-snow-with-thunder' => 'Patchy light snow with thunder',
-    'weather_moderate-or-heavy-snow-with-thunder' => 'Moderate or heavy snow with thunder',
+    'weather_partly-cloudy-day' => 'Växlande molnighet',
+    'weather_partly-cloudy-night' => 'Växlande molnighet',
+    'weather_freezing-drizzle' => 'Underkylt duggregn',
+    'weather_heavy-freezing-drizzle' => 'Kraftigt underkylt duggregn',
+    'weather_patchy-freezing-drizzle-possible' => 'Fäckvis underkylt duggren möjligt',
+    'weather_ice-pellets' => 'Hagel',
+    'weather_light-showers-of-ice-pellets' => 'Lätta skurar av hagel',
+    'weather_moderate-or-heavy-showers-of-ice-pellets' => 'Måttliga eller tunga skurar av hagel',
+    'weather_thundery-outbreaks-possible' => 'Möjlighet till åska',
+    'weather_patchy-light-rain-with-thunder' => 'Fläckvis lätt regn med åska',
+    'weather_moderate-or-heavy-rain-with-thunder' => 'Måttliga eller tunga åskskurar',
+    'weather_patchy-light-snow-with-thunder' => 'Fläckvis snö med åska',
+    'weather_moderate-or-heavy-snow-with-thunder' => 'Måttlig eller tung snö med åskbyar',
     'weather_current_temperature_celsius' => ':temperatur °C',
     'weather_current_temperature_fahrenheit' => ':temperatur °F',
     'weather_current_title' => 'Aktuell väderikon',
@@ -535,7 +565,7 @@ return [
 
     // contact list
     'contact_list_avatar' => 'Avatar',
-    'contact_list_name' => 'Contact',
-    'contact_list_description' => 'Description',
+    'contact_list_name' => 'Kontakt',
+    'contact_list_description' => 'Beskrivning',
 
 ];
