@@ -140,8 +140,10 @@ return [
 
     'relationship_type_partner' => 'sevgili',
     'relationship_type_partner_female' => 'sevgili',
+    'relationship_type_partner_male' => 'significant other',
     'relationship_type_partner_with_name' => ':name kişisinin sevgilisi',
     'relationship_type_partner_female_with_name' => ':name kişisinin sevgilisi',
+    'relationship_type_partner_male_with_name' => ':name’s significant other',
 
     'relationship_type_spouse' => 'eş',
     'relationship_type_spouse_female' => 'wife',
@@ -152,23 +154,31 @@ return [
 
     'relationship_type_date' => 'flört',
     'relationship_type_date_female' => 'flört',
+    'relationship_type_date_male' => 'date',
     'relationship_type_date_with_name' => ':name kişisinin flörtü',
     'relationship_type_date_female_with_name' => ':name kişisinin flörtü',
+    'relationship_type_date_male_with_name' => ':name’s date',
 
     'relationship_type_lover' => 'aşık',
     'relationship_type_lover_female' => 'aşık',
+    'relationship_type_lover_male' => 'lover',
     'relationship_type_lover_with_name' => ':name kişisinin aşığı',
     'relationship_type_lover_female_with_name' => ':name kişisinin aşığı',
+    'relationship_type_lover_male_with_name' => ':name’s lover',
 
     'relationship_type_inlovewith' => 'aşık olduğu',
     'relationship_type_inlovewith_female' => 'aşık olduğu',
+    'relationship_type_inlovewith_male' => 'in love with',
     'relationship_type_inlovewith_with_name' => ':name kişisinin aşık olduğu kişi',
     'relationship_type_inlovewith_female_with_name' => ':name kişisinin aşık olduğu kişi',
+    'relationship_type_inlovewith_male_with_name' => 'someone :name is in love with',
 
     'relationship_type_lovedby' => 'gizli aşık',
     'relationship_type_lovedby_female' => 'gizli aşık',
+    'relationship_type_lovedby_male' => 'loved by',
     'relationship_type_lovedby_with_name' => ':name kişisinin gizli aşığı',
     'relationship_type_lovedby_female_with_name' => ':name kişisinin gizli aşığı',
+    'relationship_type_lovedby_male_with_name' => ':name’s secret lover',
 
     'relationship_type_ex' => 'ex-partner',
     'relationship_type_ex_female' => 'eski kız arkadaş',
@@ -228,18 +238,24 @@ return [
 
     'relationship_type_uncle' => 'amca/dayı',
     'relationship_type_uncle_female' => 'hala/teyze',
+    'relationship_type_uncle_male' => 'uncle',
     'relationship_type_uncle_with_name' => ':name kişisinin amcası/dayısı',
     'relationship_type_uncle_female_with_name' => ':name kişisinin halası/teyzesi',
+    'relationship_type_uncle_male_with_name' => ':name’s uncle',
 
     'relationship_type_nephew' => 'yeğen',
     'relationship_type_nephew_female' => 'yeğen',
+    'relationship_type_nephew_male' => 'nephew',
     'relationship_type_nephew_with_name' => ':name kişisinin yeğeni',
     'relationship_type_nephew_female_with_name' => ':name kişisinin yeğeni',
+    'relationship_type_nephew_male_with_name' => ':name’s nephew',
 
     'relationship_type_cousin' => 'kuzen',
     'relationship_type_cousin_female' => 'kuzen',
+    'relationship_type_cousin_male' => 'cousin',
     'relationship_type_cousin_with_name' => ':name kişisinin kuzeni',
     'relationship_type_cousin_female_with_name' => ':name kişisinin kuzeni',
+    'relationship_type_cousin_male_with_name' => ':name’s cousin',
 
     'relationship_type_godfather' => 'godparent',
     'relationship_type_godfather_female' => 'vaftiz anası',
@@ -257,38 +273,52 @@ return [
 
     'relationship_type_friend' => 'arkadaş',
     'relationship_type_friend_female' => 'arkadaş',
+    'relationship_type_friend_male' => 'friend',
     'relationship_type_friend_with_name' => ':name kişisinin arkadaşı',
     'relationship_type_friend_female_with_name' => ':name kişisinin arkadaşı',
+    'relationship_type_friend_male_with_name' => ':name’s friend',
 
     'relationship_type_bestfriend' => 'en iyi arkadaş',
     'relationship_type_bestfriend_female' => 'en iyi arkadaş',
+    'relationship_type_bestfriend_male' => 'best friend',
     'relationship_type_bestfriend_with_name' => ':name kişisinin en iyi arkadaşı',
     'relationship_type_bestfriend_female_with_name' => ':name kişisinin en iyi arkadaşı',
+    'relationship_type_bestfriend_male_with_name' => ':name’s best friend',
 
     'relationship_type_colleague' => 'iş arkadaşı',
     'relationship_type_colleague_female' => 'iş arkadaşı',
+    'relationship_type_colleague_male' => 'colleague',
     'relationship_type_colleague_with_name' => ':name kişisinin iş arkadaşı',
     'relationship_type_colleague_female_with_name' => ':name kişisinin iş arkadaşı',
+    'relationship_type_colleague_male_with_name' => ':name’s colleague',
 
     'relationship_type_boss' => 'patron',
     'relationship_type_boss_female' => 'patron',
+    'relationship_type_boss_male' => 'boss',
     'relationship_type_boss_with_name' => ':name kişisinin patronu',
     'relationship_type_boss_female_with_name' => ':name kişisinin patronu',
+    'relationship_type_boss_male_with_name' => ':name’s boss',
 
     'relationship_type_subordinate' => 'altında çalışan',
     'relationship_type_subordinate_female' => 'altında çalışan',
+    'relationship_type_subordinate_male' => 'subordinate',
     'relationship_type_subordinate_with_name' => ':name kişisinin altında çalışan',
     'relationship_type_subordinate_female_with_name' => ':name kişisinin altında çalışan',
+    'relationship_type_subordinate_male_with_name' => ':name’s subordinate',
 
     'relationship_type_mentor' => 'danışman',
     'relationship_type_mentor_female' => 'danışman',
+    'relationship_type_mentor_male' => 'mentor',
     'relationship_type_mentor_with_name' => ':name kişisinin danışmanı',
     'relationship_type_mentor_female_with_name' => ':name kişisinin danışmanı',
+    'relationship_type_mentor_male_with_name' => ':name’s mentor',
 
     'relationship_type_protege' => 'protégé',
     'relationship_type_protege_female' => 'protégé',
+    'relationship_type_protege_male' => 'protégé',
     'relationship_type_protege_with_name' => ':name’s protégé',
     'relationship_type_protege_female_with_name' => ':name’s protégé',
+    'relationship_type_protege_male_with_name' => ':name’s protégé',
 
     'relationship_type_ex_husband' => 'ex-spouse',
     'relationship_type_ex_husband_female' => 'eski karı',
