@@ -10,29 +10,29 @@ return [
 
     //index
     'people_not_found' => 'Контакт не знайдено',
-    'people_list_number_kids' => ':count child|:count children',
+    'people_list_number_kids' => ':count дитина|:count дітей',
     'people_list_last_updated' => 'Остання консультація:',
-    'people_list_number_reminders' => ':count reminder|:count reminders',
+    'people_list_number_reminders' => ':count нагадування|:count нагадувань',
     'people_list_blank_title' => 'У вас ще нікого немає',
     'people_list_blank_cta' => 'Додати когось',
     'people_list_sort' => 'Упорядкувати',
-    'people_list_stats' => ':count contact|:count contacts',
+    'people_list_stats' => ':count контакт|:count контактів',
     'people_list_firstnameAZ' => 'Сортувати за іменем А → Я',
     'people_list_firstnameZA' => 'Сортувати за іменем Я → А',
     'people_list_lastnameAZ' => 'Сортувати за прізвищем А → Я',
     'people_list_lastnameZA' => 'Сортувати за прізвищем Я → А',
-    'people_list_lastactivitydateNewtoOld' => 'Sort by last activity date, newest to oldest',
-    'people_list_lastactivitydateOldtoNew' => 'Sort by last activity date, oldest to newest',
+    'people_list_lastactivitydateNewtoOld' => 'Сортувати за датою останньої активності, від новіших до старіших',
+    'people_list_lastactivitydateOldtoNew' => 'Сортувати за датою останньої активності, від старіших до новіших',
     'people_list_filter_tag' => 'Показано всі контакти, відмічені',
     'people_list_clear_filter' => 'Очистити фільтр',
-    'people_list_contacts_per_tags' => ':count contact|:count contacts',
+    'people_list_contacts_per_tags' => ':count контакт|:count контактів',
     'people_list_show_dead' => 'Показати померлих (:count)',
     'people_list_hide_dead' => 'Приховати померлих людей (:count)',
-    'people_search' => 'Search your contacts…',
+    'people_search' => 'Знайти ваші контакти…',
     'people_search_no_results' => 'Результатів не знайдено',
     'people_search_next' => 'Далі',
-    'people_search_prev' => 'Previous',
-    'people_search_rows_per_page' => 'Rows per page',
+    'people_search_prev' => 'Назад',
+    'people_search_rows_per_page' => 'Рядків на сторінку',
     'people_search_of' => 'з',
     'people_search_page' => 'Сторінка',
     'people_search_all' => 'Усі',
@@ -42,29 +42,29 @@ return [
     'people_list_account_upgrade_cta' => 'Оновіть тарифний план',
     'people_list_untagged' => 'Переглянути контакти без міток',
     'people_list_filter_untag' => 'Показано всі контакти без міток',
-    'archived_contact_readonly' => 'Archived contact can’t be edited, please unarchive it first.',
+    'archived_contact_readonly' => 'Архівні контакти не можна редагувати. Будь ласка, спершу розархівуйте.',
 
     // people add
     'people_add_title' => 'Додати нову особу',
-    'people_add_missing' => 'No person found – add a new one now',
+    'people_add_missing' => 'Не знайдено жодної людини – додайте нову зараз',
     'people_add_firstname' => 'Ім\'я',
-    'people_add_middlename' => 'Middle name (optional)',
-    'people_add_lastname' => 'Last name (optional)',
-    'people_add_email' => 'Email (optional)',
-    'people_add_nickname' => 'Nickname (optional)',
+    'people_add_middlename' => 'По батькові (необовʼязково)',
+    'people_add_lastname' => 'Прізвище (необовʼязково)',
+    'people_add_email' => 'Електронна пошта (необовʼязково)',
+    'people_add_nickname' => 'Прізвисько (необовʼязково)',
     'people_add_cta' => 'Додати',
     'people_save_and_add_another_cta' => 'Надіслати і додати когось іншого',
     'people_add_success' => ':name було успішно створено',
     'people_add_gender' => 'Стать',
     'people_delete_success' => 'Контакт видалено',
     'people_delete_message' => 'Видалити контакт',
-    'people_delete_confirmation' => 'Are you sure you want to delete :name’s contact? Deletion is immediate and permanent.',
+    'people_delete_confirmation' => 'Ви впевнені, що хочете видалити :name? Видалення є миттєвим і незворотним.',
     'people_add_birthday_reminder' => 'Привітайте з днем народження :name',
-    'people_add_birthday_reminder_deceased' => 'On this date, :name would have celebrated their birthday',
+    'people_add_birthday_reminder_deceased' => 'У цей день :name святкував би свій день народження',
     'people_add_import' => 'Ви хочете <a href=":url">імпортувати ваші контакти</a>?',
     'people_edit_email_error' => 'Обліковий запис з цією електронною адресою вже існує. Будь ласка, оберіть іншу.',
     'people_export' => 'Експортувати як vCard',
-    'people_add_reminder_for_birthday' => 'Create an annual birthday reminder',
+    'people_add_reminder_for_birthday' => 'Створити щорічне нагадування про день народження',
 
     // show
     'section_contact_information' => 'Контактна інформація',
@@ -82,50 +82,50 @@ return [
     'me' => 'Це ви',
     'edit_contact_information' => 'Редагувати контактну інформацію',
     'contact_archive' => 'Архівувати контакт',
-    'contact_unarchive' => 'Unarchive contact',
-    'contact_archive_help' => 'Archived contacts are not be shown on the contact list, but still appear in search results.',
-    'call_button' => 'Log a call',
-    'set_favorite' => 'Favorite contacts are placed at the top of the contact list',
+    'contact_unarchive' => 'Розархівувати контакт',
+    'contact_archive_help' => 'Архівовані контакти не показуються в списку контактів, але показуються в результатах пошуку.',
+    'call_button' => 'Записати дзвінок',
+    'set_favorite' => 'Улюблені контакти показуються на початку списку контактів',
 
     // Stay in touch
-    'stay_in_touch' => 'Stay in touch',
-    'stay_in_touch_frequency' => 'Stay in touch every day|Stay in touch every {count} days',
-    'stay_in_touch_next_date' => 'Next due: {date}',
-    'stay_in_touch_invalid' => 'The frequency must be a number greater than 0.',
+    'stay_in_touch' => 'Підтримуйте звʼязок',
+    'stay_in_touch_frequency' => 'Звʼязуйтеся кожного дня|Звʼязуйтеся кожні {count} днів',
+    'stay_in_touch_next_date' => 'Наступна подія: {date}',
+    'stay_in_touch_invalid' => 'Частота має більшою за 0.',
     'stay_in_touch_premium' => 'You need to upgrade your account to make use of this feature',
-    'stay_in_touch_modal_title' => 'Stay in touch',
-    'stay_in_touch_modal_desc' => 'We can remind you by email to keep in touch with {firstname} at a regular interval.',
-    'stay_in_touch_modal_label' => 'Send me an email every… {count} day|Send me an email every… {count} days',
+    'stay_in_touch_modal_title' => 'Підтримуйте звʼязок',
+    'stay_in_touch_modal_desc' => 'Ми можемо періодично нагадувати вам електронною поштою про підтримування звʼязку з {firstname}.',
+    'stay_in_touch_modal_label' => 'Відправляти мені електронного листа кожен… {count} день|Відправляти мені електронного листа кожні… {count} дні',
 
     // Calls
-    'modal_call_title' => 'Log a call',
-    'modal_call_comment' => 'What did you talk about? (optional)',
-    'modal_call_exact_date' => 'The phone call happened on',
-    'modal_call_who_called' => 'Who called?',
-    'modal_call_emotion' => 'Do you want to log how you felt during this call? (optional)',
-    'calls_add_success' => 'The phone call has been saved.',
-    'call_delete_confirmation' => 'Are you sure you want to delete this call?',
-    'call_delete_success' => 'The call has been deleted successfully',
-    'call_title' => 'Phone calls',
-    'call_empty_comment' => 'No details',
-    'call_blank_title' => 'Keep track of the phone calls you’ve done with {name}',
-    'call_blank_desc' => 'You called {name}',
-    'call_you_called' => 'You called',
-    'call_he_called' => '{name} called',
-    'call_emotions' => 'Emotions:',
+    'modal_call_title' => 'Записати дзвінок',
+    'modal_call_comment' => 'Про що ви говорили? (необовʼязково)',
+    'modal_call_exact_date' => 'Дзвінок відбувся',
+    'modal_call_who_called' => 'Хто дзвонив?',
+    'modal_call_emotion' => 'Хочете записати, як ви почувалися під час цього дзвінка? (необовʼязково)',
+    'calls_add_success' => 'Дзвінок збережено.',
+    'call_delete_confirmation' => 'Ви точно хочете видалити цей дзвінок?',
+    'call_delete_success' => 'Дзвінок було успішно видалено',
+    'call_title' => 'Дзвінки',
+    'call_empty_comment' => 'Немає подробиць',
+    'call_blank_title' => 'Записуйте спільні дзвінки з {name}',
+    'call_blank_desc' => 'Ви дзвонили до {name}',
+    'call_you_called' => 'Ви дзвонили',
+    'call_he_called' => '{name} дзвонив',
+    'call_emotions' => 'Емоції:',
 
     // Conversation
-    'conversation_blank' => 'Record conversations you have with :name on social media, SMS…',
-    'conversation_delete_link' => 'Delete the conversation',
-    'conversation_edit_title' => 'Edit conversation',
-    'conversation_edit_delete' => 'Are you sure you want to delete this conversation? Deletion is permanent.',
-    'conversation_add_success' => 'The conversation has been successfully added.',
-    'conversation_edit_success' => 'The conversation has been successfully updated.',
-    'conversation_delete_success' => 'The conversation has been successfully deleted.',
-    'conversation_add_title' => 'Record a new conversation',
-    'conversation_add_when' => 'When did you have this conversation?',
-    'conversation_add_who_wrote' => 'Who sent this message?',
-    'conversation_add_how' => 'How did you communicate?',
+    'conversation_blank' => 'Записуйте розмови з :name у соціальних мережах, SMS…',
+    'conversation_delete_link' => 'Видалити розмову',
+    'conversation_edit_title' => 'Редагувати розмову',
+    'conversation_edit_delete' => 'Ви точно хочете видалити цю розмову? Видалення є незворотним.',
+    'conversation_add_success' => 'Розмову було успішно додано.',
+    'conversation_edit_success' => 'Розмову було успішно змінено.',
+    'conversation_delete_success' => 'Розмову було успішно видалено.',
+    'conversation_add_title' => 'Записати нову розмову',
+    'conversation_add_when' => 'Коли ця розмова відбулася?',
+    'conversation_add_who_wrote' => 'Хто відправив це повідомлення?',
+    'conversation_add_how' => 'Як ви спілкувалися?',
     'conversation_add_you' => 'Ви',
     'conversation_add_content' => 'Запишіть, що було сказано',
     'conversation_add_what_was_said' => 'Що ви сказали?',
@@ -137,14 +137,14 @@ return [
     'conversation_list_cta' => 'Журнал розмов',
 
     // age - birthday
-    'birthdate_not_set' => 'Birthday is not set',
+    'birthdate_not_set' => 'День народження не вказано',
     'age_approximate_in_years' => 'близько :age років',
     'age_exact_in_years' => ':age років',
     'age_exact_birthdate' => 'народився :date',
 
     // Last called
     'last_called' => 'Останній виклик: :date',
-    'last_talked_to' => 'Last called: {date}',
+    'last_talked_to' => 'Останній дзвінок: {date}',
     'last_called_empty' => 'Останній виклик: невідомо',
     'last_activity_date' => 'Остання активність разом: :date',
     'last_activity_date_empty' => 'Остання активність разом: невідомо',
@@ -155,18 +155,18 @@ return [
     'information_edit_max_size' => 'Максимально :size кілобайт.',
     'information_edit_max_size2' => 'Максимально :size кілобайт.',
     'information_edit_firstname' => 'Ім\'я',
-    'information_edit_lastname' => 'Last name (optional)',
-    'information_edit_description' => 'Description (optional)',
+    'information_edit_lastname' => 'Прізвище (необовʼязково)',
+    'information_edit_description' => 'Опис (необовʼязково)',
     'information_edit_description_help' => 'Використовується в списку контактів, щоб додати деякий контекст, якщо це необхідно.',
     'information_edit_unknown' => 'Я не знаю віку цієї людини',
-    'information_edit_probably' => 'This person is probably…',
-    'information_edit_not_year' => 'I know the day and month of this person’s birthday, but not the year…',
-    'information_edit_exact' => 'I know this person’s exact birthday…',
-    'information_edit_birthdate_label' => 'Birthday',
+    'information_edit_probably' => 'Ця людина, ймовірно,…',
+    'information_edit_not_year' => 'Я знаю день і місяць народження цієї людини, але не рік…',
+    'information_edit_exact' => 'Я знаю точний день народження цієї людини…',
+    'information_edit_birthdate_label' => 'День народження',
     'information_no_work_defined' => 'Інформацію про роботу не визначено',
     'information_work_at' => 'у :company',
     'work_add_cta' => 'Оновити інформацію про роботу',
-    'work_edit_success' => 'Work information updated',
+    'work_edit_success' => 'Інформація про роботу оновлена',
     'work_edit_title' => 'Оновити інформацію про роботу :name',
     'work_edit_job' => 'Посада (необов\'язково)',
     'work_edit_company' => 'Компанія (необов\'язково)',
@@ -177,52 +177,52 @@ return [
     'food_preferences_edit_description' => 'Можливо, :firstname або хтось у родині :family має алергію або не любить конкретну пляшку вина. Вкажіть їх тут, щоб ви пам\'ятали наступного разу, коли запросите їх на вечерю',
     'food_preferences_edit_description_no_last_name' => 'Можливо, :firstname або хтось у родині :family має алергію або не любить конкретну пляшку вина. Вкажіть їх тут, щоб ви пам\'ятали наступного разу, коли запросите їх на вечерю',
     'food_preferences_edit_title' => 'Вкажіть вподобання у їжі',
-    'food_preferences_edit_cta' => 'Save food preferences',
-    'food_preferences_title' => 'Food preferences',
-    'food_preferences_cta' => 'Add food preferences',
+    'food_preferences_edit_cta' => 'Зберегти уподобання їжі',
+    'food_preferences_title' => 'Вподобання їжі',
+    'food_preferences_cta' => 'Додати уподобання їжі',
 
     // reminders
-    'reminders_blank_title' => 'Is there something you want to be reminded of about :name?',
-    'reminders_blank_add_activity' => 'Add a reminder',
-    'reminders_add_title' => 'What would you like to be reminded of about :name?',
-    'reminders_add_description' => 'Please remind me to…',
-    'reminders_add_next_time' => 'When is the next time you would like to be reminded about this?',
-    'reminders_add_once' => 'Remind me about this just once',
-    'reminders_add_recurrent' => 'Remind me about this every',
-    'reminders_add_starting_from' => 'starting from the date specified above',
-    'reminders_add_cta' => 'Add reminder',
-    'reminders_edit_update_cta' => 'Update reminder',
-    'reminders_add_error_custom_text' => 'You need to indicate a text for this reminder',
-    'reminders_create_success' => 'The reminder has been added successfully',
-    'reminders_delete_success' => 'The reminder has been deleted successfully',
-    'reminders_update_success' => 'The reminder has been updated successfully',
-    'reminders_add_optional_comment' => 'Optional comment',
+    'reminders_blank_title' => 'Хочете отримати нагадування про щось щодо :name?',
+    'reminders_blank_add_activity' => 'Додати нагадування',
+    'reminders_add_title' => 'Про що ви хочете отримати нагадування щодо :name?',
+    'reminders_add_description' => 'Будь ласка, нагадайте мені…',
+    'reminders_add_next_time' => 'Коли ви хочете отримати наступне нагадування про це?',
+    'reminders_add_once' => 'Нагадати один раз',
+    'reminders_add_recurrent' => 'Нагадувати кожні',
+    'reminders_add_starting_from' => 'від вказаної вище дати',
+    'reminders_add_cta' => 'Додати нагадування',
+    'reminders_edit_update_cta' => 'Змінити нагадування',
+    'reminders_add_error_custom_text' => 'Необхідно вказати текст цього нагадування',
+    'reminders_create_success' => 'Нагадування було успішно додано',
+    'reminders_delete_success' => 'Нагадування було успішно видалено',
+    'reminders_update_success' => 'Нагадування було успішно змінено',
+    'reminders_add_optional_comment' => 'Додатковий коментар',
 
-    'reminder_frequency_day' => 'every day|every :number days',
-    'reminder_frequency_week' => 'every week|every :number weeks',
-    'reminder_frequency_month' => 'every month|every :number months',
-    'reminder_frequency_year' => 'every year|every :number year',
-    'reminder_frequency_one_time' => 'on :date',
-    'reminders_delete_confirmation' => 'Are you sure you want to delete this reminder?',
-    'reminders_delete_cta' => 'Delete',
+    'reminder_frequency_day' => 'щодня|кожні :number днів',
+    'reminder_frequency_week' => 'щотижня|кожні :number тижнів',
+    'reminder_frequency_month' => 'щомісяця|кожні :number місяців',
+    'reminder_frequency_year' => 'щороку|кожні :number років',
+    'reminder_frequency_one_time' => ':date',
+    'reminders_delete_confirmation' => 'Ви точно хочете видалити це нагадування?',
+    'reminders_delete_cta' => 'Видалити',
     'reminders_next_expected_date' => 'on',
-    'reminders_cta' => 'Add a reminder',
-    'reminders_description' => 'We will send an email for each one of the reminders below. Reminders are sent every morning the day events will happen. Reminders automatically added for birthdays can not be deleted. If you want to change those dates, edit the birthday of the contacts.',
-    'reminders_one_time' => 'One time',
-    'reminders_type_week' => 'week',
-    'reminders_type_month' => 'month',
-    'reminders_type_year' => 'year',
-    'reminders_birthday' => 'Birthday of :name',
+    'reminders_cta' => 'Додати нагадування',
+    'reminders_description' => 'Ми відправимо електронного листа з кожним з перелічених далі нагадуванням. Нагадування відправляються зранку у день події. Нагадування про дні народження додаються автоматично і не можуть бути видаленими. Якщо хочете змінити дати, відредагуйте день народження контактів.',
+    'reminders_one_time' => 'Один раз',
+    'reminders_type_week' => 'тиждень',
+    'reminders_type_month' => 'місяць',
+    'reminders_type_year' => 'рік',
+    'reminders_birthday' => 'День народження :name',
     'reminders_free_plan_warning' => 'You are on the Free plan. No emails are sent on this plan. To receive your reminders by email, upgrade your account.',
 
     // relationships
-    'relationship_form_add' => 'Add a new relationship',
-    'relationship_form_edit' => 'Edit an existing relationship',
-    'relationship_form_is_with' => 'This person is…',
-    'relationship_form_is_with_name' => ':name is…',
+    'relationship_form_add' => 'Додати новий звʼязок',
+    'relationship_form_edit' => 'Редагувати звʼязок',
+    'relationship_form_is_with' => 'Ця людина є…',
+    'relationship_form_is_with_name' => ':name …',
     'relationship_form_add_choice' => 'Who is the relationship with?',
-    'relationship_form_create_contact' => 'Add a new person',
-    'relationship_form_associate_contact' => 'An existing contact',
+    'relationship_form_create_contact' => 'Додати нову особу',
+    'relationship_form_associate_contact' => 'Існуючий контакт',
     'relationship_form_associate_dropdown' => 'Search and select an existing contact from the dropdown below',
     'relationship_form_associate_dropdown_placeholder' => 'Search and select an existing contact',
     'relationship_form_also_create_contact' => 'Create a Contact entry for this person.',
@@ -234,27 +234,27 @@ return [
     'relationship_form_deletion_success' => 'The relationship has been deleted.',
 
     // tasks
-    'tasks_title' => 'Tasks',
-    'tasks_blank_title' => 'You don’t have any tasks yet.',
+    'tasks_title' => 'Завдання',
+    'tasks_blank_title' => 'У тебе немає ніяких завдань.',
     'tasks_form_title' => 'Title',
     'tasks_form_description' => 'Description (optional)',
-    'tasks_add_task' => 'Add a task',
+    'tasks_add_task' => 'Додати завдання',
     'tasks_delete_success' => 'The task has been deleted successfully',
     'tasks_complete_success' => 'The task has changed status successfully',
 
     // activities
     'activity_title' => 'Activities',
     'activity_type_category_simple_activities' => 'Simple activities',
-    'activity_type_category_sport' => 'Sport',
-    'activity_type_category_food' => 'Food',
+    'activity_type_category_sport' => 'Спорт',
+    'activity_type_category_food' => 'Їжа',
     'activity_type_category_cultural_activities' => 'Cultural activities',
     'activity_type_just_hung_out' => 'just hung out',
-    'activity_type_watched_movie_at_home' => 'watched a movie at home',
-    'activity_type_talked_at_home' => 'just talked at home',
-    'activity_type_did_sport_activities_together' => 'played a sport together',
-    'activity_type_ate_at_his_place' => 'ate at their place',
-    'activity_type_went_bar' => 'went to a bar',
-    'activity_type_ate_at_home' => 'ate at home',
+    'activity_type_watched_movie_at_home' => 'подивилися фільм вдома',
+    'activity_type_talked_at_home' => 'просто побалакали вдома',
+    'activity_type_did_sport_activities_together' => 'пограли разом в спорт',
+    'activity_type_ate_at_his_place' => 'поїли у нього/неї',
+    'activity_type_went_bar' => 'сходили до бару',
+    'activity_type_ate_at_home' => 'поїли вдома',
     'activity_type_picnicked' => 'picnicked',
     'activity_type_ate_restaurant' => 'ate at a restaurant',
     'activity_type_went_theater' => 'went to the theater',
