@@ -140,8 +140,10 @@ return [
 
     'relationship_type_partner' => 'điều trọng đại khác',
     'relationship_type_partner_female' => 'điều trọng đại khác',
+    'relationship_type_partner_male' => 'significant other',
     'relationship_type_partner_with_name' => 'người quan trọng với :name',
     'relationship_type_partner_female_with_name' => 'người quan trọng với :name',
+    'relationship_type_partner_male_with_name' => ':name’s significant other',
 
     'relationship_type_spouse' => 'vợ/chồng',
     'relationship_type_spouse_female' => 'wife',
@@ -152,23 +154,31 @@ return [
 
     'relationship_type_date' => 'hẹn hò',
     'relationship_type_date_female' => 'hẹn hò',
+    'relationship_type_date_male' => 'date',
     'relationship_type_date_with_name' => 'hẹn hò với :name',
     'relationship_type_date_female_with_name' => 'hẹn hò với :name',
+    'relationship_type_date_male_with_name' => ':name’s date',
 
     'relationship_type_lover' => 'người yêu',
     'relationship_type_lover_female' => 'người yêu',
+    'relationship_type_lover_male' => 'lover',
     'relationship_type_lover_with_name' => 'người yêu của :name',
     'relationship_type_lover_female_with_name' => 'người yêu của :name',
+    'relationship_type_lover_male_with_name' => ':name’s lover',
 
     'relationship_type_inlovewith' => 'có tình cảm với',
     'relationship_type_inlovewith_female' => 'có tình cảm với',
+    'relationship_type_inlovewith_male' => 'in love with',
     'relationship_type_inlovewith_with_name' => 'ai đó :name có tình cảm',
     'relationship_type_inlovewith_female_with_name' => 'ai đó :name có tình cảm',
+    'relationship_type_inlovewith_male_with_name' => 'someone :name is in love with',
 
     'relationship_type_lovedby' => 'được thích bởi',
     'relationship_type_lovedby_female' => 'được thích bởi',
+    'relationship_type_lovedby_male' => 'loved by',
     'relationship_type_lovedby_with_name' => 'người tình bí mật của :name',
     'relationship_type_lovedby_female_with_name' => 'người tình bí mật của :name',
+    'relationship_type_lovedby_male_with_name' => ':name’s secret lover',
 
     'relationship_type_ex' => 'ex-partner',
     'relationship_type_ex_female' => 'người yêu cũ',
@@ -228,18 +238,24 @@ return [
 
     'relationship_type_uncle' => 'chú/bác',
     'relationship_type_uncle_female' => 'cô/dì',
+    'relationship_type_uncle_male' => 'uncle',
     'relationship_type_uncle_with_name' => 'chú/bác của :name',
     'relationship_type_uncle_female_with_name' => 'cô/dì của :name',
+    'relationship_type_uncle_male_with_name' => ':name’s uncle',
 
     'relationship_type_nephew' => 'cháu trai',
     'relationship_type_nephew_female' => 'cháu gái',
+    'relationship_type_nephew_male' => 'nephew',
     'relationship_type_nephew_with_name' => 'cháu trai của :name',
     'relationship_type_nephew_female_with_name' => 'cháu gái của :name',
+    'relationship_type_nephew_male_with_name' => ':name’s nephew',
 
     'relationship_type_cousin' => 'anh em họ',
     'relationship_type_cousin_female' => 'anh em họ',
+    'relationship_type_cousin_male' => 'cousin',
     'relationship_type_cousin_with_name' => 'anh em họ của :name',
     'relationship_type_cousin_female_with_name' => 'anh em họ của :name',
+    'relationship_type_cousin_male_with_name' => ':name’s cousin',
 
     'relationship_type_godfather' => 'godparent',
     'relationship_type_godfather_female' => 'mẹ đỡ đầu',
@@ -257,38 +273,52 @@ return [
 
     'relationship_type_friend' => 'bạn bè',
     'relationship_type_friend_female' => 'bạn bè',
+    'relationship_type_friend_male' => 'friend',
     'relationship_type_friend_with_name' => 'bạn của :name',
     'relationship_type_friend_female_with_name' => 'bạn của :name',
+    'relationship_type_friend_male_with_name' => ':name’s friend',
 
     'relationship_type_bestfriend' => 'bạn thân',
     'relationship_type_bestfriend_female' => 'bạn thân',
+    'relationship_type_bestfriend_male' => 'best friend',
     'relationship_type_bestfriend_with_name' => 'bạn thân của :name',
     'relationship_type_bestfriend_female_with_name' => 'bạn thân của :name',
+    'relationship_type_bestfriend_male_with_name' => ':name’s best friend',
 
     'relationship_type_colleague' => 'đồng nghiệp',
     'relationship_type_colleague_female' => 'đồng nghiệp',
+    'relationship_type_colleague_male' => 'colleague',
     'relationship_type_colleague_with_name' => 'dồng nghiệp của :name',
     'relationship_type_colleague_female_with_name' => 'dồng nghiệp của :name',
+    'relationship_type_colleague_male_with_name' => ':name’s colleague',
 
     'relationship_type_boss' => 'sếp',
     'relationship_type_boss_female' => 'sếp',
+    'relationship_type_boss_male' => 'boss',
     'relationship_type_boss_with_name' => 'sếp của :name',
     'relationship_type_boss_female_with_name' => 'sếp của :name',
+    'relationship_type_boss_male_with_name' => ':name’s boss',
 
     'relationship_type_subordinate' => 'cấp dưới',
     'relationship_type_subordinate_female' => 'cấp dưới',
+    'relationship_type_subordinate_male' => 'subordinate',
     'relationship_type_subordinate_with_name' => 'cấp dưới của :name',
     'relationship_type_subordinate_female_with_name' => 'cấp dưới của :name',
+    'relationship_type_subordinate_male_with_name' => ':name’s subordinate',
 
     'relationship_type_mentor' => 'người hướng dẫn',
     'relationship_type_mentor_female' => 'người hướng dẫn',
+    'relationship_type_mentor_male' => 'mentor',
     'relationship_type_mentor_with_name' => 'người hướng dẫn của :name',
     'relationship_type_mentor_female_with_name' => 'người hướng dẫn của :name',
+    'relationship_type_mentor_male_with_name' => ':name’s mentor',
 
     'relationship_type_protege' => 'protégé',
     'relationship_type_protege_female' => 'protégé',
+    'relationship_type_protege_male' => 'protégé',
     'relationship_type_protege_with_name' => ':name’s protégé',
     'relationship_type_protege_female_with_name' => ':name’s protégé',
+    'relationship_type_protege_male_with_name' => ':name’s protégé',
 
     'relationship_type_ex_husband' => 'ex-spouse',
     'relationship_type_ex_husband_female' => 'vợ cũ',
