@@ -140,8 +140,10 @@ return [
 
     'relationship_type_partner' => '搭檔',
     'relationship_type_partner_female' => '搭檔',
+    'relationship_type_partner_male' => 'significant other',
     'relationship_type_partner_with_name' => ':name的搭檔',
     'relationship_type_partner_female_with_name' => ':name的搭檔',
+    'relationship_type_partner_male_with_name' => ':name’s significant other',
 
     'relationship_type_spouse' => '配偶',
     'relationship_type_spouse_female' => 'wife',
@@ -152,23 +154,31 @@ return [
 
     'relationship_type_date' => '約會物件',
     'relationship_type_date_female' => '約會物件',
+    'relationship_type_date_male' => 'date',
     'relationship_type_date_with_name' => ':name的約會物件',
     'relationship_type_date_female_with_name' => ':name的約會物件',
+    'relationship_type_date_male_with_name' => ':name’s date',
 
     'relationship_type_lover' => '情人',
     'relationship_type_lover_female' => '情人',
+    'relationship_type_lover_male' => 'lover',
     'relationship_type_lover_with_name' => ':name的情人',
     'relationship_type_lover_female_with_name' => ':name的情人',
+    'relationship_type_lover_male_with_name' => ':name’s lover',
 
     'relationship_type_inlovewith' => '喜歡的人',
     'relationship_type_inlovewith_female' => '喜歡的人',
+    'relationship_type_inlovewith_male' => 'in love with',
     'relationship_type_inlovewith_with_name' => ':name喜歡的人',
     'relationship_type_inlovewith_female_with_name' => ':name喜歡的人',
+    'relationship_type_inlovewith_male_with_name' => 'someone :name is in love with',
 
     'relationship_type_lovedby' => '追求者',
     'relationship_type_lovedby_female' => '追求者',
+    'relationship_type_lovedby_male' => 'loved by',
     'relationship_type_lovedby_with_name' => ':name的追求者',
     'relationship_type_lovedby_female_with_name' => ':name的追求者',
+    'relationship_type_lovedby_male_with_name' => ':name’s secret lover',
 
     'relationship_type_ex' => 'ex-partner',
     'relationship_type_ex_female' => '前女友',
@@ -228,18 +238,24 @@ return [
 
     'relationship_type_uncle' => '叔叔',
     'relationship_type_uncle_female' => '阿姨',
+    'relationship_type_uncle_male' => 'uncle',
     'relationship_type_uncle_with_name' => ':name的叔叔',
     'relationship_type_uncle_female_with_name' => ':name的阿姨',
+    'relationship_type_uncle_male_with_name' => ':name’s uncle',
 
     'relationship_type_nephew' => '外甥',
     'relationship_type_nephew_female' => '外甥女',
+    'relationship_type_nephew_male' => 'nephew',
     'relationship_type_nephew_with_name' => ':name的外甥',
     'relationship_type_nephew_female_with_name' => ':name的外甥女',
+    'relationship_type_nephew_male_with_name' => ':name’s nephew',
 
     'relationship_type_cousin' => '堂兄弟',
     'relationship_type_cousin_female' => '堂姐妹',
+    'relationship_type_cousin_male' => 'cousin',
     'relationship_type_cousin_with_name' => ':name的堂兄弟',
     'relationship_type_cousin_female_with_name' => ':name的堂姐妹',
+    'relationship_type_cousin_male_with_name' => ':name’s cousin',
 
     'relationship_type_godfather' => 'godparent',
     'relationship_type_godfather_female' => '神母',
@@ -257,38 +273,52 @@ return [
 
     'relationship_type_friend' => '朋友',
     'relationship_type_friend_female' => '朋友',
+    'relationship_type_friend_male' => 'friend',
     'relationship_type_friend_with_name' => ':name的朋友',
     'relationship_type_friend_female_with_name' => ':name的朋友',
+    'relationship_type_friend_male_with_name' => ':name’s friend',
 
     'relationship_type_bestfriend' => '基友',
     'relationship_type_bestfriend_female' => '閨密',
+    'relationship_type_bestfriend_male' => 'best friend',
     'relationship_type_bestfriend_with_name' => ':name的基友',
     'relationship_type_bestfriend_female_with_name' => ':name的閨密',
+    'relationship_type_bestfriend_male_with_name' => ':name’s best friend',
 
     'relationship_type_colleague' => '同事',
     'relationship_type_colleague_female' => '同事',
+    'relationship_type_colleague_male' => 'colleague',
     'relationship_type_colleague_with_name' => ':name的同事',
     'relationship_type_colleague_female_with_name' => ':name的同事',
+    'relationship_type_colleague_male_with_name' => ':name’s colleague',
 
     'relationship_type_boss' => '上司',
     'relationship_type_boss_female' => '上司',
+    'relationship_type_boss_male' => 'boss',
     'relationship_type_boss_with_name' => ':name的上司',
     'relationship_type_boss_female_with_name' => ':name的上司',
+    'relationship_type_boss_male_with_name' => ':name’s boss',
 
     'relationship_type_subordinate' => '下屬',
     'relationship_type_subordinate_female' => '下屬',
+    'relationship_type_subordinate_male' => 'subordinate',
     'relationship_type_subordinate_with_name' => ':name的下屬',
     'relationship_type_subordinate_female_with_name' => ':name的下屬',
+    'relationship_type_subordinate_male_with_name' => ':name’s subordinate',
 
     'relationship_type_mentor' => '老師',
     'relationship_type_mentor_female' => '老師',
+    'relationship_type_mentor_male' => 'mentor',
     'relationship_type_mentor_with_name' => ':name的老師',
     'relationship_type_mentor_female_with_name' => ':name的老師',
+    'relationship_type_mentor_male_with_name' => ':name’s mentor',
 
     'relationship_type_protege' => 'protégé',
     'relationship_type_protege_female' => 'protégé',
+    'relationship_type_protege_male' => 'protégé',
     'relationship_type_protege_with_name' => ':name’s protégé',
     'relationship_type_protege_female_with_name' => ':name’s protégé',
+    'relationship_type_protege_male_with_name' => ':name’s protégé',
 
     'relationship_type_ex_husband' => 'ex-spouse',
     'relationship_type_ex_husband_female' => '前妻',
