@@ -21,18 +21,18 @@ return [
     'people_list_firstnameZA' => '以名字 Z → A排序',
     'people_list_lastnameAZ' => '以姓A → Z排序',
     'people_list_lastnameZA' => '以姓Z → A排序',
-    'people_list_lastactivitydateNewtoOld' => 'Sort by last activity date, newest to oldest',
-    'people_list_lastactivitydateOldtoNew' => 'Sort by last activity date, oldest to newest',
+    'people_list_lastactivitydateNewtoOld' => '依最後活動日期，由近到遠排序',
+    'people_list_lastactivitydateOldtoNew' => '依最後活動日期，由遠到近排序',
     'people_list_filter_tag' => '擁有以下標籤的聯絡人：',
     'people_list_clear_filter' => '清除篩選',
-    'people_list_contacts_per_tags' => ':count contact|:count contacts',
+    'people_list_contacts_per_tags' => ':{count} 個聯絡人|{count} 個聯絡人',
     'people_list_show_dead' => '顯示已故人員 (:count)',
     'people_list_hide_dead' => '隱藏已故人員 (:count)',
-    'people_search' => 'Search your contacts…',
+    'people_search' => '搜尋聯絡人',
     'people_search_no_results' => '未找到任何結果',
     'people_search_next' => '下一頁',
-    'people_search_prev' => 'Previous',
-    'people_search_rows_per_page' => 'Rows per page',
+    'people_search_prev' => '上一頁',
+    'people_search_rows_per_page' => '每頁行數',
     'people_search_of' => '/',
     'people_search_page' => '頁',
     'people_search_all' => '所有',
@@ -48,19 +48,19 @@ return [
     'people_add_title' => '新增一位新的聯絡人',
     'people_add_missing' => 'No person found – add a new one now',
     'people_add_firstname' => '名字',
-    'people_add_middlename' => 'Middle name (optional)',
-    'people_add_lastname' => 'Last name (optional)',
-    'people_add_email' => 'Email (optional)',
-    'people_add_nickname' => 'Nickname (optional)',
+    'people_add_middlename' => '中間名 (選填)',
+    'people_add_lastname' => '姓氏 (選填)',
+    'people_add_email' => '電子信箱 (選填)',
+    'people_add_nickname' => '暱稱 (選填)',
     'people_add_cta' => '新增',
     'people_save_and_add_another_cta' => '提交併新增其他人',
     'people_add_success' => ':name 已成功建立',
     'people_add_gender' => '性別',
     'people_delete_success' => '聯絡人已被刪除',
     'people_delete_message' => '刪除聯絡人',
-    'people_delete_confirmation' => 'Are you sure you want to delete :name’s contact? Deletion is immediate and permanent.',
+    'people_delete_confirmation' => '是否確認永久刪除:name的聯絡人資訊？',
     'people_add_birthday_reminder' => '祝: name生日快樂',
-    'people_add_birthday_reminder_deceased' => 'On this date, :name would have celebrated their birthday',
+    'people_add_birthday_reminder_deceased' => ':name會在這一天過生日',
     'people_add_import' => '是否要 <a href=":url">匯入您的聯絡人</a>？',
     'people_edit_email_error' => '您的聯絡人中已經有人使用此電子郵件，請更換一個',
     'people_export' => '匯出為 vCard',
@@ -95,7 +95,7 @@ return [
     'stay_in_touch_premium' => '您需要升級到高階賬戶來使用這個功能！',
     'stay_in_touch_modal_title' => '常聯絡*',
     'stay_in_touch_modal_desc' => '我們將會用郵件提醒您與{firstname}保持聯絡。',
-    'stay_in_touch_modal_label' => 'Send me an email every… {count} day|Send me an email every… {count} days',
+    'stay_in_touch_modal_label' => '每… {count} 天寄Email提醒我|每… {count} 天寄Email提醒我',
 
     // Calls
     'modal_call_title' => '記錄通話',
@@ -137,14 +137,14 @@ return [
     'conversation_list_cta' => '記錄對話',
 
     // age - birthday
-    'birthdate_not_set' => 'Birthday is not set',
+    'birthdate_not_set' => '未設定生日',
     'age_approximate_in_years' => '大概:age歲',
     'age_exact_in_years' => ':age歲',
     'age_exact_birthdate' => '出生:date',
 
     // Last called
     'last_called' => '最近通話: :date',
-    'last_talked_to' => 'Last called: {date}',
+    'last_talked_to' => '最近通話：(date)',
     'last_called_empty' => '最近通話: 未知',
     'last_activity_date' => '最近一起的活動: :date',
     'last_activity_date_empty' => '最近一起的活動: 未知',
@@ -155,14 +155,14 @@ return [
     'information_edit_max_size' => '最大值 :size Kb',
     'information_edit_max_size2' => '最大 {size} Kb',
     'information_edit_firstname' => '名字',
-    'information_edit_lastname' => 'Last name (optional)',
+    'information_edit_lastname' => '姓氏 (選填)',
     'information_edit_description' => 'Description (optional)',
     'information_edit_description_help' => '用於在聯絡人列表中新增一些元素（如有必要）',
     'information_edit_unknown' => '我不知道具體年齡',
-    'information_edit_probably' => 'This person is probably…',
-    'information_edit_not_year' => 'I know the day and month of this person’s birthday, but not the year…',
-    'information_edit_exact' => 'I know this person’s exact birthday…',
-    'information_edit_birthdate_label' => 'Birthday',
+    'information_edit_probably' => '年齡大概...歲',
+    'information_edit_not_year' => '只知道月和日，但不知道哪一年。',
+    'information_edit_exact' => '我知道詳細的年月日',
+    'information_edit_birthdate_label' => '生日',
     'information_no_work_defined' => '未定義工作資訊',
     'information_work_at' => '在 :company工作',
     'work_add_cta' => '更新工作資訊',
@@ -218,8 +218,8 @@ return [
     // relationships
     'relationship_form_add' => '新增一個新的關係',
     'relationship_form_edit' => '修改一個已有關係',
-    'relationship_form_is_with' => 'This person is…',
-    'relationship_form_is_with_name' => ':name is…',
+    'relationship_form_is_with' => '這個人是...',
+    'relationship_form_is_with_name' => ':name 是',
     'relationship_form_add_choice' => '這是與誰的關係？',
     'relationship_form_create_contact' => '新增一個新的人',
     'relationship_form_associate_contact' => '匯入一位已存在的聯絡人',
@@ -270,7 +270,7 @@ return [
     'activities_add_title' => '您與 {name} 一起做了什麼?',
     'activities_summary' => '描述你做了什麼',
     'activities_add_pick_activity' => 'Would you like to categorize this activity? You don’t have to, but it will give you statistics later on (optional)',
-    'activities_add_date_occured' => 'The activity happened on…',
+    'activities_add_date_occured' => '這活動是在什麼時候？',
     'activities_add_participants' => '除了 {name} 之外，誰參與了這個活動？(可選)',
     'activities_add_emotions_title' => '您想記錄您在此通話中的感受嗎？(可選)',
     'activities_blank_title' => '記錄您與 {name} 之間的點滴',
@@ -287,7 +287,7 @@ return [
     'activities_profile_year_summary_activity_types' => ':year年活動型別彙總',
     'activities_profile_year_summary' => ':year年你們一起進行的活動',
     'activities_profile_number_occurences' => ':value 次活動',
-    'activities_list_participants' => 'Participants ({total}):',
+    'activities_list_participants' => '與會人員 ({total})',
     'activities_list_emotions' => '我感覺:',
     'activities_list_date' => '發生於',
     'activities_list_category' => '分類：',
@@ -376,8 +376,8 @@ return [
 
     // Deceased
     'deceased_reminder_title' => ':name的去世週年懷念',
-    'deceased_mark_person_deceased' => 'Mark this as deceased',
-    'deceased_know_date' => 'I know the date that this person died',
+    'deceased_mark_person_deceased' => '標記為已逝者',
+    'deceased_know_date' => '我知道去世日期',
     'deceased_add_reminder' => '為此日期新增提醒',
     'deceased_label' => '逝者',
     'deceased_date_label' => '死亡日期',
@@ -431,7 +431,7 @@ return [
     'life_event_create_life_event' => '新增生活事件',
     'life_event_create_default_title' => '標題 (可選)',
     'life_event_create_default_story' => '故事 (可選)',
-    'life_event_create_date' => 'You do not need to indicate a month or a day – only the year is mandatory.',
+    'life_event_create_date' => '不需要詳細到某一天，提供年份即可',
     'life_event_create_default_description' => '新增你知道的資訊',
     'life_event_create_add_yearly_reminder' => '為該事件新增年度提醒',
     'life_event_create_success' => '生活事件新增成功',
@@ -439,11 +439,11 @@ return [
     'life_event_delete_description' => '確實要刪除此生活事件嗎？刪除是永久性的。',
     'life_event_delete_success' => '事件已刪除',
     'life_event_date_it_happened' => '發生日期',
-    'life_event_category_work_education' => 'Work & education',
+    'life_event_category_work_education' => '工作 & 教育',
     'life_event_category_family_relationships' => 'Family & relationships',
-    'life_event_category_home_living' => 'Home & living',
+    'life_event_category_home_living' => '居家生活',
     'life_event_category_health_wellness' => 'Health & wellness',
-    'life_event_category_travel_experiences' => 'Travel & experiences',
+    'life_event_category_travel_experiences' => '旅行與經歷',
     'life_event_sentence_new_job' => '開始了新的工作',
     'life_event_sentence_retirement' => '退休',
     'life_event_sentence_new_school' => '開始上學',
@@ -493,7 +493,7 @@ return [
     'document_list_cta' => '上載檔案',
     'document_list_blank_desc' => '在這裡, 您可以儲存與此人相關的檔案。',
     'document_upload_zone_cta' => '上傳檔案',
-    'document_upload_zone_progress' => 'Uploading the document…',
+    'document_upload_zone_progress' => '正在上傳檔案中...',
     'document_upload_zone_error' => '上傳檔案時出錯，請再試一次 ！',
 
     // Photos
@@ -505,8 +505,8 @@ return [
     'photo_current_profile_pic' => '目前頭像',
     'photo_make_profile_pic' => '製作頭像',
     'photo_delete' => '刪除照片',
-    'photo_next' => 'Next photo ❯',
-    'photo_previous' => '❮ Previous photo',
+    'photo_next' => '下一張照片 ❯',
+    'photo_previous' => '❮ 上一張照片',
 
     // Avatars
     'avatar_change_title' => '更換頭像',
@@ -516,7 +516,7 @@ return [
     'avatar_gravatar' => '此使用者的電子郵件地址 與 Gravatar 關聯 。 <a href="https://gravatar.com/">Gravatar</a> 是全球通用的頭像服務。',
     'avatar_current' => '保持當前頭像',
     'avatar_photo' => '從您上傳的照片',
-    'avatar_crop_new_avatar_photo' => 'Crop new avatar photo',
+    'avatar_crop_new_avatar_photo' => '裁剪新頭像圖片',
 
     // emotions
     'emotion_this_made_me_feel' => '這讓你覺得...',
