@@ -14,7 +14,7 @@ return [
     'add' => '添加',
     'cancel' => '取消',
     'confirm' => '确认',
-    'delete_confirm' => '确定要这样做吗?',
+    'delete_confirm' => '确定吗？',
     'delete' => '删除',
     'edit' => '编辑',
     'upload' => '上传',
@@ -48,7 +48,7 @@ return [
 
     'application_title' => 'Monica – 您的私人社交关系管家',
     'application_description' => 'Monica是用来收集并管理您与亲朋好友之间的关系的得力助手。',
-    'application_og_title' => 'Have better relations with your loved ones. Free online CRM for friends and family.',
+    'application_og_title' => '促进你们之间的感情。一个免费开源的面向亲朋好友的 CRM 工具',
 
     'markdown_description' => '想用一种美观的方式格式化文本吗？我们以Markdown语法支持粗体、斜体、列表等样式。',
     'markdown_link' => '阅读文档',
@@ -140,162 +140,192 @@ return [
 
     'relationship_type_partner' => '搭档',
     'relationship_type_partner_female' => '搭档',
+    'relationship_type_partner_male' => '爱人',
     'relationship_type_partner_with_name' => ':name的情侣',
     'relationship_type_partner_female_with_name' => ':name的搭档',
+    'relationship_type_partner_male_with_name' => ':name的爱人',
 
     'relationship_type_spouse' => '配偶',
-    'relationship_type_spouse_female' => 'wife',
-    'relationship_type_spouse_male' => 'husband',
+    'relationship_type_spouse_female' => '妻子',
+    'relationship_type_spouse_male' => '丈夫',
     'relationship_type_spouse_with_name' => ':name的配偶',
-    'relationship_type_spouse_female_with_name' => ':name’s wife',
-    'relationship_type_spouse_male_with_name' => ':name’s husband',
+    'relationship_type_spouse_female_with_name' => ':name的妻子',
+    'relationship_type_spouse_male_with_name' => ':name的丈夫',
 
     'relationship_type_date' => '约会对象',
     'relationship_type_date_female' => '约会对象',
+    'relationship_type_date_male' => '约会对象',
     'relationship_type_date_with_name' => ':name的约会对象',
     'relationship_type_date_female_with_name' => ':name的约会对象',
+    'relationship_type_date_male_with_name' => ':name的约会对象',
 
     'relationship_type_lover' => '情人',
     'relationship_type_lover_female' => '情人',
+    'relationship_type_lover_male' => '情人',
     'relationship_type_lover_with_name' => ':name的情人',
     'relationship_type_lover_female_with_name' => ':name的情人',
+    'relationship_type_lover_male_with_name' => ':name的情人',
 
     'relationship_type_inlovewith' => '喜欢的人',
     'relationship_type_inlovewith_female' => '喜欢的人',
+    'relationship_type_inlovewith_male' => '喜欢的人',
     'relationship_type_inlovewith_with_name' => ':name喜欢的人',
     'relationship_type_inlovewith_female_with_name' => ':name喜欢的人',
+    'relationship_type_inlovewith_male_with_name' => ':name喜欢的人',
 
     'relationship_type_lovedby' => '追求者',
     'relationship_type_lovedby_female' => '追求者',
+    'relationship_type_lovedby_male' => '追求者',
     'relationship_type_lovedby_with_name' => ':name的追求者',
     'relationship_type_lovedby_female_with_name' => ':name的追求者',
+    'relationship_type_lovedby_male_with_name' => ':name暗恋的人',
 
-    'relationship_type_ex' => 'ex-partner',
+    'relationship_type_ex' => '前伴侣',
     'relationship_type_ex_female' => '前女友',
-    'relationship_type_ex_male' => 'ex-boyfriend',
-    'relationship_type_ex_with_name' => ':name’s ex-partner',
+    'relationship_type_ex_male' => '前男友',
+    'relationship_type_ex_with_name' => ':name的前伴侣',
     'relationship_type_ex_female_with_name' => ':name的前女友',
-    'relationship_type_ex_male_with_name' => ':name’s ex-boyfriend',
+    'relationship_type_ex_male_with_name' => ':name的前男友',
 
-    'relationship_type_parent' => 'parent',
+    'relationship_type_parent' => '父母',
     'relationship_type_parent_female' => '母亲',
-    'relationship_type_parent_male' => 'father',
-    'relationship_type_parent_with_name' => ':name’s parent',
+    'relationship_type_parent_male' => '父亲',
+    'relationship_type_parent_with_name' => ':name的父母',
     'relationship_type_parent_female_with_name' => ':name的母亲',
-    'relationship_type_parent_male_with_name' => ':name’s father',
+    'relationship_type_parent_male_with_name' => ':name的父亲',
 
-    'relationship_type_child' => 'child',
+    'relationship_type_child' => '子女',
     'relationship_type_child_female' => '女儿',
-    'relationship_type_child_male' => 'son',
-    'relationship_type_child_with_name' => ':name’s child',
+    'relationship_type_child_male' => '儿子',
+    'relationship_type_child_with_name' => ':name的子女',
     'relationship_type_child_female_with_name' => ':name的女人',
-    'relationship_type_child_male_with_name' => ':name’s son',
+    'relationship_type_child_male_with_name' => ':name的儿子',
 
-    'relationship_type_stepparent' => 'step-parent',
+    'relationship_type_stepparent' => '继父/继母',
     'relationship_type_stepparent_female' => '继母',
-    'relationship_type_stepparent_male' => 'stepfather',
-    'relationship_type_stepparent_with_name' => ':name’s step-parent',
+    'relationship_type_stepparent_male' => '继父',
+    'relationship_type_stepparent_with_name' => ':name的继父母',
     'relationship_type_stepparent_female_with_name' => ':name的继母',
-    'relationship_type_stepparent_male_with_name' => ':name’s stepfather',
+    'relationship_type_stepparent_male_with_name' => ':name的继父',
 
-    'relationship_type_stepchild' => 'stepchild',
+    'relationship_type_stepchild' => '继子女',
     'relationship_type_stepchild_female' => '继女',
-    'relationship_type_stepchild_male' => 'stepson',
-    'relationship_type_stepchild_with_name' => ':name’s stepchild',
+    'relationship_type_stepchild_male' => '继子',
+    'relationship_type_stepchild_with_name' => ':name的继子女',
     'relationship_type_stepchild_female_with_name' => ':name的继女',
-    'relationship_type_stepchild_male_with_name' => ':name’s stepson',
+    'relationship_type_stepchild_male_with_name' => ':name的继子',
 
-    'relationship_type_sibling' => 'sibling',
+    'relationship_type_sibling' => '兄弟姐妹',
     'relationship_type_sibling_female' => '姐妹',
-    'relationship_type_sibling_male' => 'brother',
-    'relationship_type_sibling_with_name' => ':name’s sibling',
+    'relationship_type_sibling_male' => '兄弟',
+    'relationship_type_sibling_with_name' => ':name的兄弟姐妹',
     'relationship_type_sibling_female_with_name' => ':name的姐妹',
-    'relationship_type_sibling_male_with_name' => ':name’s brother',
+    'relationship_type_sibling_male_with_name' => ':name的兄弟',
 
-    'relationship_type_grandparent' => 'grandparent',
-    'relationship_type_grandparent_female' => 'grandmother',
-    'relationship_type_grandparent_male' => 'grandfather',
-    'relationship_type_grandparent_with_name' => ':name’s grandparent',
-    'relationship_type_grandparent_female_with_name' => ':name’s grandmother',
-    'relationship_type_grandparent_male_with_name' => ':name’s grandfather',
+    'relationship_type_grandparent' => '祖父母',
+    'relationship_type_grandparent_female' => '祖母',
+    'relationship_type_grandparent_male' => '祖父',
+    'relationship_type_grandparent_with_name' => ':name的祖父母',
+    'relationship_type_grandparent_female_with_name' => ':name的祖母',
+    'relationship_type_grandparent_male_with_name' => ':name的祖父',
 
-    'relationship_type_grandchild' => 'grandchild',
-    'relationship_type_grandchild_female' => 'granddaughter',
-    'relationship_type_grandchild_male' => 'grandson',
-    'relationship_type_grandchild_with_name' => ':name’s grandchild',
-    'relationship_type_grandchild_female_with_name' => ':name’s granddauther',
-    'relationship_type_grandchild_male_with_name' => ':name’s grandson',
+    'relationship_type_grandchild' => '（外）孙子女',
+    'relationship_type_grandchild_female' => '（外）孙女',
+    'relationship_type_grandchild_male' => '（外）孙子',
+    'relationship_type_grandchild_with_name' => ':name的（外）孙子女',
+    'relationship_type_grandchild_female_with_name' => ':name的（外）孙女',
+    'relationship_type_grandchild_male_with_name' => ':name的（外）孙子',
 
     'relationship_type_uncle' => '叔叔',
     'relationship_type_uncle_female' => '阿姨',
+    'relationship_type_uncle_male' => '叔叔',
     'relationship_type_uncle_with_name' => ':name的叔叔',
     'relationship_type_uncle_female_with_name' => ':name的阿姨',
+    'relationship_type_uncle_male_with_name' => ':name的叔叔',
 
     'relationship_type_nephew' => '外甥',
     'relationship_type_nephew_female' => '外甥女',
+    'relationship_type_nephew_male' => '外甥',
     'relationship_type_nephew_with_name' => ':name的外甥',
     'relationship_type_nephew_female_with_name' => ':name的外甥女',
+    'relationship_type_nephew_male_with_name' => ':name的外甥',
 
     'relationship_type_cousin' => '堂兄弟',
     'relationship_type_cousin_female' => '堂姐妹',
+    'relationship_type_cousin_male' => '堂兄弟',
     'relationship_type_cousin_with_name' => ':name的堂兄弟',
     'relationship_type_cousin_female_with_name' => ':name的堂姐妹',
+    'relationship_type_cousin_male_with_name' => ':name的堂兄弟',
 
-    'relationship_type_godfather' => 'godparent',
+    'relationship_type_godfather' => '义父母',
     'relationship_type_godfather_female' => '神母',
-    'relationship_type_godfather_male' => 'godfather',
-    'relationship_type_godfather_with_name' => ':name’s godparent',
+    'relationship_type_godfather_male' => '义父',
+    'relationship_type_godfather_with_name' => ':name的义父',
     'relationship_type_godfather_female_with_name' => ':name的神母',
-    'relationship_type_godfather_male_with_name' => ':name’s godfather',
+    'relationship_type_godfather_male_with_name' => ':name的义父',
 
-    'relationship_type_godson' => 'godchild',
+    'relationship_type_godson' => '义子',
     'relationship_type_godson_female' => '义女',
-    'relationship_type_godson_male' => 'godson',
-    'relationship_type_godson_with_name' => ':name’s godchild',
+    'relationship_type_godson_male' => '义子',
+    'relationship_type_godson_with_name' => ':name的义子',
     'relationship_type_godson_female_with_name' => ':name的义女',
-    'relationship_type_godson_male_with_name' => ':name’s godson',
+    'relationship_type_godson_male_with_name' => ':name的义子',
 
     'relationship_type_friend' => '朋友',
     'relationship_type_friend_female' => '朋友',
+    'relationship_type_friend_male' => '朋友',
     'relationship_type_friend_with_name' => ':name的朋友',
     'relationship_type_friend_female_with_name' => ':name的朋友',
+    'relationship_type_friend_male_with_name' => ':name的朋友',
 
     'relationship_type_bestfriend' => '基友',
     'relationship_type_bestfriend_female' => '闺密',
+    'relationship_type_bestfriend_male' => '好友',
     'relationship_type_bestfriend_with_name' => ':name的基友',
     'relationship_type_bestfriend_female_with_name' => ':name的闺密',
+    'relationship_type_bestfriend_male_with_name' => ':name的好友',
 
     'relationship_type_colleague' => '同事',
     'relationship_type_colleague_female' => '同事',
+    'relationship_type_colleague_male' => '同事',
     'relationship_type_colleague_with_name' => ':name的同事',
     'relationship_type_colleague_female_with_name' => ':name的同事',
+    'relationship_type_colleague_male_with_name' => ':name的同事',
 
     'relationship_type_boss' => '上司',
     'relationship_type_boss_female' => '上司',
+    'relationship_type_boss_male' => '上司',
     'relationship_type_boss_with_name' => ':name的上司',
     'relationship_type_boss_female_with_name' => ':name的上司',
+    'relationship_type_boss_male_with_name' => ':name的上司',
 
     'relationship_type_subordinate' => '下属',
     'relationship_type_subordinate_female' => '下属',
+    'relationship_type_subordinate_male' => '下属',
     'relationship_type_subordinate_with_name' => ':name的下属',
     'relationship_type_subordinate_female_with_name' => ':name的下属',
+    'relationship_type_subordinate_male_with_name' => ':name的下属',
 
     'relationship_type_mentor' => '老师',
     'relationship_type_mentor_female' => '老师',
+    'relationship_type_mentor_male' => '老师',
     'relationship_type_mentor_with_name' => ':name的老师',
     'relationship_type_mentor_female_with_name' => ':name的老师',
+    'relationship_type_mentor_male_with_name' => ':name的老师',
 
-    'relationship_type_protege' => 'protégé',
+    'relationship_type_protege' => '门徒',
     'relationship_type_protege_female' => 'protégé',
+    'relationship_type_protege_male' => 'protégé',
     'relationship_type_protege_with_name' => ':name’s protégé',
     'relationship_type_protege_female_with_name' => ':name’s protégé',
+    'relationship_type_protege_male_with_name' => ':name’s protégé',
 
-    'relationship_type_ex_husband' => 'ex-spouse',
+    'relationship_type_ex_husband' => '前夫',
     'relationship_type_ex_husband_female' => '前妻',
-    'relationship_type_ex_husband_male' => 'ex-husband',
-    'relationship_type_ex_husband_with_name' => ':name’s ex-spouse',
+    'relationship_type_ex_husband_male' => '前夫',
+    'relationship_type_ex_husband_with_name' => ':name的前配偶',
     'relationship_type_ex_husband_female_with_name' => ':name的前妻',
-    'relationship_type_ex_husband_male_with_name' => ':name’s ex-husband',
+    'relationship_type_ex_husband_male_with_name' => ':name的前夫',
 
     // emotions
     'emotion_primary_love' => '喜爱',
@@ -465,58 +495,58 @@ return [
     'emotion_dread' => '惊恐',
 
     // weather
-    'weather_sunny' => 'Sunny',
-    'weather_clear' => 'Clear',
-    'weather_clear-day' => 'Clear',
+    'weather_sunny' => '晴天',
+    'weather_clear' => '万里无云',
+    'weather_clear-day' => '晴朗',
     'weather_clear-night' => '晴朗的夜晚',
-    'weather_light-drizzle' => 'Light drizzle',
-    'weather_patchy-light-drizzle' => 'Patchy light drizzle',
-    'weather_patchy-light-rain' => 'Patchy light rain',
-    'weather_light-rain' => 'Light rain',
-    'weather_moderate-rain-at-times' => 'Moderate rain at times',
-    'weather_moderate-rain' => 'Moderate rain',
-    'weather_patchy-rain-possible' => 'Patchy rain possible',
-    'weather_heavy-rain-at-times' => 'Heavy rain at times',
-    'weather_heavy-rain' => 'Heavy rain',
-    'weather_light-freezing-rain' => 'Light freezing rain',
-    'weather_moderate-or-heavy-freezing-rain' => 'Moderate or heavy freezing rain',
-    'weather_light-sleet' => 'Light sleet',
-    'weather_moderate-or-heavy-rain-shower' => 'Moderate or heavy rain shower',
-    'weather_light-rain-shower' => 'Light rain shower',
-    'weather_torrential-rain-shower' => 'Torrential rain shower',
+    'weather_light-drizzle' => '小雨',
+    'weather_patchy-light-drizzle' => '局部小雨',
+    'weather_patchy-light-rain' => '局部下雨',
+    'weather_light-rain' => '小雨',
+    'weather_moderate-rain-at-times' => '有时中雨',
+    'weather_moderate-rain' => '中雨',
+    'weather_patchy-rain-possible' => '可能有局部降雨',
+    'weather_heavy-rain-at-times' => '有时大雨',
+    'weather_heavy-rain' => '大雨',
+    'weather_light-freezing-rain' => '小冻雨',
+    'weather_moderate-or-heavy-freezing-rain' => '中度或重度冻雨',
+    'weather_light-sleet' => '小雨夹雪',
+    'weather_moderate-or-heavy-rain-shower' => '中到大雨，阵雨',
+    'weather_light-rain-shower' => '小雨，阵雨',
+    'weather_torrential-rain-shower' => '暴雨，阵雨',
     'weather_rain' => '雨',
     'weather_snow' => '雪',
-    'weather_blowing-snow' => 'Blowing snow',
-    'weather_patchy-light-snow' => 'Patchy light snow',
-    'weather_light-snow' => 'Light snow',
-    'weather_patchy-moderate-snow' => 'Patchy moderate snow',
-    'weather_moderate-snow' => 'Moderate snow',
-    'weather_patchy-heavy-snow' => 'Patchy heavy snow',
-    'weather_heavy-snow' => 'Heavy snow',
-    'weather_light-snow-showers' => 'Light snow showers',
-    'weather_moderate-or-heavy-snow-showers' => 'Moderate or heavy snow showers',
-    'weather_patchy-snow-possible' => 'Patchy snow possible',
-    'weather_patchy-sleet-possible' => 'Patchy sleet possible',
-    'weather_moderate-or-heavy-sleet' => 'Moderate or heavy sleet',
-    'weather_light-sleet-showers' => 'Light sleet showers',
-    'weather_moderate-or-heavy-sleet-showers' => 'Moderate or heavy sleet showers',
+    'weather_blowing-snow' => '高吹雪',
+    'weather_patchy-light-snow' => '局部小雪',
+    'weather_light-snow' => '小雪',
+    'weather_patchy-moderate-snow' => '局部中雪',
+    'weather_moderate-snow' => '中雪',
+    'weather_patchy-heavy-snow' => '局部大雪',
+    'weather_heavy-snow' => '大雪',
+    'weather_light-snow-showers' => '小阵雪',
+    'weather_moderate-or-heavy-snow-showers' => '中到大阵雪',
+    'weather_patchy-snow-possible' => '可能有局部降雪',
+    'weather_patchy-sleet-possible' => '可能有局部雨夹雪',
+    'weather_moderate-or-heavy-sleet' => '中到大雨夹雪',
+    'weather_light-sleet-showers' => '小阵雨夹雪',
+    'weather_moderate-or-heavy-sleet-showers' => '中到大阵雨夹雪',
     'weather_sleet' => '雨夹雪',
     'weather_wind' => '风',
     'weather_fog' => '雾',
-    'weather_freezing-fog' => 'Freezing fog',
-    'weather_mist' => 'Mist',
-    'weather_blizzard' => 'Blizzard',
-    'weather_overcast' => 'Overcast',
+    'weather_freezing-fog' => '冻雾',
+    'weather_mist' => '雾',
+    'weather_blizzard' => '暴风雪',
+    'weather_overcast' => '阴天',
     'weather_cloudy' => '多云',
-    'weather_partly-cloudy-day' => 'Partly cloudy',
-    'weather_partly-cloudy-night' => 'Partly cloudy',
-    'weather_freezing-drizzle' => 'Freezing drizzle',
-    'weather_heavy-freezing-drizzle' => 'Heavy freezing drizzle',
-    'weather_patchy-freezing-drizzle-possible' => 'Patchy freezing drizzle possible',
-    'weather_ice-pellets' => 'Ice pellets',
-    'weather_light-showers-of-ice-pellets' => 'Light showers of ice pellets',
-    'weather_moderate-or-heavy-showers-of-ice-pellets' => 'Moderate or heavy showers of ice pellets',
-    'weather_thundery-outbreaks-possible' => 'Thundery outbreaks possible',
+    'weather_partly-cloudy-day' => '局部多云',
+    'weather_partly-cloudy-night' => '局部多云',
+    'weather_freezing-drizzle' => '冻毛毛雨',
+    'weather_heavy-freezing-drizzle' => '冷冻大雨',
+    'weather_patchy-freezing-drizzle-possible' => '可能有局部冻毛毛雨',
+    'weather_ice-pellets' => '冰雹',
+    'weather_light-showers-of-ice-pellets' => '阵雨加冰雹',
+    'weather_moderate-or-heavy-showers-of-ice-pellets' => '中等或重度的冰雹阵雨',
+    'weather_thundery-outbreaks-possible' => '雷雨可能',
     'weather_patchy-light-rain-with-thunder' => 'Patchy light rain with thunder',
     'weather_moderate-or-heavy-rain-with-thunder' => 'Moderate or heavy rain with thunder',
     'weather_patchy-light-snow-with-thunder' => 'Patchy light snow with thunder',
