@@ -21,8 +21,8 @@ return [
     'people_list_firstnameZA' => '以名字 Z → A排序',
     'people_list_lastnameAZ' => '以姓A → Z排序',
     'people_list_lastnameZA' => '以姓Z → A排序',
-    'people_list_lastactivitydateNewtoOld' => 'Sort by last activity date, newest to oldest',
-    'people_list_lastactivitydateOldtoNew' => 'Sort by last activity date, oldest to newest',
+    'people_list_lastactivitydateNewtoOld' => '以最后活动日期从近到远排序',
+    'people_list_lastactivitydateOldtoNew' => '以最后活动日期从远到近排序',
     'people_list_filter_tag' => '拥有以下标签的联系人：',
     'people_list_clear_filter' => '清除筛选',
     'people_list_contacts_per_tags' => ':count 个联系人',
@@ -46,7 +46,7 @@ return [
 
     // people add
     'people_add_title' => '添加一位新的联系人',
-    'people_add_missing' => '列表为空 — — 现在添加一个新的',
+    'people_add_missing' => '列表为空——现在添加一个新联系人',
     'people_add_firstname' => '名字',
     'people_add_middlename' => '中间名（可选）',
     'people_add_lastname' => '姓氏（选填）',
@@ -58,9 +58,9 @@ return [
     'people_add_gender' => '性别',
     'people_delete_success' => '联系人已被删除',
     'people_delete_message' => '删除联系人',
-    'people_delete_confirmation' => '确实要删除 :name 的联系人吗？删除将立即生效且无法恢复。',
+    'people_delete_confirmation' => '确定要删除 :name 联系人吗？删除将立即生效且无法恢复。',
     'people_add_birthday_reminder' => '祝 :name 生日快乐',
-    'people_add_birthday_reminder_deceased' => 'On this date, :name would have celebrated their birthday',
+    'people_add_birthday_reminder_deceased' => '在这天，:name 会庆祝他们的生日',
     'people_add_import' => '是否要 <a href=":url">导入您的联系人</a>？',
     'people_edit_email_error' => '您的联系人中已经有人使用此电子邮件，请更换一个',
     'people_export' => '导出为 vCard',
@@ -83,19 +83,19 @@ return [
     'edit_contact_information' => '编辑联系人信息',
     'contact_archive' => '存档联系人',
     'contact_unarchive' => '取消存档',
-    'contact_archive_help' => 'Archived contacts are not be shown on the contact list, but still appear in search results.',
+    'contact_archive_help' => '已存档的联系人不会显示在联系人列表中，但仍会出现在搜索结果中。',
     'call_button' => '记录通话',
     'set_favorite' => '您收藏的联系人将在联系人列表置顶显示。',
 
     // Stay in touch
     'stay_in_touch' => '常联系*',
     'stay_in_touch_frequency' => '常联系*提醒频率：每天|常联系*提醒频率：每 {count} 天',
-    'stay_in_touch_next_date' => 'Next due: {date}',
+    'stay_in_touch_next_date' => '下次到期日： {date}',
     'stay_in_touch_invalid' => '频率必须大于0。',
     'stay_in_touch_premium' => '您需要升级到高级账户来使用这个功能！',
     'stay_in_touch_modal_title' => '常联系*',
     'stay_in_touch_modal_desc' => '我们将会用邮件提醒您与{firstname}保持联系。',
-    'stay_in_touch_modal_label' => 'Send me an email every… {count} day|Send me an email every… {count} days',
+    'stay_in_touch_modal_label' => '每… {count} 天给我发一封电子邮件|每… {count} 天给我发一封电子邮件',
 
     // Calls
     'modal_call_title' => '记录通话',
@@ -115,7 +115,7 @@ return [
     'call_emotions' => '情绪：',
 
     // Conversation
-    'conversation_blank' => '记录你和 :name 在社交媒体或 SMS 等平台的对话。',
+    'conversation_blank' => '记录你和 :name 在社交媒体或 SMS 等平台的对话…',
     'conversation_delete_link' => '删除对话',
     'conversation_edit_title' => '编辑对话',
     'conversation_edit_delete' => '您是否要删除这个对话？操作无法撤销。',
@@ -124,7 +124,7 @@ return [
     'conversation_delete_success' => '对话成功删除',
     'conversation_add_title' => '记录一个新对话',
     'conversation_add_when' => '你们何时进行的对话？',
-    'conversation_add_who_wrote' => 'Who sent this message?',
+    'conversation_add_who_wrote' => '谁发的这条消息？',
     'conversation_add_how' => '你们怎么交流？',
     'conversation_add_you' => '您',
     'conversation_add_content' => '写下你们说的话',
@@ -144,7 +144,7 @@ return [
 
     // Last called
     'last_called' => '最近通话: :date',
-    'last_talked_to' => 'Last called: {date}',
+    'last_talked_to' => '最近通话：{date}',
     'last_called_empty' => '最近通话: 未知',
     'last_activity_date' => '最近一起的活动: :date',
     'last_activity_date_empty' => '最近一起的活动: 未知',
@@ -155,18 +155,18 @@ return [
     'information_edit_max_size' => '最大值 :size Kb',
     'information_edit_max_size2' => '最大 {size} Kb',
     'information_edit_firstname' => '名字',
-    'information_edit_lastname' => 'Last name (optional)',
-    'information_edit_description' => 'Description (optional)',
+    'information_edit_lastname' => '姓（可选）',
+    'information_edit_description' => '描述 (可选)',
     'information_edit_description_help' => '用于在联系人列表中添加一些元素（如有必要）',
     'information_edit_unknown' => '我不知道具体年龄',
-    'information_edit_probably' => 'This person is probably…',
-    'information_edit_not_year' => 'I know the day and month of this person’s birthday, but not the year…',
+    'information_edit_probably' => '此人可能是…',
+    'information_edit_not_year' => '我知道这个人生日的月日，但不知是哪一年…',
     'information_edit_exact' => '我知道这个人确切的生日…',
     'information_edit_birthdate_label' => '生日',
     'information_no_work_defined' => '未定义工作信息',
     'information_work_at' => '在 :company工作',
     'work_add_cta' => '更新工作信息',
-    'work_edit_success' => 'Work information updated',
+    'work_edit_success' => '工作信息已更新',
     'work_edit_title' => '更新:name的工作信息',
     'work_edit_job' => '职位名称 (可选)',
     'work_edit_company' => '公司 (可选)',
@@ -185,7 +185,7 @@ return [
     'reminders_blank_title' => '您有什么关于:name的提醒吗？',
     'reminders_blank_add_activity' => '添加提醒',
     'reminders_add_title' => '你需要关于:name的提醒吗？',
-    'reminders_add_description' => 'Please remind me to…',
+    'reminders_add_description' => '请提醒我…',
     'reminders_add_next_time' => '您希望下一次关于这个的提醒的时间是？',
     'reminders_add_once' => '仅一次',
     'reminders_add_recurrent' => '每',
@@ -207,7 +207,7 @@ return [
     'reminders_delete_cta' => '删除',
     'reminders_next_expected_date' => '在',
     'reminders_cta' => '添加提醒',
-    'reminders_description' => 'We will send an email for each one of the reminders below. Reminders are sent every morning the day events will happen. Reminders automatically added for birthdays can not be deleted. If you want to change those dates, edit the birthday of the contacts.',
+    'reminders_description' => '我们将为下面每个提醒发送一封电子邮件。提醒将于事件发生的当天早晨发送。自动添加的生日提醒无法删除。如果您想要更改生日提醒的日期，请编辑联系人的生日。',
     'reminders_one_time' => '一次性',
     'reminders_type_week' => '周',
     'reminders_type_month' => '月',
@@ -218,8 +218,8 @@ return [
     // relationships
     'relationship_form_add' => '添加一个新的关系',
     'relationship_form_edit' => '修改一个已有关系',
-    'relationship_form_is_with' => 'This person is…',
-    'relationship_form_is_with_name' => ':name is…',
+    'relationship_form_is_with' => '这个人是…',
+    'relationship_form_is_with_name' => ':name 是...',
     'relationship_form_add_choice' => '这是与谁的关系？',
     'relationship_form_create_contact' => '添加一个新的人',
     'relationship_form_associate_contact' => '导入一位已存在的联系人',
@@ -249,7 +249,7 @@ return [
     'activity_type_category_food' => '食物',
     'activity_type_category_cultural_activities' => '文化',
     'activity_type_just_hung_out' => '约会',
-    'activity_type_watched_movie_at_home' => '看电影',
+    'activity_type_watched_movie_at_home' => '在家看电影',
     'activity_type_talked_at_home' => '谈心',
     'activity_type_did_sport_activities_together' => '一起打球',
     'activity_type_ate_at_his_place' => '在对方家里做客',
@@ -269,8 +269,8 @@ return [
     'activities_item_information' => ':Activity，发生于:date',
     'activities_add_title' => '您与 {name} 一起做了什么?',
     'activities_summary' => '描述你做了什么',
-    'activities_add_pick_activity' => 'Would you like to categorize this activity? You don’t have to, but it will give you statistics later on (optional)',
-    'activities_add_date_occured' => 'The activity happened on…',
+    'activities_add_pick_activity' => '是否对此活动进行分类？这不是必须的，但日后会为您提供统计数据 (可选)',
+    'activities_add_date_occured' => '活动发生于…',
     'activities_add_participants' => '除了 {name} 之外，谁参与了这个活动？(可选)',
     'activities_add_emotions_title' => '您想记录您在此通话中的感受吗？(可选)',
     'activities_blank_title' => '记录您与 {name} 之间的点滴',
@@ -287,7 +287,7 @@ return [
     'activities_profile_year_summary_activity_types' => ':year年活动类型汇总',
     'activities_profile_year_summary' => ':year年你们一起进行的活动',
     'activities_profile_number_occurences' => ':value 次活动',
-    'activities_list_participants' => 'Participants ({total}):',
+    'activities_list_participants' => '参与者 ({total}):',
     'activities_list_emotions' => '我感觉:',
     'activities_list_date' => '发生于',
     'activities_list_category' => '分类：',
@@ -332,7 +332,7 @@ return [
     'gifts_view_comment' => '查看评论',
     'gifts_mark_offered' => '标记为提供',
     'gifts_update_success' => '礼物已成功更新',
-    'gifts_add_date' => 'Date (optional)',
+    'gifts_add_date' => '日期 (可选)',
 
     // debts
     'debt_delete_confirmation' => '是否确实要删除此债务？',
@@ -376,8 +376,8 @@ return [
 
     // Deceased
     'deceased_reminder_title' => ':name的去世周年怀念',
-    'deceased_mark_person_deceased' => 'Mark this as deceased',
-    'deceased_know_date' => 'I know the date that this person died',
+    'deceased_mark_person_deceased' => '将此人标记为已逝者',
+    'deceased_know_date' => '我知道此人的去世日期',
     'deceased_add_reminder' => '为此日期添加提醒',
     'deceased_label' => '逝者',
     'deceased_date_label' => '死亡日期',
@@ -431,7 +431,7 @@ return [
     'life_event_create_life_event' => '添加生活事件',
     'life_event_create_default_title' => '标题 (可选)',
     'life_event_create_default_story' => '故事 (可选)',
-    'life_event_create_date' => 'You do not need to indicate a month or a day – only the year is mandatory.',
+    'life_event_create_date' => '只需要提供年份即可 — 日与月不是必填项。',
     'life_event_create_default_description' => '添加你知道的信息',
     'life_event_create_add_yearly_reminder' => '为该事件添加年度提醒',
     'life_event_create_success' => '生活事件添加成功',
@@ -439,11 +439,11 @@ return [
     'life_event_delete_description' => '确实要删除此生活事件吗？删除是永久性的。',
     'life_event_delete_success' => '事件已删除',
     'life_event_date_it_happened' => '发生日期',
-    'life_event_category_work_education' => 'Work & education',
-    'life_event_category_family_relationships' => 'Family & relationships',
-    'life_event_category_home_living' => 'Home & living',
-    'life_event_category_health_wellness' => 'Health & wellness',
-    'life_event_category_travel_experiences' => 'Travel & experiences',
+    'life_event_category_work_education' => '工作与教育',
+    'life_event_category_family_relationships' => '家庭与恋爱',
+    'life_event_category_home_living' => '生活日常',
+    'life_event_category_health_wellness' => '健身',
+    'life_event_category_travel_experiences' => '旅行与经历',
     'life_event_sentence_new_job' => '开始了新的工作',
     'life_event_sentence_retirement' => '退休',
     'life_event_sentence_new_school' => '开始上学',
@@ -493,7 +493,7 @@ return [
     'document_list_cta' => '上载文档',
     'document_list_blank_desc' => '在这里, 您可以存储与此人相关的文档。',
     'document_upload_zone_cta' => '上传文件',
-    'document_upload_zone_progress' => 'Uploading the document…',
+    'document_upload_zone_progress' => '正在上传文档...',
     'document_upload_zone_error' => '上传文件时出错，请再试一次 ！',
 
     // Photos
